@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/checks.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/checks.F
       subroutine checks (errorc, vmixset, hmixset)
       logical errorc, vmixset, hmixset
       include "param.h"
@@ -10,6 +10,8 @@
       include "iounit.h"
       include "levind.h"
 
+      include "isopyc.h"
+
       include "mw.h"
       include "scalar.h"
       include "switch.h"
@@ -52,18 +54,6 @@
         errorc = .true.
       endif
 
-      n = 0
-
-      n = n + 1
-
-      if (n .ne. 1) then
-        write (stdout,'(/,(1x,a))')
-     & '==> Error: Either "levitus_ic" or "idealized_ic" or            '
-     &,'           "equatorial_thermocline" must be enabled.           '
-     &,'           choose only one for initial conditions.             '
-        errorc = .true.
-      endif
-
       if (hmixset) then
         write (stdout,'(/,(1x,a))')
      & '==> Error: "consthmix"  cannot be enabled because another      '
@@ -125,6 +115,8 @@
      &, jmw, 'with calculations starting on MW row =', jsmw
      &,'and ending on MW row =', jemw
 
+     &                               -1
+
      &,'disk latitude rows to be calculated are from 2 through', jmt-1
      &,'to compute these rows, the MW is moved northward '
      &, num_mw,' times.','however, the last time there are only ',n
@@ -134,8 +126,8 @@
      &, 'imbalance on the last MW. The following is a list of "jmw"'
      &, 'which will not cause a load imbalance:'
 
-        jb = 2
-        jjs  = 3
+        jb = 3
+        jjs  = 4
 
         do jj=jjs,jmt-2
           ncrow = jj-jb
@@ -146,15 +138,17 @@
         enddo
       endif
 
-      if (jmw .lt. 3) then
+      if (jmw .lt. 4) then
         write (stdout,9000)
-     & '==> Error: the MW can not have fewer than 3 rows (jmw >2)      '
+     & '==> Error: the MW can not have fewer than 4 rows when using any'
+     &,'           fourth order options                                '
         write (stdout,*)'          you have set jmw=',jmw
         errorc = .true.
       endif
-      if (jmw .gt. 3) then
+      if (jmw .gt. 4) then
         write (stdout,9000)
-     & '==> Warning: "jmw" > 3 ("jmw"=3 will use the minimum memory)   '
+     & '==> Warning: "jmw" > 4 ("jmw"=4 will use the minimum memory)   '
+        write (stdout,*)'          you have set jmw=',jmw
       endif
 
       if (jmw .gt. jmt) then
@@ -188,10 +182,23 @@
      &,'             the "restorst" otpion is not enabled              '
       endif
 
+        write (stdout,9000)
+     & '==> Note: consthmix will only affect mixing of momentum        '
+     &,'          since isopycmix was specified for tracer diffusion.  '
+     &,'          kappa_h and Ah will be used as background mixing     '
+     &,'          coefficients                                         '
+
         write (stdout,9000)
      & '==> Warning: although "sf_5_point" has no null space, it does  '
      &,'             not conserve total energy.                        '
 
+        if ((ah+ahisop) .gt. 1.e11) then
+          write (stdout,9000)
+     & '==> Error: "ahisop"+"ah" is too large for the                  '
+     &,'           "isopycmix" mixing option                           '
+          errorc = .true.
+        endif
+
         if (dtsf .le. c0) then
           write (stdout,9000)
      & '==> Error: need to set the external mode time step "dtsf"      '
@@ -283,12 +290,6 @@
      &,'             average will be over only one time step!          '
         endif
 
-          write (stdout,9000)
-     & '==> Warning: "option "time_averages" is enabled but            '
-     &,'             "time_averages_disk" is not. extra memory will be '
-     &,'             used. Note that"time_averages_disk" does not work '
-     &,'             with option "ramdrive"                            '
-
       if (xbtint .ne. c0) then
         write (stdout,9000)
      & '==> Warning: the averaging interval "xbtint"  is > zero but    '
@@ -320,11 +321,9 @@
       enddo
       dzmin  = dzt(1)
       xlmax  = dtxcel(1)
-
       do k=2,km
         xlmax  = max(xlmax,dtxcel(k))
         dzmin  = min(dzmin,dzt(k))
-
       enddo
 
       if (xlmax .gt. c1) then
@@ -340,13 +339,20 @@
       do j=2,jmtm1
         dxdymn = c1/(c1/(dxmin*cst(j))**2 + c1/dymin**2)
 
-        if ((dtxl*ah)/dxdymn .ge. p25) then
+        fimax = 0.
+        do k=1,km
+          do i=2,imtm1
+            fimax = max(fimax,fisop(i,j,k))
+          enddo
+        enddo
+        if ((dtxl*(ah+ahisop*fimax))/dxdymn .ge. p25) then
 
           num = num + 1
           if (num .eq. 1) write (stdout,9000)
 
-     & '==> Warning: lateral diffusive criteria exceeded for "ah".     '
-     &,'              use a smaller "dtts", "dtxcel", and/or "ah"      '
+     & '==> Warning: lateral diffusive criteria exceeded for "ah" +    '
+     &,'             "ahisop". use a smaller "dtts", "dtxcel", and/or  '
+     &,'             "ah" + "ahisop"                                   '
 
           write (stdout,'(a48,f6.2,a5,i3)') ' at latitude ',yt(j)
      &,                                     ',  j=',j
@@ -393,13 +399,6 @@
 
 !     check range of implicit factors
 
-      if (aidif .ne. c0) then
-        write (stdout,9000)
-     & '==> Warning: "aidif" was not = 0.0  but "implicivmix" or       '
-     &,'             "isopycmix" is not defined, so vertical mixing    '
-     &,'              will be fully explicit.                          '
-      endif
-
       if (acor .ne. 0) then
         write (stdout,9000)
      & '==> Error: "acor" must=0 when option damp_inertial_oscillation '
@@ -409,11 +408,12 @@
 
 !       check for marginally resolved inertial oscillation
 
-        fmax = max(abs(c2*omega*sine(2)),epsln)
-        do jrow=3,jmtm2
-          fmax = max(fmax,abs(c2*omega*sine(jrow)))
+        fmax = epsln
+        do jrow=2,jmtm1
+          do i=2,imtm1
+            fmax = max(fmax,abs(cori(i,jrow,1)))
+          enddo
         enddo
-
         if (dtuv .gt. (1.0/6.0)*(c2*pi)/fmax) then
           write (stdout,9000)
      & '==> Error: the inertial oscillation is not resolved. reduce    '
@@ -495,6 +495,11 @@
      &,'           points.                                             '
       endif
 
+      write (stdout,9000)
+     & '==> Warning: fct delimiter type is not specified               '
+     &,'             specify either fct_dlm1 or fct_dlm2               '
+     &,'    Default: using fct_dlm1                                    '
+
       write (stdout,'(/,20x,a,/)')
      &         ' E N D    C O N S I S T E N C Y    C H E C K S'
       if (errorc) stop '=>checks'
