@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/clinic.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/clinic.F
       subroutine clinic (joff, js, je, is, ie)
 
 !=======================================================================
@@ -12,7 +12,7 @@
 !       is   = starting longitude index in the MW
 !       ie   = ending longitude index in the MW
 
-!     author:   r.c.pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -24,14 +24,12 @@
       include "hmixc.h"
       include "emode.h"
       include "levind.h"
-      include "mapsbc.h"
       include "mw.h"
       include "scalar.h"
       include "switch.h"
       include "vmixc.h"
       dimension tempik(imt,km,jsmw:jmw)
       dimension baru(imt,jsmw:jemw,2)
-
       include "fdifm.h"
 
 !-----------------------------------------------------------------------
@@ -361,20 +359,8 @@
 !     averaged over this segment
 !-----------------------------------------------------------------------
 
-      if (igu .ne. 0 .and. igv .ne. 0) then
-        call isbcu (joff, js, je, istrt, iend, igu, igv)
-      endif
-
-!-----------------------------------------------------------------------
-!     if needed, construct the Atmos S.B.C.(surface boundary conditions)
-!     averaged over this segment
-!     reference: Pacanowski, R.C., Effect of Equatorial Currents
-!                on Surface Stress (JPO, Vol 17, No. 6, June 1987)
-!-----------------------------------------------------------------------
-
-      if (isu .ne. 0 .and. isv .ne. 0) then
-        call asbcu (joff, js, je, istrt, iend, isu, isv)
-      endif
+      call isbcu (joff, js, je, istrt, iend, igu, igv)
+      call asbcu (joff, js, je, istrt, iend, isu, isv)
 
       return
       end
@@ -393,7 +379,7 @@
 !       ie   = ending longitude index in the MW
 !       n    = (1,2) = (u,v) velocity component
 
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       include "param.h"
@@ -409,7 +395,7 @@
 
 !-----------------------------------------------------------------------
 !     diagnostic: accumulate global kinetic energy on "tau" velocity
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !               (based on diagnostic by M. Cox)
 !-----------------------------------------------------------------------
 
@@ -433,7 +419,7 @@
 !-----------------------------------------------------------------------
 !     diagnostic: integrate work done by the r.h.s. terms in the
 !                  momentum equations.
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !               (this is not done the same way as in MOM 1)
 !-----------------------------------------------------------------------
 
@@ -443,7 +429,7 @@
 !     diagnostic: integrate r.h.s. terms in the momentum equations
 !                 over specified regional volumes
 
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       if (trmbts .and. eots) call utb1 (joff, js, je, is, ie, n)
@@ -464,7 +450,7 @@
 !       is   = starting longitude index in the MW
 !       ie   = ending longitude index in the MW
 
-!     author:   r.c.pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       include "param.h"
@@ -478,7 +464,7 @@
 !                 accounted for after the external mode is solved.
 !                 also, integrate the work done by buoyancy.
 
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !               (this is not done the same way as in MOM 1)
 !-----------------------------------------------------------------------
 
@@ -491,7 +477,7 @@
 !                 over specified volumes. the external mode parts will
 !                 be accounted for after the external mode is solved.
 
-!     author:   R. C. Pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       if (trmbts .and. eots) then
@@ -517,7 +503,7 @@
 
 !     reference: Pacanowski, R.C., Effect of Equatorial Currents
 !                on Surface Stress (JPO, Vol 17, No. 6, June 1987)
-!     author:   r.c.pacanowski       e-mail rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       include "param.h"
@@ -535,8 +521,8 @@
           jrow  = j + joff
           do i=is,ie
             if (kmt(i,jrow) .ne. 0) then
-              sbcocn(i,jrow,iu) = c0
-              sbcocn(i,jrow,iv) = c0
+              sbc(i,jrow,iu) = c0
+              sbc(i,jrow,iv) = c0
             endif
           enddo
         enddo
@@ -548,12 +534,12 @@
         do j=js,je
           jrow  = j + joff
           do i=is,ie
-            sbcocn(i,jrow,iu) = sbcocn(i,jrow,iu) + p25*(
-     &                          u(i,1,j,1,tau) + u(i-1,1,j,1,tau)
-     &                        + u(i,1,j-1,1,tau) + u(i-1,1,j-1,1,tau))
-            sbcocn(i,jrow,iv) = sbcocn(i,jrow,iv) + p25*(
-     &                          u(i,1,j,2,tau) + u(i-1,1,j,2,tau)
-     &                        + u(i,1,j-1,2,tau) + u(i-1,1,j-1,2,tau))
+            sbc(i,jrow,iu) = sbc(i,jrow,iu) + p25*(
+     &                       u(i,1,j,1,tau) + u(i-1,1,j,1,tau)
+     &                     + u(i,1,j-1,1,tau) + u(i-1,1,j-1,1,tau))
+            sbc(i,jrow,iv) = sbc(i,jrow,iv) + p25*(
+     &                       u(i,1,j,2,tau) + u(i-1,1,j,2,tau)
+     &                     + u(i,1,j-1,2,tau) + u(i-1,1,j-1,2,tau))
           enddo
         enddo
       endif
@@ -567,8 +553,8 @@
           jrow  = j + joff
           do i=is,ie
             if (kmt(i,jrow) .ne. 0) then
-              sbcocn(i,jrow,iu) = rts*sbcocn(i,jrow,iu)
-              sbcocn(i,jrow,iv) = rts*sbcocn(i,jrow,iv)
+              sbc(i,jrow,iu) = rts*sbc(i,jrow,iu)
+              sbc(i,jrow,iv) = rts*sbc(i,jrow,iv)
             endif
           enddo
         enddo
@@ -607,8 +593,8 @@
           jrow  = j + joff
           do i=is,ie
             if (kmt(i,jrow) .ne. 0) then
-              sbcocn(i,jrow,iu) = c0
-              sbcocn(i,jrow,iv) = c0
+              sbc(i,jrow,iu) = c0
+              sbc(i,jrow,iv) = c0
             endif
           enddo
         enddo
@@ -621,8 +607,8 @@
         do j=js,je
           jrow  = j + joff
           do i=is,ie
-            sbcocn(i,jrow,iu) = sbcocn(i,jrow,iu) + u(i,2,j,1,tau)
-            sbcocn(i,jrow,iv) = sbcocn(i,jrow,iv) + u(i,2,j,2,tau)
+            sbc(i,jrow,iu) = sbc(i,jrow,iu) + u(i,2,j,1,tau)
+            sbc(i,jrow,iv) = sbc(i,jrow,iv) + u(i,2,j,2,tau)
           enddo
         enddo
       endif
@@ -636,8 +622,8 @@
           jrow  = j + joff
           do i=is,ie
             if (kmt(i,jrow) .ne. 0) then
-              sbcocn(i,jrow,iu) = rts*sbcocn(i,jrow,iu)
-              sbcocn(i,jrow,iv) = rts*sbcocn(i,jrow,iv)
+              sbc(i,jrow,iu) = rts*sbc(i,jrow,iu)
+              sbc(i,jrow,iv) = rts*sbc(i,jrow,iv)
             endif
           enddo
         enddo
