@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/cnep.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/cnep.h
 !===================== include file "cnep.h" ===========================
 
 !     the option "neptune" provides a subgridscale parameterization
