@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/cobc.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/cobc.h
 !====================== include file "cobc.h" ==========================
 
       common /ccobc/ var
