@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/cpolar.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/cpolar.h
 !====================== include file "cpolar.h" =========================
 
 !     polar transform coefficients used to transform velocities near
