@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/cprnts.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/cprnts.h
 !====================== include file "cprnts.h" =======================
 
 !     variables used for controlling matrix printouts during diagnostic
