@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/cshort.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/cshort.h
 !====================== include file "cshort.h" ========================
 
 !     pen    = double exponential penetration function defined at
