@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/csnap.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/csnap.h
 !====================== include file "csnap.h" =========================
 
 !     snapls = starting latitude (degs) for 1
