@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/ctavg.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/ctavg.h
 !====================== include file "ctavg.h" =========================
 
 !     common for tracer averages within horizontal regions
