@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/diago.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/diago.F
       subroutine diago
 
 !=======================================================================
@@ -29,11 +29,9 @@
       include "task_on.h"
       include "tmngr.h"
       include "vmixc.h"
-!#define debug_extmode
 
-      character(120) :: ftsi, ftbt, file_stamp
-      save ftsi, ftbt
-      data ftsi  /' '/
+      character(120) :: fname, ftbt, file_stamp
+      save ftbt
       data ftbt  /' '/
 
       integer ntrec
@@ -185,23 +183,19 @@
         if (iotsi .ne. stdout .or. iotsi .lt. 0) then
 
           if (iotsi .ne. stdout) then
-            ntrec = 1
-            if (ftsi .eq. ' ') then
-              ntrec = 0
-              ftsi = file_stamp ('ts_intgrls_mom',stamp,'.nc')
-            endif
             avgper = dtts*ntatio/daylen
             time = relyr + year0
-            call mom_tsi_out (ftsi, ntrec, timunit, expnam, avgper
-     &,                       time, stamp, tai_ek, tai_t, tai_s
-     &,                       tai_tvar, tai_svar, tai_dt, tai_ds
-     &,                       tai_scan
-
-     &,                       tai_dic
-
-     &,                       tai_otmax, tai_otmin
-
-     &                       )
+            call def_tsi
+            call def_tsi_mom (fname)
+            call mom_tsi_out (fname, avgper, time, stamp, tai_ek, tai_t
+     &,                       tai_s, tai_tvar, tai_svar, tai_dt, tai_ds
+     &,                       tai_scan, tai_hflx, tai_sflx, tai_dic
+     &,                       tai_dicflx, tai_alk, tai_o2, tai_o2flx
+     &,                       tai_po4, tai_p, tai_z, tai_d, tai_no3
+     &,                       tai_di, tai_c14, tai_dc14, tai_c14flx
+     &,                       tai_cfc11, tai_cfc11flx, tai_cfc12
+     &,                       tai_cfc12flx, tai_otmax, tai_otmin
+     &,                       tai_slh, ntrec)
           endif
         endif
 
@@ -1041,25 +1035,70 @@
 !      implicit none
 
       include "param.h"
+      include "csbc.h"
       include "coord.h"
       include "cregin.h"
       include "grdvar.h"
       include "diag.h"
+      include "diaga.h"
       include "emode.h"
       include "levind.h"
       include "mw.h"
       include "iounit.h"
 
-      integer i, j, jrow, k, ib(10), ic(10)
+      integer i, j, jrow, k, kmax, ib(10), ic(10)
 
       include "state.h"
       include "dens.h"
 
       real d, dens, dins, rntatio, s, sum, tmp, tins, tinsit
-      real C2K, p001, p035
+      real C2K, p001, p035, dmsk(imt,jmt)
 
       real otsf(km)
 
+      character(120) :: fname, new_file_name
+
+      logical exists
+
+      real, allocatable :: d_slh(:,:,:)
+      save d_slh
+
+      C2K = 273.15
+      p001 = 0.001
+      p035 = 0.035
+
+      if (.not. allocated (d_slh)) then
+        fname = new_file_name ("slh_ref.nc")
+        inquire (file=trim(fname), exist=exists)
+        if (exists) then
+          allocate ( d_slh(2:imtm1,2:jmtm1,km) )
+          d_slh(:,:,:) = 0.
+          ib(:) = 1
+          ic(:) = imtm2
+          ic(2) = jmtm2
+          ic(3) = km
+          ic(4) = 1
+
+          call openfile (fname, iou)
+          call getvara ('temp', iou, imtm2*jmtm2*km, ib, ic
+     &,     t_slh(2,2,1,1), c1, -C2K)
+          call getvara ('salinity', iou, imtm2*jmtm2*km, ib, ic
+     &,     t_slh(2,2,1,2), p001, -p035)
+
+          call closefile (iou)
+          do j=2,jmtm1
+            do i=2,imtm1
+              do k=1,kmt(i,j)
+                s = (t_slh(i,j,k,2)*1000.) + 35.
+                d = zt(k)*0.01
+                tins = tinsit(t_slh(i,j,k,1), s, d)
+                d_slh(i,j,k) = dens(tins-to(k), t_slh(i,j,k,2)-so(k), k)
+              enddo
+            enddo
+          enddo
+        endif
+      endif
+
 !-----------------------------------------------------------------------
 !     time averaged integrated data
 !-----------------------------------------------------------------------
@@ -1068,9 +1107,15 @@
 !       zero
         ntatio = 0
 
+        nt_slh = 0
+        t_slh(:,:,:,:) = 0.
+
         nv_otsf = 0
         v_otsf(:,:) = 0.
 
+        tai_otmax = 0.
+        tai_otmin = 0.
+        tai_slh = 0.
         tai_ek = 0.
         tai_t = 0.
         tai_s = 0.
@@ -1079,11 +1124,22 @@
         tai_dt = 0.
         tai_ds = 0.
         tai_scan = 0.
-        tai_otmax = 0.
-        tai_otmin = 0.
-
+        tai_hflx = 0.
+        tai_sflx = 0.
         tai_dic = 0.
-
+        tai_dicflx = 0.
+        tai_alk = 0.
+        tai_o2 = 0.
+        tai_o2flx = 0.
+        tai_po4 = 0.
+        tai_p = 0.
+        tai_z = 0.
+        tai_d = 0.
+        tai_no3 = 0.
+        tai_di = 0.
+        tai_c14 = 0.
+        tai_dc14 = 0.
+        tai_c14flx = 0.
       elseif (m .eq. 1) then
 !       accumulate
         ntatio = ntatio + 1
@@ -1114,8 +1170,16 @@
         tai_dt = tai_dt + dtabs(0,itemp,1)
         tai_ds = tai_ds + dtabs(0,isalt,1)
         tai_scan = tai_scan + mscan
+        dmsk(:,:) = 1.
+        where (kmt(:,:) .eq. 0) dmsk(:,:) = 0.
+        call areaavg (sbc(1,1,ihflx), dmsk, tmp)
+        tai_hflx = tai_hflx + tmp
+        call areaavg (sbc(1,1,isflx), dmsk, tmp)
+        tai_sflx = tai_sflx + tmp
 
         tai_dic = tai_dic + tbar(0,idic,1)
+        call areaavg (sbc(1,1,idicflx), dmsk, tmp)
+        tai_dicflx = tai_dicflx + tmp
 
       elseif (m .eq. 2 .and. ntatio .ne. 0) then
 !       average
@@ -1141,6 +1205,46 @@
           enddo
         endif
 
+        if (nt_slh .gt. 0) then
+          rnt_slh = 1./float(nt_slh)
+          t_slh(:,:,:,:) = t_slh(:,:,:,:)*rnt_slh
+          if (.not. allocated (d_slh)) then
+!           if not allocated get reference from the first density
+            allocate ( d_slh(imt,jmt,km) )
+            do j=2,jmtm1
+              do i=2,imtm1
+                do k=1,kmt(i,j)
+                  s = (t_slh(i,j,k,2)*1000.) + 35.
+                  d = zt(k)*0.01
+                  tins = tinsit(t_slh(i,j,k,1), s, d)
+                  d_slh(i,j,k) = dens(tins-to(k),t_slh(i,j,k,2)-so(k),k)
+                enddo
+              enddo
+            enddo
+          else
+!           if reference is allocated calculate relative sea level height
+            tai_slh = 0.0
+            tarea = 0.0
+            do j=2,jmtm1
+              cosdyt = cst(j)*dyt(j)
+              do i=2,imtm1
+                if (kmt(i,j) .ge. 1) then
+                  area = dxt(i)*cosdyt
+                  tarea = tarea + area
+                  do k=1,kmt(i,j)
+                    s = (t_slh(i,j,k,2)*1000.) + 35.
+                    d = zt(k)*0.01
+                    tins = tinsit(t_slh(i,j,k,1), s, d)
+                    dins = dens(tins-to(k),t_slh(i,j,k,2)-so(k),k)
+                    tai_slh = tai_slh-(dins-d_slh(i,j,k))*area*dzt(k)
+                  enddo
+                endif
+              enddo
+            enddo
+            if (tarea .gt. 0) tai_slh = tai_slh/tarea
+          endif
+        endif
+
         tai_ek = tai_ek*rntatio
         tai_t = tai_t*rntatio
         tai_s = tai_s*rntatio
@@ -1149,11 +1253,81 @@
         tai_dt = tai_dt*rntatio
         tai_ds = tai_ds*rntatio
         tai_scan = tai_scan*rntatio
-
+        tai_hflx = tai_hflx*rntatio
+        tai_sflx = tai_sflx*rntatio
         tai_dic = tai_dic*rntatio
-
+        tai_dicflx = tai_dicflx*rntatio
+        tai_alk = tai_alk*rntatio
+        tai_o2 = tai_o2*rntatio
+        tai_o2flx = tai_o2flx*rntatio
+        tai_po4 = tai_po4*rntatio
+        tai_p = tai_p*rntatio
+        tai_z = tai_z*rntatio
+        tai_d = tai_d*rntatio
+        tai_no3 = tai_no3*rntatio
+        tai_di = tai_di*rntatio
+        tai_c14 = tai_c14*rntatio
+        tai_dc14 = tai_dc14*rntatio
+        tai_c14flx = tai_c14flx*rntatio
+        tai_cfc11 = tai_cfc11*rntatio
+        tai_cfc11flx = tai_cfc11flx*rntatio
+        tai_cfc12 = tai_cfc12*rntatio
+        tai_cfc12flx = tai_cfc12flx*rntatio
       endif
 
       return
       end
 
+      real function tinsit (ti, si, di)
+!=======================================================================
+!     function to calculate insitu temperature using Newtons method
+
+!     based on code by e.c.wiebe
+
+!     input:
+!       ti = potential temperature (C)
+!       si = salinity (psu)
+!       di = depth (m)
+
+!     output:
+!       tinsit = institu temperataure
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      integer iter
+
+      real, intent(in) :: di, si, ti
+      real(kind=8) d, dfdt, error, s, t, ta, tb, tol
+
+      error = 1.
+      iter = 0
+      tol = 1.e-5
+      t = ti
+      d = di
+      s= si
+      do while (abs(error) .gt. tol .and. iter .lt. 25)
+        iter = iter + 1
+        call potem(t, s, d, ta)
+        call potem(t+1.e-3 ,s, d, tb)
+        dfdt = (tb - ta)*1.e3
+        error = (ta - ti)/dfdt
+        t = t - error
+      enddo
+      if (abs(error) .gt. tol) then
+        print*, "=> Error: insitu temperature did not converge"
+        print*, "          ti = ", ti
+        print*, "          si = ", si
+        print*, "          di = ", di
+        print*, "          error = ", abs(error)
+        print*, "          tinsit = ", t
+        print*, "   Stopped in function tinsit in diago.F"
+        stop
+      endif
+      tinsit = t
+
+      return
+      end
+
