@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/docnam.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/docnam.h
 !====================== include file "docnam.h" ========================
 
 !    info from docum.F that can be used elsewhere.
