@@ -1,4 +1,5 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/eoyr.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/eoyr.F
+
       subroutine eoyr (is, ie, js, je)
 !=======================================================================
 !     things to do at the end of a year
@@ -18,24 +19,24 @@
       include "atm.h"
       include "coord.h"
       include "grdvar.h"
-
-      include "ice.h"
-
-      include "mtlm.h"
-
       include "cembm.h"
       include "iounit.h"
       include "scalar.h"
       include "switch.h"
       include "tmngr.h"
 
-      character(120) :: fname, new_file_name
+      include "ice.h"
 
-      integer i, ie, is, iou, j, je, js, L, ib(10), ic(10)
+      include "mtlm.h"
+
+      character(120) :: fname, new_file_name
+      character(3) :: a3
+
+      integer i, ie, is, iou, j, je, js, L, ib(10), ic(10), n
 
       logical exists, inqvardef
 
-      real wt, wtp1
+      real wt, f, dmsk(imt,jmt)
 
       return
       end
