@@ -1,21 +1,12 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/ice/evp.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/ice/evp.F
       subroutine evp (is, ie, js, je)
 !=======================================================================
 !     calculate velocities using an "elastic-viscous-plastic" rheology
-!     based on code by e.hunke
 
 !     see E. C. Hunke and J. K. Dukowicz. An elastic-viscous-plastic
 !       model for sea ice dynamics. J. Phys. Oceanogr., 1997.
 
-!     author:   m.eby   e-mail: eby@uvic.ca
-
-!     most of the code called by this routine is available to the
-!     public from the following internet sight:
-!     http://gnarly.lanl.gov/Pop/eclare/evpcode/evp.html
-
-!     e.hunke (e-mail: eclare@lanl.gov as of 01/March/1998) would
-!     appreciate being informed as to who uses this code
-
+!     based on code by: E. Hunke and M. Holland
 !=======================================================================
 
       include "param.h"
@@ -66,9 +57,6 @@
 !.. nor the University makes any warranty, express or implied, or assumes
 !.. any liability or responsibility for the use of this software.
 
-!   code modified for coupling to the uvic climate model by m.holland
-!     holland@ocean.uvic.ca
-
 !-----------------------------------------------------------------------
 
       subroutine viscevp
@@ -81,6 +69,7 @@
 
       include "param.h"
       include "grdvar.h"
+      include "atm.h"
       include "ice.h"
       include "evp.h"
 
@@ -158,10 +147,10 @@
             zetaw(i,j) = max(zetamin,zetaw(i,j))
 
 !           mask zeta (and therefore eta)
-            zetan(i,j) = zetan(i,j)*tm(i,j)
-            zetae(i,j) = zetae(i,j)*tm(i,j)
-            zetas(i,j) = zetas(i,j)*tm(i,j)
-            zetaw(i,j) = zetaw(i,j)*tm(i,j)
+            zetan(i,j) = zetan(i,j)*tmsk(i,j)
+            zetae(i,j) = zetae(i,j)*tmsk(i,j)
+            zetas(i,j) = zetas(i,j)*tmsk(i,j)
+            zetaw(i,j) = zetaw(i,j)*tmsk(i,j)
 
 !           shear viscosity eta                        ! g/s
             etan(i,j) = zetan(i,j)*ecc2
@@ -195,7 +184,6 @@
       include "atm.h"
       include "ice.h"
       include "evp.h"
-      include "mapsbc.h"
       include "csbc.h"
 
       costh = 0.9063
@@ -207,7 +195,7 @@
         do j=jsi(n),jei(n)+1
           do i=2,imt
 
-            if (tm(i,j) .gt. floor) then
+            if (tmsk(i,j) .gt. floor) then
 
               ey = Econst*hice(i,j,2)          ! E, g/s^2
 
@@ -293,20 +281,18 @@
       do n=1,nseg
         do j=jsi(n),jei(n)
           do i=2,imtm1
-
-            fmass(i,j) = fcor(j)*umass(i,j)        ! Coriolis * mass
-
+            fmass(i,j) = fcor(i,j)*umass(i,j)      ! Coriolis * mass
             sinth = sign(sinth,fmass(i,j))
 !           for water stress
-            waterx(i,j) = um(i,j)*(sbcocn(i,j,igu)*costh -
-     +                sbcocn(i,j,igv)*sinth)
-            watery(i,j) = um(i,j)*(sbcocn(i,j,igv)*costh +
-     +                sbcocn(i,j,igu)*sinth)
+            waterx(i,j) = umsk(i,j)*(sbc(i,j,igu)*costh -
+     +                sbc(i,j,igv)*sinth)
+            watery(i,j) = umsk(i,j)*(sbc(i,j,igv)*costh +
+     +                sbc(i,j,igu)*sinth)
 !           air stress and -mg*gradH_o term (tilt)
-            strairx(i,j) = um(i,j)*(sbcocn(i,j,itaux) -
-     +                fmass(i,j)*sbcocn(i,j,igv))
-            strairy(i,j) = um(i,j)*(sbcocn(i,j,itauy) +
-     +                fmass(i,j)*sbcocn(i,j,igu))
+            strairx(i,j) = umsk(i,j)*(sbc(i,j,itaux) -
+     +                fmass(i,j)*sbc(i,j,igv))
+            strairy(i,j) = umsk(i,j)*(sbc(i,j,itauy) +
+     +                fmass(i,j)*sbc(i,j,igu))
           enddo
         enddo
       enddo
@@ -322,6 +308,7 @@
 !=======================================================================
       include "param.h"
       include "levind.h"
+      include "atm.h"
       include "ice.h"
       include "evp.h"
 
@@ -329,7 +316,7 @@
         do j=jsi(n), jei(n) + 1
           do i=2,imt
 
-            if (tm(i,j) .gt. floor) then
+            if (tmsk(i,j) .gt. floor) then
 
               dun = uice(i,j) - uice(i-1,j)
               dus = uice(i,j-1) - uice(i-1,j-1)
@@ -403,18 +390,18 @@
 !=======================================================================
       include "param.h"
       include "cembm.h"
-      include "levind.h"
+      include "atm.h"
       include "ice.h"
       include "evp.h"
 
       real tmass(imt,jmt)
 
       pstar = 2.75e5
-!     total mass of ice and snow, centered in T-cell
+!     total mass of ice and snow, centred in T-cell
       do n=1,nseg
         do j=jsi(n), jei(n) + 1
           do i=1,imt
-            if(tm(i,j) .ne. 0.0) then
+            if (tmsk(i,j) .ne. 0.0) then
 !             if you, like Hibler (1979), have only thick ice
 
               tmass(i,j) = rhoice*hice(i,j,2)    ! g/cm^2
@@ -433,7 +420,7 @@
         enddo
       enddo
 
-!     mass centered at velocity nodes (U-cells)
+!     mass centred at velocity nodes (U-cells)
       do n=1,nseg
         do j=jsi(n),jei(n)
           do i=2,imtm1
@@ -468,7 +455,7 @@
 !=======================================================================
       include "param.h"
       include "levind.h"
-      include "mapsbc.h"
+      include "atm.h"
       include "ice.h"
       include "evp.h"
       include "csbc.h"
@@ -515,18 +502,14 @@
         do j=jsi(n),jei(n)
           do i=2,imtm1
 
-            if (um(i,j) .gt. floor .and. umass(i,j) .gt. 0.01) then
-!           geostrophic ocean currents relative to ice velocity
-              uorel = sbcocn(i,j,igu) - uice(i,j)
-              vorel = sbcocn(i,j,igv) - vice(i,j)
+            if (umsk(i,j) .gt. floor .and. umass(i,j) .gt. 0.01) then
+!             geostrophic ocean currents relative to ice velocity
+              uorel = sbc(i,j,igu) - uice(i,j)
+              vorel = sbc(i,j,igv) - vice(i,j)
 !             (magnitude of relative geostrophic ocean current)*rhow*drag
               vrel = 0.0055*1.03*sqrt(uorel**2 + vorel**2)  ! cm/s
 !              vrel = dragw*sqrt(uorel**2 + vorel**2)  ! cm/s
 
-!             TOTAL surface stress-includes wind stress, water stress, tilt
-              taux = strairx(i,j) + vrel*waterx(i,j)
-              tauy = strairy(i,j) + vrel*watery(i,j)
-
 !             alpha, beta are defined in Hunke and Dukowicz sec 3.2
               umassdtei = umass(i,j)*dtei  ! m/dte,alpha, beta, g/cm^2 s
               cca = umassdtei + vrel*costh
@@ -550,8 +533,10 @@
               yint(i,j) = s21 + s22
 
 !             finally, the velocity components (in cm/s)
-              c1evp = xint(i,j) + taux + umassdtei*uice(i,j)
-              c2evp = yint(i,j) + tauy + umassdtei*vice(i,j)
+              c1evp = xint(i,j) + strairx(i,j) + vrel*waterx(i,j)
+     &              + umassdtei*uice(i,j)
+              c2evp = yint(i,j) + strairy(i,j) + vrel*watery(i,j)
+     &              + umassdtei*vice(i,j)
               uice(i,j) = (cca*c1evp + ccb*c2evp)/ab2
               vice(i,j) = (cca*c2evp - ccb*c1evp)/ab2
             else
