@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/file_names.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/file_names.F
       subroutine file_names
 !=======================================================================
 !     edit this routine to change file names or add directories to file
@@ -87,6 +87,7 @@
       call put_names ('kmt', 'data/kmt')
       call put_names ('region_masks', 'data/region_masks')
       call put_names ('sf_alb', 'data/sf_alb')
+      call put_names ('a_calb', 'data/a_calb')
       call put_names ('hflx', 'data/hflx')
       call put_names ('sflx', 'data/sflx')
       call put_names ('grid', 'data/grid')
@@ -95,30 +96,45 @@
       call put_names ('veg', 'data/veg')
       call put_names ('solar', 'data/solar')
       call put_names ('co2', 'data/co2')
+      call put_names ('cfc', 'data/cfc')
+      call put_names ('c14', 'data/c14')
+      call put_names ('dc14', 'data/dc14')
+      call put_names ('tidal', 'data/tidal')
       call put_names ('crops', 'data/crops')
       call put_names ('ice', 'data/ice')
       call put_names ('slh_ref', 'data/slh_ref')
       call put_names ('diff', 'data/diff')
       call put_names ('temperature_', 'data/temperature_')
       call put_names ('salinity_', 'data/salinity_')
-      call put_names ('dic_', 'data/dic_')
       call put_names ('dtr_', 'data/dtr_')
-      call put_names ('restart_mtlm', 'restart')
-      call put_names ('ts_intgrls_mtlm', 'ts_intgrls')
-      call put_names ('time_mean_mtlm', 'time_mean')
-      call put_names ('snapshots_mtlm', 'snapshots')
-      call put_names ('restart_embm', 'restart')
-      call put_names ('ts_intgrls_embm', 'ts_intgrls')
-      call put_names ('time_mean_embm', 'time_mean')
-      call put_names ('snapshots_embm', 'snapshots')
-      call put_names ('restart_mom', 'restart')
-      call put_names ('ts_intgrls_mom', 'ts_intgrls')
-      call put_names ('time_mean_mom', 'time_mean')
-      call put_names ('snapshots_mom', 'snapshots')
-      call put_names ('restart_cidm', 'restart')
-      call put_names ('ts_intgrls_cidm', 'ts_intgrls')
-      call put_names ('time_mean_cidm', 'time_mean')
-      call put_names ('snapshots_cidm', 'snapshots')
+      call put_names ('tco2_', 'data/tco2_')
+      call put_names ('phosphate_', 'data/phosphate_')
+      call put_names ('alk_', 'data/alk_')
+      call put_names ('nitrate_', 'data/nitrate_')
+      call put_names ('oxygen_', 'data/oxygen_')
+      call put_names ('bkgc14_', 'data/bkgc14_')
+      call put_names ('odf', 'data/odf')
+      call put_names ('rest_mtlm', 'rest')
+      call put_names ('restart_mtlm', 'data/restart')
+      call put_names ('tsi_mtlm', 'tsi')
+      call put_names ('tavg_mtlm', 'tavg')
+      call put_names ('snap_mtlm', 'snap')
+      call put_names ('rest_embm', 'rest')
+      call put_names ('restart_embm', 'data/restart')
+      call put_names ('tsi_embm', 'tsi')
+      call put_names ('tavg_embm', 'tavg')
+      call put_names ('snap_embm', 'snap')
+      call put_names ('rest_mom', 'rest')
+      call put_names ('restart_mom', 'data/restart')
+      call put_names ('tsi_mom', 'tsi')
+      call put_names ('tavg_mom', 'tavg')
+      call put_names ('snap_mom', 'snap')
+      call put_names ('rest_ism', 'rest')
+      call put_names ('restart_ism', 'data/restart')
+      call put_names ('tsi_ism', 'tsi')
+      call put_names ('tavg_ism', 'tavg')
+      call put_names ('snap_ism', 'snap')
+      call put_names ('ts_intgrls', 'tsi')
 
 !     write file name changes to filenames
       if (exists) then
