@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/gasbc.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/gasbc.F
       subroutine gasbc (is, ie, js, je)
 
 !=======================================================================
@@ -20,6 +20,7 @@
       include "insolation.h"
       include "calendar.h"
       include "grdvar.h"
+      include "levind.h"
 
       include "solve.h"
 
@@ -27,40 +28,44 @@
 
       integer i, ie, iem1, is, isp1, j, je, jem1, js, jsp1, l
 
-      real sss, phlo, phhi, sit_in, pt_in, atmpres, xconv, ta_in
-      real ph, co2_in, co2star, dco2star, dco2surf, dpco2, pco2surf
-      real scco2, piston_vel, avgflxc, fa, calday
+      real sss, sst, phlo, phhi, sit_in, pt_in, atmpres, xconv, ta_in
+      real dic_in, ph, co2_in, co2star, dco2star, dco2surf, dpco2
+      real pco2surf, scco2, piston_vel, avgflxc, fa, calday, f, sco2
+      real o2sat, o2sato, o2surf, piston_o2, cfc11ccn, cfc12ccn, wt
+      real sccfc, piston_cfc, sol_cfc, cfcsat, ao, tarea, tdc14ccn
+      real h_r, d, f1, f2, f3, f4, f5
 
       real cosz(is:ie,js:je)
 
+      real dmsk(is:ie,js:je)
+
       isp1 = is + 1
       iem1 = ie - 1
       jsp1 = js + 1
       jem1 = je - 1
 
+!     xconv is constant to convert piston_vel from cm/hr -> cm/s
+!     here it is 100.*a*xconv (100 => m to cm, a=0.337, xconv=1/3.6e+05)
+      xconv = 33.7/3.6e+05
+
       phlo = 6.
-      phhi = 9.
+      phhi = 10.
       sit_in = 7.6875e-03 !mol/m^3
       pt_in = 0.5125e-3   !mol/m^3
       atmpres = 1.0       !atm
-      xconv = 31.5/3.6e+05
       co2flx = 0.
 !     fa is used in converting g carbon cm-2 => ppmv CO2
 !     4.138e-7 => 12e-6 g/umol carbon / 29 g/mol air
       fa = 1./(4.138e-7*rhoatm*shc)
 
-!-----------------------------------------------------------------------
-!     average precipitaion and zero accumulator
-!-----------------------------------------------------------------------
-      avgp(:,:) = accp(:,:)/(segtim*daylen)
-      accp(:,:) = 0.0
-
 !-----------------------------------------------------------------------
 !     zero totals for new accumulation
 !-----------------------------------------------------------------------
       atatm = 0.
       flux(:,:,:) = 0.
 
+      sbc(:,:,ihflx) = 0.
+      sbc(:,:,isflx) = 0.
       sbc(:,:,iro) = 0.
 
       sbc(:,:,iat) = 0.
@@ -70,48 +75,12 @@
       sbc(:,:,iaws) = 0.
       sbc(:,:,iswr) = 0.
 
-      sbc(:,:,icflx) = 0.
-
-      do j=jsp1,jem1
-        do i=isp1,iem1
-
-          if (tmsk(i,j) .ge. 0.5) then
+      sbc(:,:,idicflx) = 0.
 
 !-----------------------------------------------------------------------
-!           calculate freezing point of sea water using UNESCO (1983)
+!     set solar constant
 !-----------------------------------------------------------------------
-            sss = 1000.0*sbc(i,j,isss) + 35.0
-            frzpt(i,j) = -.0575*sss + 1.710523e-3*sss**1.5
-     &                   - 2.154996e-4*sss**2
-
-!-----------------------------------------------------------------------
-!           calculate ocean surface flux of carbon
-!-----------------------------------------------------------------------
-            ta_in = sss*2.36775/(socn*1000.)   !surface ref alk
-
-            co2_in = co2ccn
-
-            call co2calc (sbc(i,j,isst), sss, sbc(i,j,issc)
-     &,       ta_in, pt_in, sit_in, phlo, phhi, ph, co2_in, atmpres
-     &,       co2star, dco2star, pCO2surf, dpco2)
-
-!           calculate Schmidt number (of co2 = 660 at t = 20 in sea water)
-!           based on SST. from Wanninkhof:  Sc = A - Bt + Ct^2 - Dt^3
-            scco2 = 2073.1 - 125.62*sbc(i,j,isst)
-     &            + 3.6276*sbc(i,j,isst)**2.0
-     &            - 0.043219*sbc(i,j,isst)**3.0
-
-!           xconv is constant to convert piston_vel from cm/hr -> cm/s
-!           wind speed spd(i,j) is converted from cm/s -> m/s
-            piston_vel = xconv*((sbc(i,j,iws)*0.01)**2.)
-     &                  *((scco2/660.)**(-0.5))*(1.0 - aice(i,j,1))
-
-!           dic in umol cm-3 or (mol m-3) => flux in umol cm-2 s-1
-            sbc(i,j,icflx) = piston_vel*dco2star
-
-          endif
-        enddo
-      enddo
+      call solardata
 
 !-----------------------------------------------------------------------
 !     update insolation for the current day
@@ -126,22 +95,71 @@
 !-----------------------------------------------------------------------
 !     update any atmospheric data
 !-----------------------------------------------------------------------
-
       call atmos
-      call albedo
+
+!-----------------------------------------------------------------------
+!     calculate freezing point of sea water using UNESCO (1983)
+!-----------------------------------------------------------------------
+
+      do j=jsp1,jem1
+        do i=isp1,iem1
+          if (tmsk(i,j) .ge. 0.5) then
+            sss = 1000.0*sbc(i,j,isss) + 35.0
+            frzpt(i,j) = -.0575*sss + 1.71e-3*sss**1.5 - 2.155e-4*sss**2
+
+            sst = sbc(i,j,isst)
+
+            ao = 1. - aice(i,j,1)
+
+!-----------------------------------------------------------------------
+!           calculate ocean carbon fluxes
+!-----------------------------------------------------------------------
+
+            ta_in = 2.36775*sss/(socn*1000.)
+
+            dic_in = sbc(i,j,issdic)
+
+            co2_in = co2ccn
+
+            call co2calc_SWS (sst, sss, dic_in, ta_in, pt_in, sit_in
+     &,                       phlo, phhi, ph, co2_in, atmpres, co2star
+     &,                       dco2star, pCO2surf, dpco2)
+!           Schmidt number for CO2
+            scco2 = 2073.1 - 125.62*sst + 3.6276*sst**2
+     &            - 0.043219*sst**3
+            piston_vel = ao*xconv*((sbc(i,j,iws)*0.01)**2)
+     &                  *((scco2/660.)**(-0.5))
+!           dic in umol cm-3 or (mol m-3) => flux in umol cm-2 s-1
+            sbc(i,j,idicflx) = piston_vel*dco2star
+
+          else
+!-----------------------------------------------------------------------
+!           calculate land carbon fluxes
+!-----------------------------------------------------------------------
+
+!           convert from kg m-2 s-1 => umol cm-2 s-1
+            sbc(i,j,idicflx) = (sbc(i,j,inpp) - sbc(i,j,isr))*0.1/12.e-6
+
+          endif
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     set boundary conditions for carbon
 !-----------------------------------------------------------------------
-      call setbcx (sbc(1,1,icflx), imt, jmt)
+      call setbcx (sbc(1,1,idicflx), imt, jmt)
+
+      dmsk(:,:) = 1.
+      call areaavg (sbc(1,1,idicflx), dmsk, avgflxc)
+      co2ccn = co2ccn - (co2flx + avgflxc)*segtim*12.e-6*daylen*fa
 
 !-----------------------------------------------------------------------
-!     calcualte CO2 forcing
+!     calculate CO2 forcing
 !-----------------------------------------------------------------------
       call co2forc
 
 !-----------------------------------------------------------------------
-!     set flags to calcualte new coefficients
+!     set flags to calculate new coefficients
 !-----------------------------------------------------------------------
       newcoef(1,1) = .true.
       newcoef(2,1) = .true.
