@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/hmixc.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/hmixc.h
 !======================= include file "hmixc.h" ========================
 
 !                    horizontal mixing coefficients
@@ -15,7 +15,7 @@
 !     ambi   = constant lateral biharmonic viscosity coeff for momentum
 !     ahbi   = constant lateral biharmonic diffusion coeff for tracers
 
-!     author:   r.c.pacanowski     e-mail  rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       common /diffus0/ am, ambi, am3(jmt), am4(jmt,2)
