@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/iomngr.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/iomngr.F
       subroutine ioinit
 
 !=======================================================================
@@ -7,7 +7,7 @@
 !     initializes the array fname of file names associated with each
 !     i/o unit, and opens a file "iohistory", if enabled.
 
-!     author c. h. goldberg          e-mail: chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "iomngr.h"
@@ -17,7 +17,7 @@
         hide_file(i) = .false.
         iunit(i) = 0
         fname(i) = ' '
-      end do
+      enddo
 
       fname(0) = ' '
       fname(1) = 'reserved'
@@ -34,13 +34,13 @@
         ifile(i) = 1
         scratch_file(i) = .false.
         unix_name(i) = .true.
-      end do
+      enddo
       do i=last_reserved_unit+1,maxunit
         inuse(i) = .false.
         ifile(i) = 0
         scratch_file(i) = .false.
         unix_name(i) = .true.
-      end do
+      enddo
 
 !     reserve units 5 and 6, whether or not they are stdin/stdout
 
@@ -57,7 +57,7 @@
         call link_unit (stderr, 'stderr')
       else
         fname(ifile(stdout)) = 'stdout/stderr'
-      end if
+      endif
 
       return
       end
@@ -70,7 +70,7 @@
 !     a section of code that does not use the iomngr to allocate
 !     units.  It reopens the file "iohistory", if enabled.
 
-!     author c. h. goldberg          e-mail: chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "iomngr.h"
@@ -88,7 +88,7 @@
 
 !     see relunit which releases a Fortran i/o unit number.
 
-!     author c. h. goldberg          e-mail: chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "iomngr.h"
@@ -104,12 +104,12 @@
 !         still be NAMED.  Getunit skips over it.
 
           open (i,FILE='/tmp/dummy',IOSTAT=iostat,status='unknown')
-          if (iostat .EQ. 0) then
+          if (iostat .eq. 0) then
             close (i)
             goto 101
-          end if
-        end if
-      end do
+          endif
+        endif
+      enddo
 
 !     "Normal" termination of the do loop indicates all units are in use
 
@@ -133,13 +133,13 @@
 !     given in optionlist.  Enable cpp directive "print_io_description"
 !     to see the list of options.
 
-!     author c. h. goldberg          e-mail: chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "iomngr.h"
 
       character(*) :: oldfilename, optionlist
-      character(80) :: filename, new_file_name
+      character(120) :: filename, new_file_name
       character(160) :: options
       character(2) :: aiounit
       character(160) :: string
@@ -211,14 +211,10 @@
 
 !       scan options by full names
 
-        if     (scan_option(options, i,
+        if (scan_option(options, i,
      &          'sequential', saccess, ssequential)) then
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'direct', saccess, sdirect)) then
-          if(scan_option(options, i, 'recl', sdummy, sdummy)) then
-          end if
-          if(scan_size(options, i, irec_len, iblock, iword, ibyte)) then
-          end if
           call setreclen (irec_len,srec_len,sform,iblock,iword,ibyte)
           if (irec_len .eq. 0) then
             print '(a,a,/,a,a)',
@@ -226,10 +222,8 @@
      &         ' ''direct'' requires a record length',
      &         ' options=',options
             errors = errors + 1
-          end if
-        else if(scan_option(options, i, 'recl', sdummy, sdummy)) then
-          if(scan_size(options, i, irec_len, iblock, iword, ibyte)) then
-          end if
+          endif
+        elseif (scan_option(options, i, 'recl', sdummy, sdummy)) then
           call setreclen (irec_len,srec_len,sform,iblock,iword,ibyte)
           if (irec_len .eq. 0) then
             print '(a,a,/,a,a)',
@@ -237,56 +231,52 @@
      &         ' ''recl='' requires a record length',
      &         ' options=',options
             errors = errors + 1
-          end if
-        else if(scan_option(options, i,
+          endif
+        elseif (scan_option(options, i,
      &          'formatted', sform, sformatted)) then
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'unformatted', sform, sunformatted)) then
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'readwrite', saction, sreadwrite)) then
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'read', saction, sread)) then
-          if (scan_option(options, i, 'only', sdummy, sdummy)) then
-          end if
           print '(a,a)', 'WARNING:  ACTION=''read'' not supported.  ',
      &                            'ACTION=''READWRITE'' is used.'
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'write', saction, swrite)) then
-          if (scan_option(options, i, 'only', sdummy, sdummy)) then
-          end if
           print '(a,a)', 'WARNING:  ACTION=''write'' not supported.  ',
      &                            'ACTION=''READWRITE'' is used.'
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'rewind', sposition, srewind)) then
-        else if(scan_option(options, i,
+        elseif (scan_option(options, i,
      &          'append', sposition, sappend)) then
-        else if(scan_option(options, i, 'ieee', sieee, 'ieee')) then
-        else if(scan_option(options, i, 'f77namelist',
+        elseif (scan_option(options, i, 'ieee', sieee, 'ieee')) then
+        elseif (scan_option(options, i, 'f77namelist',
      &          snamelist, 'f77')) then
 
 !       scan for blocking options
 
-        else if(scan_option(options, i, 'fortran',
+        elseif (scan_option(options, i, 'fortran',
      &          sblocking, 'f77')) then
-        else if(scan_option(options, i, 'f77',
+        elseif (scan_option(options, i, 'f77',
      &          sblocking, 'f77')) then
-        else if(scan_option(options, i, 'stream',
+        elseif (scan_option(options, i, 'stream',
      &          sblocking, 'null')) then
-        else if(scan_option(options, i, 'unblocked',
+        elseif (scan_option(options, i, 'unblocked',
      &          sblocking, 'null')) then
-        else if(scan_option(options, i, 'null',
+        elseif (scan_option(options, i, 'null',
      &          sblocking, 'null')) then
 
 !       the 'buffer' option is parsed, but ignored on many systems
 !       f77 blocking is assumed
 
-        else if(scan_option(options, i, 'buffer', sdummy, sdummy)) then
+        elseif (scan_option(options, i, 'buffer', sdummy, sdummy)) then
 
 !         force new_layer to recognize f77 blocking
 
           sblocking = 'f77'
           if (scan_size(options, i, ibuffer, iblock, iword, ibyte)) then
-          end if
+          endif
 !         why assume that buffers are in bytes?   f77 buffer units=bytes.
           call set2byte (ibuffer, iblock, iword, ibyte)
             inum = ibuffer
@@ -296,15 +286,11 @@
      &         ' ''buffer='' requires a size',
      &         ' options=',options
             errors = errors + 1
-          end if
+          endif
 !       scan options by abbreviated names
 
-        else if(scan_option(options, i, 's', saccess, ssequential)) then
-        else if(scan_option(options, i, 'd', saccess, sdirect)) then
-          if(scan_option(options, i, 'recl', sdummy, sdummy)) then
-          end if
-          if(scan_size(options, i, irec_len, iblock, iword, ibyte)) then
-          end if
+        elseif (scan_option(options, i, 's', saccess, ssequential)) then
+        elseif (scan_option(options, i, 'd', saccess, sdirect)) then
           call setreclen (irec_len,srec_len,sform,iblock,iword,ibyte)
           if (irec_len .eq. 0) then
             print '(a,a,/,a,a)',
@@ -312,26 +298,26 @@
      &         ' ''direct'' requires a record length',
      &         ' options=',options
             errors = errors + 1
-          end if
-        else if(scan_option(options, i, 'f', sform, sformatted)) then
-        else if(scan_option(options, i, 'u', sform, sunformatted)) then
-        else if(scan_option(options, i, 'rw', saction, sreadwrite)) then
-        else if(scan_option(options, i, 'ro', saction, sread)) then
-        else if(scan_option(options, i, 'wo', saction, swrite)) then
-        else if(scan_option(options, i, 'r', sposition, srewind)) then
-        else if(scan_option(options, i, 'a', sposition, sappend)) then
+          endif
+        elseif (scan_option(options, i, 'f', sform, sformatted)) then
+        elseif (scan_option(options, i, 'u', sform, sunformatted)) then
+        elseif (scan_option(options, i, 'rw', saction, sreadwrite)) then
+        elseif (scan_option(options, i, 'ro', saction, sread)) then
+        elseif (scan_option(options, i, 'wo', saction, swrite)) then
+        elseif (scan_option(options, i, 'r', sposition, srewind)) then
+        elseif (scan_option(options, i, 'a', sposition, sappend)) then
 
 !       scan for size options with no introductory keyword
 !       the introductory keyword must be several options back
 
-        else if(scan_size(options, i, inum, iblock, iword, ibyte)) then
+        elseif (scan_size(options, i, inum, iblock, iword, ibyte)) then
         else
           print '(4a)', '=>ERROR:  Getunit unable to parse options=',
      &                    options(1:i-1), '|',
      &                    options(i:len_trim(options))
           errors = errors + 1
           i = i + 1
-        end if
+        endif
       goto 100
 
 !     end of scan loop
@@ -343,7 +329,7 @@
      &,   'STOP in getunit'
      &,   'There were',errors,' errors scanning the list of I/O options'
         stop
-      end if
+      endif
 
 !     in case neither "formatted" or "unformatted" is specified, choose
 !     the proper default for sequential and direct access files.
@@ -351,10 +337,10 @@
       if (sform .eq. ' ') then
         if (saccess .eq. ssequential) then
           sform = sformatted
-        else if (saccess .eq. sdirect) then
+        elseif (saccess .eq. sdirect) then
           sform = sunformatted
-        end if
-      end if
+        endif
+      endif
 !-----------------------------------------------------------------------
 !     See if the file has previously been opened in this run
 !-----------------------------------------------------------------------
@@ -383,7 +369,7 @@
               call close_file (iounit, filename)
               skip_open = .false.
 
-            end if
+            endif
           else
 
 !           This file is now closed, but had previously been opened.
@@ -398,12 +384,12 @@
 
             if (sposition .eq. sappend) then
               sstatus = sold
-            end if
+            endif
             skip_open = .false.
-          end if
+          endif
           go to 201
-        end if
-      end do
+        endif
+      enddo
 
 !     This file has not previously been opened in this run.
 
@@ -425,10 +411,10 @@
             sposition = srewind
           else
             sstatus = sold
-          end if
+          endif
 
-        end if
-      end if
+        endif
+      endif
       skip_open = .false.
 
 201   continue
@@ -440,7 +426,7 @@
       if (sblocking .eq. 'null') then
         saccess = ssequential
         sform = 'UNFORMATTED'
-      end if
+      endif
 
 !-----------------------------------------------------------------------
 !     select open statement compatible with options and computer platform
@@ -448,7 +434,7 @@
 
       if (skip_open) then
         goto 301
-      end if
+      endif
       if (saccess .eq. ssequential .or. saccess .eq. sappend) then
 
 !       some compilers may allow a record length specifier for
@@ -471,9 +457,9 @@
      &,       POSITION=sposition
      &,       RECL=irec_len
      &        )
-        end if
+        endif
         unix_name(iounit) = .true.
-      else if (saccess .eq. sdirect) then
+      elseif (saccess .eq. sdirect) then
         open (iounit,
      &        FILE=filename,
      &        FORM=sform,
@@ -483,7 +469,7 @@
      &        )
 !        unix_name(iounit) = .true.
         unix_name(iounit) = .false.
-      end if
+      endif
 
 301   continue
 
@@ -497,7 +483,7 @@
 !     closes the file.
 !     see Getunit which gets a Fortran i/o unit number.
 
-!     author c. h. goldberg          e-mail: chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "iomngr.h"
@@ -509,7 +495,7 @@
         if (.not. hide_file(ifn) .and. unix_name(iounit)) then
           call close_file (iounit, fname(ifn))
           iunit(ifn) = 0
-        end if
+        endif
         ifile(iounit) = 0
       else
         print *,'=>ERROR: iounit is bad. iounit=',iounit
@@ -527,7 +513,7 @@
 !     All files except stdin, stdout, and stderr are closed.
 !     Hidden files are closed at this time.
 
-!     Ater a call to release_all, it is safe to execute a sectiion of
+!     After a call to release_all, it is safe to execute a section of
 !     code that does not use the iomngr to allocate units.
 
 !=======================================================================
@@ -551,9 +537,9 @@
 
             inuse(iunit(ifn)) = .false.
             iunit(ifn) = 0
-          end if
-        end if
-      end do
+          endif
+        endif
+      enddo
 
       return
       end
@@ -591,8 +577,8 @@
           write(stdout, '(i4,tr3,l2,tr4,a)')
      &              i, hide_file(ifile(i)),
      &              fname(ifile(i))(1:len_trim(fname(ifile(i))))
-        end if
-      end do
+        endif
+      enddo
 
       return
       end
@@ -614,7 +600,7 @@
         write(stdout, '(i4,tr3,l2,tr4,a)')
      &            i, hide_file(i),
      &              fname(i)(1:len_trim(fname(i)))
-      end do
+      enddo
 
       return
       end
@@ -653,7 +639,7 @@
         call set2byte (irec_len, iblock, iword, ibyte)
       else
         call set2word (irec_len, iblock, iword, ibyte)
-      end if
+      endif
 
       call i2a(irec_len, srec_len)
 
@@ -670,10 +656,10 @@
       if (inum .eq. 0) then
         if (ibyte .ne. 0) then
           inum = ibyte
-        else if (iword .ne. 0) then
+        elseif (iword .ne. 0) then
           inum = 4 * iword
-        end if
-      end if
+        endif
+      endif
 
       return
       end
@@ -688,10 +674,10 @@
       if (inum .eq. 0) then
         if (ibyte .ne. 0) then
           inum = 1 + (ibyte - 1) / 4
-        else if (iword .ne. 0) then
+        elseif (iword .ne. 0) then
           inum = iword
-        end if
-      end if
+        endif
+      endif
 
       return
       end
@@ -711,8 +697,8 @@
         c = string(i:i)
         if ('A' .le. c .and. c .le. 'Z') then
           string(i:i) = char(ichar(c) + lcshift)
-        end if
-      end do
+        endif
+      enddo
 
       return
       end
@@ -727,7 +713,7 @@
       write (string, '(i15)') i
       do j=1,15
         if (string(j:j) .ne. ' ') go to 101
-      end do
+      enddo
 101   continue
       a = string(j:)
 
@@ -755,8 +741,8 @@
         if (c.eq.'=' .or. c.eq.' ' .or. c.eq.',' .or. c.eq.':') then
           i = i + 1
           goto 100
-          end if
-        end if
+          endif
+        endif
 
 !     scan for option
 
@@ -767,8 +753,8 @@
           scan_option = .true.
           svar = soption
           i = i + len_trim(spattern)
-        end if
-      end if
+        endif
+      endif
 
       return
       end
@@ -790,12 +776,12 @@
 
       scan_size = .false.
 
-      if(scan_number(options, i, inum, snum)) then
+      if (scan_number(options, i, inum, snum)) then
         iblock = 0
         iword = 0
         ibyte = 0
         scan_size = .true.
-      else if(scan_option(options, i, 'words', sdummy, sdummy)) then
+      elseif (scan_option(options, i, 'words', sdummy, sdummy)) then
         if (scan_number(options, i, iword, sword)) then
           inum = 0
           iblock = 0
@@ -806,8 +792,8 @@
      &       '=>ERROR in getunit options list:',
      &       ' ''words='' requires a size in words',
      &       ' options=',options
-        end if
-      else if(scan_option(options, i, 'bytes', sdummy, sdummy)) then
+        endif
+      elseif (scan_option(options, i, 'bytes', sdummy, sdummy)) then
         if (scan_number(options, i, ibyte, sbyte)) then
           inum = 0
           iblock = 0
@@ -818,8 +804,8 @@
      &       '=>ERROR in getunit options list:',
      &       ' ''bytes='' requires a size in bytes',
      &       ' options=',options
-        end if
-      end if
+        endif
+      endif
 
       return
       end
@@ -845,8 +831,8 @@
         if (c.eq.'=' .or. c.eq.' ' .or. c.eq.',' .or. c.eq.':') then
           i = i + 1
           goto 100
-        end if
-      end if
+        endif
+      endif
 
 !     scan for digits
 
@@ -864,12 +850,12 @@
               sn = sn(1:len_trim(sn)) // c
               n = 10 * n + ichar(c) - ichar('0')
               goto 200
-            end if
-          end if
+            endif
+          endif
         else
           scan_number = .false.
-        end if
-      end if
+        endif
+      endif
 
       return
       end
