@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/isleperim.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/isleperim.F
       subroutine isleperim (kmt, map, iperm, jperm, iofs, nippts, nisle
      &,                    imt, jmt, km, mnisle, maxipp
      &,                    xu, yu, zw)
@@ -43,8 +43,8 @@
 !                  kmt = array of depths.  (0 for land) (>0 for ocean)
 !          Outputs:
 !                  map = map of land masses and their ocean perimeters
-!                           mid-ocean cells are labeled 0
-!                           land masses are labeled 1, 2, 3, ...,
+!                           mid-ocean cells are labelled 0
+!                           land masses are labelled 1, 2, 3, ...,
 !                           their perimeter ocean cells -1, -2, -3, ...,
 !                  iperm = i coordinates of perimeter points
 !                  jperm = j coordinates of perimeter points
@@ -66,8 +66,7 @@
 !                  yu = latitude (degrees) at "u" points
 !                  zw = depth at bottom of cells
 
-!         author: Charles Goldberg  ==> chg@gfdl.gov
-!         December 1993/revised February 1995
+!     based on code by: C. Goldberg
 !=======================================================================
 
       common /qsize/ maxqsize
@@ -104,7 +103,7 @@
 !-----------------------------------------------------------------------
 !     copy kmt to map changing notation
 !     initially, 0 means ocean and 1 means unassigned land in map
-!     as land masses are found, they are labeled 2, 3, 4, ...,
+!     as land masses are found, they are labelled 2, 3, 4, ...,
 !     and their perimeter ocean cells -2, -3, -4, ...,
 !     when no land points remain unassigned, land mass numbers are
 !     reduced by 1 and their perimeter ocean points relabelled accordingly
@@ -116,10 +115,10 @@
             map(i,j) = ocean
           else
             map(i,j) = land
-          end if
-        end do
+          endif
+        enddo
 
-      end do
+      enddo
 
 !-----------------------------------------------------------------------
 !     find unassigned land points and expand them to continents
@@ -152,12 +151,12 @@
             if (label .gt. mnisle) then
               print '(a,i3,a)','ERROR==> mnisle=',mnisle,' is too small'
               stop '==> expand'
-            end if
+            endif
             iofs(label) = iofs(label-1) + nippts(label-1)
             nippts(label) = 0
-          end if
-        end do
-      end do
+          endif
+        enddo
+      enddo
       nisle = label - 1
 
 !-----------------------------------------------------------------------
@@ -168,19 +167,19 @@
         do j=1,jnorth
           if (map(i,j) .ne. 0) then
             map(i,j) = map(i,j) - sign(1, map(i,j))
-          end if
-        end do
-      end do
+          endif
+        enddo
+      enddo
       do isle=2,nisle
         iofs(isle-1) = iofs(isle)
         nippts(isle-1) = nippts(isle)
-      end do
+      enddo
       nisle = nisle - 1
 
       do j=1,jmt
         map(1,j) = map(imt-1,j)
         map(imt,j) = map(2,j)
-      end do
+      enddo
 
 !      print '(/a)',
 !     &       'The following changes fix "PERIMETER VIOLATIONS"'
@@ -198,7 +197,7 @@
      &, '==>Remapping land masses to see if PERIMETER VIOLATIONS remain'
         print *, ' '
         goto 1
-      end if
+      endif
 
       print *,' Island perimeter statistics:'
       print *,'maximum queue size was ',maxqsize
@@ -236,11 +235,11 @@
           print '(t6,32i5)', (istart+i+4,i=1,iline,5)
           do j=jmt,1,-1
             print '(i4,t6,160i1)', j,(mmm(map(istart+i,j)),i=1,iline)
-          end do
+          enddo
           print '(t6,32i5)', (istart+i+4,i=1,iline,5)
           istart = istart + iline
-        end if
-      end do
+        endif
+      enddo
       print *, ' '
       return
       end
@@ -304,11 +303,11 @@
         print '(a,i4,a)',
      & 'ERROR:  change parameter (mnisle2=',mnisle,') in isleperim.F'
         stop '==>isleperim'
-      end if
+      endif
 
       do isle=1,mnisle
         bridge_to(isle) = .false.
-      end do
+      enddo
 
 !-----------------------------------------------------------------------
 !     main loop:
@@ -327,16 +326,16 @@
         if (i .eq. offmap .or. j .eq. offmap) then
           goto 1000
 
-!       case: map(i,j) is already labeled for this land mass
-        else if (map(i,j) .eq. label) then
+!       case: map(i,j) is already labelled for this land mass
+        elseif (map(i,j) .eq. label) then
           goto 1000
 
 !       case: map(i,j) is an ocean perimeter point of this land mass
-        else if (map(i,j) .eq. -label) then
+        elseif (map(i,j) .eq. -label) then
           goto 1000
 
 !       case: map(i,j) is an unassigned land point
-        else if (map(i,j) .eq. land) then
+        elseif (map(i,j) .eq. land) then
           map(i,j) = label
 !         print *, 'labeling ',i,j,' as ',label
           call qpush (i,         jn(j,jmt), iq, jq, qfront, qback)
@@ -350,7 +349,7 @@
           goto 1000
 
 !       case: map(i,j) is an ocean point adjacent to this land mass
-        else if (map(i,j) .eq. ocean .or. map(i,j) .lt. 0) then
+        elseif (map(i,j) .eq. ocean .or. map(i,j) .lt. 0) then
 
 !         subcase: map(i,j) is a perimeter ocean point of another mass
           if (map(i,j) .lt. 0) then
@@ -373,7 +372,7 @@
               call clear_kmt_options ()
 
 !             OK to set kmt to 0, but don`t change map because that would
-!             require complete relabeling of land masses
+!             require complete relabelling of land masses
 
 !             option 1: fill common perimeter point to make land bridge
 
@@ -393,9 +392,9 @@
      &                kmt(i+i1,j+j1) .eq. 0) then
                     call kmt_option (3, i+i1, j+j1
      &,                              kmt(i+i1,j+j1), kmt(i,j), kmt)
-                  end if
-                end do
-              end do
+                  endif
+                enddo
+              enddo
 
               problem = 'perim'
               call select_option ('perim'
@@ -408,12 +407,12 @@
      &              kmt_changes(n,2) .eq.j .and.
      &              kmt_changes(n,4) .eq.0) then
                   bridge_to(-map(i,j)-1) = .true.
-                end if
-              end do
-            end if
+                endif
+              enddo
+            endif
 
             goto 1000
-          end if
+          endif
 
 !         case: map(i,j) is a ocean point--label it for current mass
           map(i,j) = -label
@@ -423,23 +422,23 @@
           if (iofs(label) + nippts(label) .gt. maxipp) then
             print *, 'ERROR==>  maxipp=',maxipp,' is not large enough'
             stop '==>expand'
-          end if
+          endif
           iperm(iofs(label) + nippts(label)) = i
           jperm(iofs(label) + nippts(label)) = j
           goto 1000
 
-!       case: map(i,j) is probably labeled for another land mass
+!       case: map(i,j) is probably labelled for another land mass
 !       ************* this case should not happen **************
         else
           nerror = nerror + 1
           print '(a,a,i3,a,i3,a,a,i3,a,i3)',
      &          'ERROR ==>  ',
-     &          'map(',i,',',j,') is labeled for both ',
+     &          'map(',i,',',j,') is labelled for both ',
      &          'land masses ', map(i,j)-1,' and ',label-1
-        end if
+        endif
         goto 1000
 
-      end if
+      endif
       return
       end
 
@@ -477,14 +476,14 @@
           do ip=qfront,qback-1
             iq(ip-ishift) = iq(ip)
             jq(ip-ishift) = jq(ip)
-          end do
+          enddo
           qfront = 1
           qback = qback - ishift
         else
           print *, 'queue fault in qpush'
           stop '==>qpush'
-        end if
-      end if
+        endif
+      endif
       iq(qback) = i
       jq(qback) = j
 
@@ -530,7 +529,7 @@
         jn = j + 1
       else
         jn = offmap
-      end if
+      endif
 
       return
       end
@@ -546,7 +545,7 @@
         js = j - 1
       else
         js = offmap
-      end if
+      endif
 
       return
       end
@@ -562,7 +561,7 @@
         ie = i + 1
       else
         ie = (i+1) - imt + 2
-      end if
+      endif
 
       return
       end
@@ -578,7 +577,7 @@
         iw = i - 1
       else
         iw = (i-1) + imt - 2
-      end if
+      endif
 
       return
       end
@@ -599,7 +598,7 @@
         print '(t4,a,/)', '<none>'
       else
         auto_kmt_changes = .true.
-      end if
+      endif
       do n=1,nchanges
         kmt(kmt_changes(n,1), kmt_changes(n,2)) = kmt_changes(n,4)
 !        write (io_del_kmt, '(t7,a4,i4,a1,i4,a,t25,i4)')
@@ -610,7 +609,7 @@
           print '(a)',' Use -Dshow_topog_details to see modifications'
         endif
 
-      end do
+      enddo
       print '(/)'
       nchanges = 0
       return
@@ -628,9 +627,9 @@
         do j_opt=1,len_opt
           do k_opt=1,4
             kmt_opt(i_opt, j_opt, k_opt) = 0
-          end do
-        end do
-      end do
+          enddo
+        enddo
+      enddo
       return
       end
 
@@ -654,9 +653,9 @@
           do n=1,len_opt
             do k_opt=1,4
               kmt_opt(i_opt,n,k_opt) = 0
-            end do
-          end do
-        end if
+            enddo
+          enddo
+        endif
 
 !      enter the change in kmt_opt
 
@@ -664,13 +663,13 @@
        do nn=len_opt,1,-1
           if (kmt_opt(i_opt,nn,1) .eq. 0) then
             j_opt = nn
-          end if
-        end do
+          endif
+        enddo
         kmt_opt(i_opt,j_opt,1) = i
         kmt_opt(i_opt,j_opt,2) = jrow
         kmt_opt(i_opt,j_opt,3) = kmt_old
         kmt_opt(i_opt,j_opt,4) = kmt_new
-      end if
+      endif
       return
       end
 
@@ -697,7 +696,7 @@
         i_opt = idefault
         call accept_option(i_opt, kmt)
 
-      else if (problem .eq. 'bay') then
+      elseif (problem .eq. 'bay') then
 
         idefault = 1
 
@@ -708,7 +707,7 @@
         i_opt = idefault
         call accept_option(i_opt, kmt)
 
-       else if (problem .eq. 'pothole') then
+       elseif (problem .eq. 'pothole') then
 
         idefault = 1
 
@@ -719,7 +718,7 @@
         i_opt = idefault
         call accept_option(i_opt, kmt)
 
-       else if (problem .eq. 'shallow') then
+       elseif (problem .eq. 'shallow') then
 
         idefault = 2
 
@@ -731,14 +730,14 @@
           do j_opt=1,len_opt
             do k_opt=1,4
               kmt_opt(i_opt,j_opt,k_opt) = 0
-            end do
-          end do
+            enddo
+          enddo
           idefault = 2
         endif
 
         i_opt = idefault
         call accept_option(i_opt, kmt)
-      end if
+      endif
 
       return
       end
@@ -768,15 +767,15 @@
      &,           'To avoid this message, '
      &,          'increase max_change = ', max_change,' in isleperim.h'
             call enter_kmt_changes()
-          end if
+          endif
           nchanges = nchanges + 1
           do jch=1,4
             kmt_changes(nchanges,jch) = kmt_opt(i_opt, j_opt, jch)
-          end do
+          enddo
           kmt(kmt_changes(nchanges,1), kmt_changes(nchanges,2)) =
      &      kmt_changes(nchanges,4)
-        end if
-      end do
+        endif
+      enddo
 
       return
       end
