@@ -1,5 +1,5 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/isleperim.h
-!====================== include file "isleperim.h" =====================
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/isleperim.h
+!===================== include file "isleperim.h" ======================
 
 !                      topography changes
 
