@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/levind.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/levind.h
 !====================== include file "levind.h" ========================
 
 !     vertical level indicators which define model geometry & bottom
