@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/mom.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/mom.F
       subroutine mom
 
 !=======================================================================
@@ -406,10 +406,16 @@
 !-----------------------------------------------------------------------
 
       if (restrt) then
-        fname = new_file_name (file_stamp ("restart_mom",stamp,".nc"))
-        if (restts) call mom_rest_out (fname, 1, imt, 1, jmt)
-        fname = new_file_name ("restart_mom.nc")
-        if (eorun) call mom_rest_out (fname, 1, imt, 1, jmt)
+        if (restts) then
+          call def_rest (0)
+          call def_rest_mom (0, fname)
+          call mom_rest_out (fname, 1, imt, 1, jmt)
+        endif
+        if (eorun) then
+          call def_rest (1)
+          call def_rest_mom (1, fname)
+          call mom_rest_out (fname, 1, imt, 1, jmt)
+        endif
       endif
 
 !-----------------------------------------------------------------------
