@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/mtlm/mtlm_rest.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mtlm/mtlm_rest.F
       subroutine mtlm_rest_in (fname, ids, ide, jds, jde)
 !=======================================================================
 !     input routine for land restarts
@@ -14,16 +14,6 @@
 !     fname              = file name
 !     ids, ide ...       = start and end index for data domain
 
-!   local variables
-!     ils, ile, jls, jle = local domain start and end indicies
-!     it                 = t grid axis definitions (x,y,t default)
-!     iu                 = u grid axis definitions (x,y,t default)
-!     is                 = start for write on each axis (x,y,t default)
-!     ic                 = count for write on each axis (x,y,t default)
-!     id_...             = id's for axis (used for it, iu or defvar)
-!     iou                = io unit (ncid)
-!     ln                 = length of data to be written
-
 !     based on code by: M. Eby
 !=======================================================================
 
@@ -33,21 +23,21 @@
       include "coord.h"
       include "grdvar.h"
       include "csbc.h"
+      include "levind.h"
       include "tmngr.h"
       include "switch.h"
       include "mtlm.h"
 
       character(*) :: fname
-      character(120) :: name, new_file_name
       character(3) :: a3
 
-      integer i, iou, j, ln, n, ntrec, ids, ide, jds, jde, ig
-      integer ils, ile, jls, jle, ib(10), ic(10), it(10)
-      integer iu(10), id_time, id_xt, id_xu, id_yt, id_yu, id_xt_e
-      integer id_xu_e, id_yt_e, id_yu_e, undef
+      integer i, iou, j, k, ln, n, ntrec, ids, ide, jds, jde, ils, ile
+      integer jls, jle, ib(10), ic(10), undef, L, mskl(imt,jmt)
+      integer mskt(imt,jmt)
       integer nyear, nmonth, nday, nhour, nmin, nsec
 
-      real xt_e(imt+1), xu_e(imt+1), yt_e(jmt+1), yu_e(jmt+1)
+      logical exists, inqvardef
+
       real data(imt,jmt), tmp, c0, c1
       real, allocatable :: tmpij(:,:)
 
@@ -58,8 +48,7 @@
 !-----------------------------------------------------------------------
 !     open file
 !-----------------------------------------------------------------------
-      name = new_file_name (fname)
-      call openfile (name, iou)
+      call openfile (fname, iou)
       ntrec = 1
 
 !-----------------------------------------------------------------------
@@ -71,6 +60,20 @@
       jle = min(jde,jmt)
 
       allocate ( tmpij(ils:ile,jls:jle) )
+      L = 0
+!     mskl is the map of current maximum possible land points
+      mskl(:,:) = 0
+!     mskt is the map of current maximum possible land points in restart
+      mskt(:,:) = 0
+      do j=2,jmt-1
+        do i=2,imt-1
+          if (kmt(i,j) .le. klmax) then
+            L = L + 1
+            mskl(i,j) = L
+          endif
+          if (kmt(i,j) .le. 0) mskt(i,j) = L
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     read 1d data (t)
@@ -141,79 +144,100 @@
       ic(3) = 1
       ln = ic(1)*ic(2)*ic(3)
 
+      tmpij(ils:ile,jls:jle) = mskt(ils:ile,jls:jle)
+      call getvara ('mskl', iou, ln, ib, ic, tmpij, c1, c0)
+      mskt(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+
       tmpij(ils:ile,jls:jle) = land_map(ils:ile,jls:jle)
       call getvara ('land_map', iou, ln, ib, ic, tmpij, c1, c0)
       land_map(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
 
-      call loadland (POINTS, TSOIL, imt, jmt, land_map, data)
+      call unloadland (POINTS, TSOIL, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('TSOIL', iou, ln, ib, ic, tmpij, c1, c0)
       data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, TSOIL, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, TSOIL, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, LYING_SNOW, imt, jmt, land_map, data)
+      call unloadland (POINTS, LYING_SNOW, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('LYING_SNOW', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, LYING_SNOW, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, LYING_SNOW, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, TS1, imt, jmt, land_map, data)
+      call unloadland (POINTS, TS1, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('TS1', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, TS1, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, TS1, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, CS, imt, jmt, land_map, data)
+      call unloadland (POINTS, CS, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('CS', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, CS, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, CS, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, CV, imt, jmt, land_map, data)
+      call unloadland (POINTS, CV, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('CV', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, CV, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, CV, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, VEG_FRAC, imt, jmt, land_map, data)
+      call unloadland (POINTS, VEG_FRAC, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('VEG_FRAC', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, VEG_FRAC, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, VEG_FRAC, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, FRAC_VS, imt, jmt, land_map, data)
+      call unloadland (POINTS, FRAC_VS, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('FRAC_VS', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, FRAC_VS, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, FRAC_VS, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, M, imt, jmt, land_map, data)
+      call unloadland (POINTS, M, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('M', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, M, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, M, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, MNEG, imt, jmt, land_map, data)
+      call unloadland (POINTS, MNEG, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('MNEG', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, MNEG, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, MNEG, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, FSMC, imt, jmt, land_map, data)
+      call unloadland (POINTS, FSMC, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('FSMC', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, FSMC, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, FSMC, imt, jmt, mskl, data)
 
-      call unloadland (POINTS, RESP_S_DR, imt, jmt, land_map, data)
+      call unloadland (POINTS, RESP_S_DR, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call getvara ('RESP_S_DR', iou, ln, ib, ic, tmpij, c1, c0)
-      data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-      call loadland (POINTS, RESP_S_DR, imt, jmt, land_map, data)
+      where (mskt(ils:ile,jls:jle) .ne. 0)
+     &  data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+      call loadland (POINTS, RESP_S_DR, imt, jmt, mskl, data)
 
-      tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,icalb)
-      call getvara ('sbc_calb', iou, ln, ib, ic, tmpij, c1, c0)
-      sbc(ils:ile,jls:jle,icalb) = tmpij(ils:ile,jls:jle)
+      tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,isca)
+      call getvara ('sbc_sca', iou, ln, ib, ic, tmpij, c1, c0)
+!     only use land points so other values can be changed
+      do j=jls,jle
+        do i=ils,ile
+          if (mskl(i,j) .gt. 0) sbc(i,j,isca) = tmpij(i,j)
+        enddo
+      enddo
 
       tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,ilwr)
       call getvara ('sbc_lwr', iou, ln, ib, ic, tmpij, c1, c0)
@@ -240,95 +264,107 @@
         if (n .lt. 100) write(a3, '(i2)') n
         if (n .lt. 10) write(a3, '(i1)') n
 
-        call unloadland (POINTS, TSTAR(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, TSTAR(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('TSTAR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, TSTAR(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, TSTAR(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, ALBSNF(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, ALBSNF(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('ALBSNF_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, ALBSNF(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, ALBSNF(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, ALBSNC(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, ALBSNC(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('ALBSNC_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, ALBSNC(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, ALBSNC(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, HT(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, HT(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('HT_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, HT(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, HT(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, LAI(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, LAI(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('LAI_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, LAI(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, LAI(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, C_VEG(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, C_VEG(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('CVEG_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, C_VEG(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, C_VEG(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, land_map
+        call unloadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('G_LEAF_PHEN_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, land_map
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, mskl
      &,   data)
 
-        call unloadland (POINTS, G_LEAF_DR(1,n), imt, jmt, land_map
+        call unloadland (POINTS, G_LEAF_DR(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('G_LEAF_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, G_LEAF_DR(1,n), imt, jmt, land_map
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, G_LEAF_DR(1,n), imt, jmt, mskl
      &,   data)
 
-        call unloadland (POINTS, NPP_DR(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, NPP_DR(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('NPP_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, NPP_DR(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, NPP_DR(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, RESP_W_DR(1,n), imt, jmt, land_map
+        call unloadland (POINTS, RESP_W_DR(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('RESP_W_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, RESP_W_DR(1,n), imt, jmt, land_map
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, RESP_W_DR(1,n), imt, jmt, mskl
      &,   data)
 
-        call unloadland (POINTS, CATCH(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, CATCH(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('CATCH_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, CATCH(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, CATCH(1,n), imt, jmt, mskl, data)
 
-        call unloadland (POINTS, Z0(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, Z0(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('Z0_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, Z0(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, Z0(1,n), imt, jmt, mskl, data)
 
        enddo
 
@@ -337,12 +373,13 @@
         if (n .lt. 100) write(a3, '(i2)') n
         if (n .lt. 10) write(a3, '(i1)') n
 
-        call unloadland (POINTS, FRAC(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, FRAC(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call getvara ('FRAC_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
-        data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
-        call loadland (POINTS, FRAC(1,n), imt, jmt, land_map, data)
+        where (mskt(ils:ile,jls:jle) .ne. 0)
+     &    data(ils:ile,jls:jle) = tmpij(ils:ile,jls:jle)
+        call loadland (POINTS, FRAC(1,n), imt, jmt, mskl, data)
 
        enddo
 !-----------------------------------------------------------------------
@@ -357,32 +394,12 @@
       return
       end
 
-      subroutine mtlm_rest_out (fname, ids, ide, jds, jde)
+      subroutine mtlm_rest_def (fname)
 !=======================================================================
-!     output routine for land restarts
-
-!     data may be sized differently in x and y from the global fields.
-!     fields may be written with or without a time dimension. data
-!     should be defined with the routine defvar and written with putvar.
-!     if no time dimension, then data is only written once per file.
-!     make sure the it, iu, ib, and ic arrays and are defining the
-!     correct dimensions. ln may also need to be recalculated.
+!     definition routine for land restarts
 
 !   inputs:
-!     fname              = file name
-!     ids, ide ...       = start and end index for data domain
-
-!   local variables
-!     igs, ige, jgs, jge = global write domain start and end indicies
-!     ig, jg             = global write domain size
-!     ils, ile, jls, jle = local domain start and end indicies
-!     it                 = t grid axis definitions (x,y,t default)
-!     iu                 = u grid axis definitions (x,y,t default)
-!     is                 = start for write on each axis (x,y,t default)
-!     ic                 = count for write on each axis (x,y,t default)
-!     id_...             = id's for axis (used for it, iu or defvar)
-!     iou                = io unit (ncid)
-!     ln                 = length of data to be written
+!     fname = file name
 
 !     based on code by: M. Eby
 !=======================================================================
@@ -390,43 +407,28 @@
       implicit none
 
       include "size.h"
-      include "coord.h"
-      include "grdvar.h"
-      include "csbc.h"
-      include "tmngr.h"
-      include "switch.h"
-      include "mtlm.h"
       include "iounit.h"
+      include "tmngr.h"
 
       character(*) :: fname
-      character(120) :: name, new_file_name, title
       character(3) :: a3
       character(32) :: lstamp
 
-      integer i, iou, j, ln, n, ntrec, ids, ide, jds, jde, igs, ige, ig
-      integer jgs, jge, jg, ils, ile, jls, jle, ib(10), ic(10), it(10)
-      integer iu(10), id_time, id_xt, id_xu, id_yt, id_yu, id_xt_e
-      integer id_xu_e, id_yt_e, id_yu_e
-      integer nyear, nmonth, nday, nhour, nmin, nsec
-      integer L
+      integer i, iou, j, ln, n, ntrec, igs, ige, ig, jgs, jge, jg
+      integer it(10), iu(10), id_time, id_xt, id_xu, id_yt, id_yu
+      integer id_xt_e, id_xu_e, id_yt_e, id_yu_e
 
-      real xt_e(imt+1), xu_e(imt+1), yt_e(jmt+1), yu_e(jmt+1)
-      real data(imt,jmt), tmp, c0, c1, c1e5, c1e20
-      real, allocatable :: tmpij(:,:)
-      real, allocatable :: tmpi(:), tmpj(:)
-      real, allocatable :: tmpie(:), tmpje(:)
+      real c0, c1, c1e5, c1e20
 
       c0 = 0.
       c1 = 1.
       c1e5 = 1.e5
       c1e20 = 1.e20
-      lstamp = stamp
 
 !-----------------------------------------------------------------------
 !     open file
 !-----------------------------------------------------------------------
-      name = new_file_name (fname)
-      call openfile (name, iou)
+      call openfile (fname, iou)
       ntrec = 1
 
 !-----------------------------------------------------------------------
@@ -445,10 +447,12 @@
       call redef (iou)
 
 !-----------------------------------------------------------------------
-!     set global attributes
+!     write global attributes
 !-----------------------------------------------------------------------
-      title = 'Restart'
-      call putglobal (iou, name, title, expnam, timunit)
+      call putatttext (iou, 'global', 'Conventions', 'CF-1.0')
+      call putatttext (iou, 'global', 'experiment_name', expnam)
+      call putatttext (iou, 'global', 'run_stamp', runstamp)
+      call putatttext (iou, 'global', 'time_unit', timunit)
 
 !-----------------------------------------------------------------------
 !     define dimensions
@@ -467,6 +471,8 @@
 !       define 1d data (t)
 !-----------------------------------------------------------------------
       it(:) = id_time
+      call defvar ('time', iou, 1, it, c0, c0, 'T', 'D'
+     &, 'time since initial condition', 'time', trim(timunit))
       call defvar ('POINTS', iou, 1, it, c0, c0, ' ', 'D'
      &, 'POINTS', ' ',' ')
       call defvar ('atlnd', iou, 1, it, c0, c0, ' ', 'D'
@@ -532,6 +538,9 @@
       it(3) = id_time
       iu(3) = id_time
 
+      call defvar ('mskl', iou , 3, it, c0, c1e5, ' ', 'I'
+     &, 'mskl', ' ', ' ')
+
       call defvar ('land_map', iou , 3, it, c0, c1e5, ' ', 'I'
      &, 'land_map', ' ', ' ')
 
@@ -568,8 +577,8 @@
       call defvar ('MNEG', iou , 3, it, -c1e20, c1e20, ' ', 'D'
      &, 'MNEG', ' ', ' ')
 
-      call defvar ('sbc_calb', iou , 3, it, -c1e20, c1e20, ' ', 'D'
-     &, 'sbc_calb', ' ', ' ')
+      call defvar ('sbc_sca', iou , 3, it, -c1e20, c1e20, ' ', 'D'
+     &, 'sbc_sca', ' ', ' ')
 
       call defvar ('sbc_lwr', iou , 3, it, -c1e20, c1e20, ' ', 'D'
      &, 'sbc_lwr', ' ', ' ')
@@ -641,6 +650,79 @@
 
       call enddef (iou)
 
+!-----------------------------------------------------------------------
+!     close the file
+!-----------------------------------------------------------------------
+      call closefile (iou)
+
+      return
+      end
+
+      subroutine mtlm_rest_out (fname, ids, ide, jds, jde)
+!=======================================================================
+!     output routine for land restarts
+
+!     data may be sized differently in x and y from the global fields.
+!     fields may be written with or without a time dimension. data
+!     should be defined with the routine defvar and written with putvar.
+!     if no time dimension, then data is only written once per file.
+!     make sure the it, iu, ib, and ic arrays and are defining the
+!     correct dimensions. ln may also need to be recalculated.
+
+!   inputs:
+!     fname              = file name
+!     ids, ide ...       = start and end index for data domain
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include "size.h"
+      include "coord.h"
+      include "grdvar.h"
+      include "csbc.h"
+      include "levind.h"
+      include "tmngr.h"
+      include "switch.h"
+      include "mtlm.h"
+      include "iounit.h"
+
+      character(*) :: fname
+      character(3) :: a3
+      character(32) :: lstamp
+
+      integer i, iou, j, k, ln, n, ntrec, ids, ide, jds, jde, igs, ige
+      integer ig, jgs, jge, jg, ils, ile, jls, jle, ib(10), ic(10), L
+      integer mskl(imt,jmt)
+      integer nyear, nmonth, nday, nhour, nmin, nsec
+
+      real xt_e(imt+1), xu_e(imt+1), yt_e(jmt+1), yu_e(jmt+1)
+      real data(imt,jmt), tmp, c0, c1
+      real, allocatable :: tmpij(:,:)
+      real, allocatable :: tmpi(:), tmpj(:)
+      real, allocatable :: tmpie(:), tmpje(:)
+
+      c0 = 0.
+      c1 = 1.
+      lstamp = stamp
+
+!-----------------------------------------------------------------------
+!     open file
+!-----------------------------------------------------------------------
+      call openfile (fname, iou)
+      ntrec = 1
+
+!-----------------------------------------------------------------------
+!     set global write domain size
+!-----------------------------------------------------------------------
+      igs = 1
+      ige = imt
+      ig  = ige-igs+1
+      jgs = 1
+      jge = jmt
+      jg  = jge-jgs+1
+
 !-----------------------------------------------------------------------
 !     local domain size (minimum of data domain and global write domain)
 !-----------------------------------------------------------------------
@@ -649,11 +731,21 @@
       jls = max(jds,jgs)
       jle = min(jde,jge)
 
-      allocate ( tmpij(igs:ige,jgs:jge) )
-      allocate ( tmpi(igs:ige) )
-      allocate ( tmpj(jgs:jge) )
-      allocate ( tmpie(igs:ige+1) )
-      allocate ( tmpje(jgs:jge+1) )
+      allocate ( tmpij(ils:ile,jls:jle) )
+      allocate ( tmpi(ils:ile) )
+      allocate ( tmpj(jls:jle) )
+      allocate ( tmpie(ils:ile+1) )
+      allocate ( tmpje(jls:jle+1) )
+      L = 0
+      mskl(:,:) = 0
+      do j=2,jmt-1
+        do i=2,imt-1
+          if (kmt(i,j) .le. klmax) then
+            L = L + 1
+            mskl(i,j) = L
+          endif
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     write 1d data (t)
@@ -743,55 +835,58 @@
       ic(3) = 1
       ln = ic(1)*ic(2)*ic(3)
 
+      tmpij(ils:ile,jls:jle) = mskl(ils:ile,jls:jle)
+      call putvara ('mskl', iou, ln, ib, ic, tmpij, c1, c0)
+
       tmpij(ils:ile,jls:jle) = land_map(ils:ile,jls:jle)
       call putvara ('land_map', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, TSOIL, imt, jmt, land_map, data)
+      call unloadland (POINTS, TSOIL, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('TSOIL', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, LYING_SNOW, imt, jmt, land_map, data)
+      call unloadland (POINTS, LYING_SNOW, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('LYING_SNOW', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, TS1, imt, jmt, land_map, data)
+      call unloadland (POINTS, TS1, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('TS1', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, CS, imt, jmt, land_map, data)
+      call unloadland (POINTS, CS, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('CS', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, CV, imt, jmt, land_map, data)
+      call unloadland (POINTS, CV, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('CV', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, VEG_FRAC, imt, jmt, land_map, data)
+      call unloadland (POINTS, VEG_FRAC, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('VEG_FRAC', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, FRAC_VS, imt, jmt, land_map, data)
+      call unloadland (POINTS, FRAC_VS, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('FRAC_VS', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, M, imt, jmt, land_map, data)
+      call unloadland (POINTS, M, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('M', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, FSMC, imt, jmt, land_map, data)
+      call unloadland (POINTS, FSMC, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('FSMC', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, RESP_S_DR, imt, jmt, land_map, data)
+      call unloadland (POINTS, RESP_S_DR, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('RESP_S_DR', iou, ln, ib, ic, tmpij, c1, c0)
 
-      call unloadland (POINTS, MNEG, imt, jmt, land_map, data)
+      call unloadland (POINTS, MNEG, imt, jmt, mskl, data)
       tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
       call putvara ('MNEG', iou, ln, ib, ic, tmpij, c1, c0)
 
-      tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,icalb)
-      call putvara ('sbc_calb', iou, ln, ib, ic, tmpij, c1, c0)
+      tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,isca)
+      call putvara ('sbc_sca', iou, ln, ib, ic, tmpij, c1, c0)
 
       tmpij(ils:ile,jls:jle) = sbc(ils:ile,jls:jle,ilwr)
       call putvara ('sbc_lwr', iou, ln, ib, ic, tmpij, c1, c0)
@@ -813,65 +908,65 @@
         if (n .lt. 100) write(a3, '(i2)') n
         if (n .lt. 10) write(a3, '(i1)') n
 
-        call unloadland (POINTS, TSTAR(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, TSTAR(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('TSTAR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, ALBSNF(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, ALBSNF(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('ALBSNF_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, ALBSNC(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, ALBSNC(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('ALBSNC_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, HT(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, HT(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('HT_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, LAI(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, LAI(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('LAI_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, C_VEG(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, C_VEG(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('CVEG_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, land_map
+        call unloadland (POINTS, G_LEAF_PHEN(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('G_LEAF_PHEN_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, G_LEAF_DR(1,n), imt, jmt, land_map
+        call unloadland (POINTS, G_LEAF_DR(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('G_LEAF_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, NPP_DR(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, NPP_DR(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('NPP_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, RESP_W_DR(1,n), imt, jmt, land_map
+        call unloadland (POINTS, RESP_W_DR(1,n), imt, jmt, mskl
      &,   data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('RESP_W_DR_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, CATCH(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, CATCH(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('CATCH_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
 
-        call unloadland (POINTS, Z0(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, Z0(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('Z0_'//trim(a3), iou, ln, ib, ic, tmpij, c1, c0)
 
@@ -882,7 +977,7 @@
         if (n .lt. 100) write(a3, '(i2)') n
         if (n .lt. 10) write(a3, '(i1)') n
 
-        call unloadland (POINTS, FRAC(1,n), imt, jmt, land_map, data)
+        call unloadland (POINTS, FRAC(1,n), imt, jmt, mskl, data)
         tmpij(ils:ile,jls:jle) = data(ils:ile,jls:jle)
         call putvara ('FRAC_'//trim(a3), iou, ln, ib, ic, tmpij
      &,   c1, c0)
