@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/ndcon.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/ndcon.h
 !====================== include file "ndcon.h" ========================
 
 !     various non dimensional quantities:
