@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/pconst.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/pconst.h
 !====================== include file "pconst.h" ========================
 
 !     rules for parameter constants
