@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/embm/rivmodel.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/embm/rivmodel.F
       subroutine rivmodel
 
 !=======================================================================
@@ -13,6 +13,7 @@
       include "param.h"
       include "csbc.h"
       include "riv.h"
+      include "atm.h"
       include "cembm.h"
       include "grdvar.h"
 
@@ -41,10 +42,12 @@
         do i=2,imtm1
           n = ndis(i,j)
           if (n .ne. 0) then
+            disch(i,j) = psum(n)*wdar(i,j)
             sbc(i,j,isflx) = sbc(i,j,isflx) -socn*psum(n)*wdar(i,j)
           endif
         enddo
       enddo
+      call setbcx (sbc(1,1,isflx), imt, jmt)
 
       return
       end
@@ -186,7 +189,7 @@
 
       nriv(:,:) = nrfill(:,:)
 
-      call basin_perimiter
+      call basin_perimeter
 
 !     check each basin has discharge
       done = .true.
@@ -205,7 +208,7 @@
           enddo
         enddo
         call expand_basins
-        call basin_perimiter
+        call basin_perimeter
       endif
 
 !     find total specified weight for discharge points for each basin
@@ -236,10 +239,12 @@
 !     calculate normalized weight over area for all discharge points
       do j=2,jmtm1
         do i=2,imtm1
-          if (ndis(i,j) .ne. 0) then
-            n = ndis(i,j)
-            if (wt(n)*dxt(i)*cst(j)*dyt(j) .eq. 0.) stop 'rivmodel wt'
-            wdar(i,j) = (wdar(i,j) + wp(n))/(wt(n)*dxt(i)*cst(j)*dyt(j))
+          n = ndis(i,j)
+          if (n .ne. 0) then
+            if (nbp(n) .ne. 0) then
+              if (wt(n)*dxt(i)*cst(j)*dyt(j) .eq. 0.) stop 'rivmodel wt'
+              wdar(i,j) = (wdar(i,j)+wp(n))/(wt(n)*dxt(i)*cst(j)*dyt(j))
+            endif
           endif
         enddo
       enddo
@@ -247,10 +252,10 @@
       return
       end
 
-      subroutine basin_perimiter
+      subroutine basin_perimeter
 
 !=======================================================================
-!     sets basin perimiters
+!     sets basin perimeters
 
 !     based on code by: E. C. Wiebe and M. Eby
 !=======================================================================
@@ -272,20 +277,21 @@
       do j=2,jmtm1
         do i=2,imtm1
           if (nriv(i,j) .gt. nb) nb = nriv(i,j)
-          if (nb .gt. maxnb) stop "basin_perimiter maxnb"
+          if (nb .gt. maxnb) stop "basin_perimeter maxnb"
           if (tmsk(i,j) .ge. 0.5) then
             if (ndis(i,j) .ne. 0) then
               ndp(ndis(i,j)) = ndp(ndis(i,j)) + 1
             elseif (tmsk(i-1,j+1) .lt. 0.5 .or. tmsk(i,j+1) .lt. 0.5
      &        .or. tmsk(i+1,j+1) .lt. 0.5 .or. tmsk(i-1,j) .lt. 0.5
      &        .or. tmsk(i+1,j) .lt. 0.5 .or. tmsk(i-1,j-1) .lt. 0.5
-     &        .or. tmsk(i-1,j) .lt. 0.5 .or. tmsk(i-1,j+1) .lt. 0.5)
+     &        .or. tmsk(i,j-1) .lt. 0.5 .or. tmsk(i+1,j-1) .lt. 0.5)
      &        then
               ndis(i,j) = nriv(i,j)
               ndp(ndis(i,j)) = ndp(ndis(i,j)) + 1
             endif
             nriv(i,j) = 0
           else
+            if (nriv(i,j) .eq. 0) stop "basin_perimeter zero nriv"
             nbp(nriv(i,j)) = nbp(nriv(i,j)) + 1
             ndis(i,j) = 0
           endif
