@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/embm/setembm.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/embm/setembm.F
       subroutine setembm
 
 !=======================================================================
@@ -29,7 +29,6 @@
       include "csbc.h"
       include "scalar.h"
       include "veg.h"
-
       real rveg(imt,jmt)
 
       character(120) :: fname, new_file_name
@@ -40,15 +39,18 @@
 
       logical exists, inqvardef
 
-      real dlam, dphi, dtatms, dte, dyz, eccice, grarea, rhair, saltmax
+      real dlam, dphi, dtatms, dte, dyz, eccice, grarea, saltmax
       real si, ssh, t1, tair, yz_max, yz_min, wz, calday
       real zrel, C2K, c100
+      real dmsk(imt,jmt)
 
       namelist /tsteps/ dtts, dtuv, dtsf, dtatm, dtatms, namix, segtim
-      namelist /co2/    co2ccn, co2yri, co2yrf, co2rate, co2for, co2_yr
+      namelist /embm/   rlapse, rfactor, scatter, rhmax
+      namelist /carbon/ co2ccn, co2yri, co2yrf, co2rate, co2for, co2_yr
+     &,                 c14_yr, dc14ccn, c14prod
       namelist /paleo/  orbit_yr, pyear, eccen, obliq, mvelp
       namelist /ice/    niats, nivts, dampice, tsno, hsno_max, ice_yr
-      namelist /adv_q/  diffactor
+     &,                  ice_calb, sno_calb
       namelist /veg/    veg_alb, veg_rl, veg_rs, veg_smd, crops_yr
      &,                 icrops, idesert, iice
       namelist /solar/  solarconst, solar_yr
@@ -65,13 +67,22 @@
 !     define default parameters
 !-----------------------------------------------------------------------
 
-!     set defaults namelist co2
-      co2ccn     = 350
+!     set defaults namelist embm
+      rlapse     = 5.e-5
+      rfactor    = 0.2
+      scatter    = 0.23
+      rhmax      = 0.85
+
+!     set defaults namelist carbon
+      co2ccn     = 280
       co2yri     = 1.e20
       co2yrf     = 1.e20
       co2rate    = 0.
-      co2for     = 5.77e03
+      co2for     = 5.35e03
       co2_yr     = 2.e20
+      c14_yr     = 2.e20
+      dc14ccn    = 0.
+      c14prod    = 0.
 
 !     set defaults namelist paleo
       pyear      = 2.e20
@@ -85,21 +96,18 @@
       niats      = 1
       nivts      = 1
       dampice    = 5.
-      tsno       = -5.
+      tsno       = 0.
       hsno_max   = 1000.
 
       ice_yr     = 2.e20
-
-!     set defaults namelist adv_q
-      diffactor  = 50.
+      ice_calb   = 0.35
+      sno_calb   = 0.25
 
 !     set defaults namelist veg
-      veg_alb(1:4) = (/0.134054, 0.108081, 0.174938, 0.169483/)
-      veg_alb(5:7) = (/0.199028, 0.282249, 0.142956/)
-      veg_rl(1:4) = (/2.85857, 0.907664, 0.108264, 0.0529845/)
-      veg_rl(5:7) = (/0.0394621, 0.0389969, 0.0200000/)
+      veg_alb(1:7) = (/0.17, 0.17, 0.22, 0.22, 0.22, 0.30, 0.60/)
+      veg_rl(1:7) = (/2.9, 0.91, 0.11, 0.053, 0.039, 0.039, 0.020/)
       veg_rs(1:7) = (/0.75, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0/)
-      veg_smd(1:7) = (/10.0, 10.0, 1.0, 0.1, 0.1, 0.01, 0.01/)
+      veg_smd(1:7) = (/2.0, 3.0, 0.1, 0.1, 0.5, 0.01, 0.01/)
       crops_yr = 2.e20
       icrops = 3
       idesert = 6
@@ -110,44 +118,50 @@
       solar_yr = 2.e20
 
 !     set other stuff
-      scatter    = 0.30
-      pass       = 1. - scatter
+      cdatm     = 1.e-3
+      cpatm     = 1.004e7
+      sht       = 8.4e5
+      shq       = 1.8e5
+      shc       = 7.9e5
+      rhoatm    = 1.250e-3
+      esatm     = 4.6e-05
+      pcfactor  = 0.
+      cssh      = 3.8011e-3
+      cfc11ccnn = 0.
+      cfc11ccns = 0.
+      cfc12ccnn = 0.
+      cfc12ccns = 0.
+      dc14ccnn  = 0.
+      dc14ccne  = 0.
+      dc14ccns  = 0.
 
-      cdatm      = 1.e-3
-      cpatm      = 1.004e7
-      sht        = 8.4e5
-      shq        = 1.8e5
-      shc        = 7.9e5
-      rhoatm     = 1.250e-3
-      esatm      = 4.7e-05
-      rlapse     = 6.e-5
-      rfactor    = 0.05
-      pcfactor   = 0.
-      cssh       = 3.8011e-3
+      rhoocn    = 1.035
+      esocn     = 5.4e-5
+      vlocn     = 2.501e10
 
-      rhoocn     = 1.035
-      esocn      = 5.347e-5
-      vlocn      = 2.501e10
-      socn       = 34.9e-3
+      cdice     = 5.5e-3
+      rhoice    = 0.913
+      rhosno    = 0.330
+      esice     = 5.347e-5
+      slice     = 2.835e10
+      flice     = 3.34e9
+      condice   = 2.1656e5
 
-      cdice      = 5.5e-3
-      rhoice     = 0.913
-      rhosno     = 0.330
-      esice      = 5.347e-5
-      slice      = 2.835e10
-      flice      = 3.34e9
-      condice    = 2.1656e5
+      soilmax   = 15.
+      eslnd     = 5.347e-5
+      cs_alb    = 0.08
 
-      soilmax    = 15.
-      eslnd      = 5.347e-5
-      cs_alb     = 0.08
-      ice_calb   = 0.4
-      sno_calb   = 0.4
+      nivc      = 1
+      dtatms    = 1800.
+      ns        = 30
 
-      nivc       = 1
-      dtatms     = 1800.
-      ns         = 30
+      dalt_v    = 3.3e-3
+      dalt_o    = 1.4e-3
+      dalt_i    = 1.4e-3
 
+!-----------------------------------------------------------------------
+!     read namelist files
+!-----------------------------------------------------------------------
       call getunit (iou, 'control.in', 'f s r')
       read  (iou, tsteps, end=100)
 100   continue
@@ -155,9 +169,15 @@
       call relunit (iou)
 
       call getunit (iou, 'control.in', 'f s r')
-      read  (iou, co2, end=102)
+      read  (iou, embm, end=101)
+101   continue
+      write (stdout,embm)
+      call relunit (iou)
+
+      call getunit (iou, 'control.in', 'f s r')
+      read  (iou, carbon, end=102)
 102   continue
-      write (stdout,co2)
+      write (stdout,carbon)
       call relunit (iou)
       co2ccni = co2ccn
 
@@ -174,24 +194,28 @@
       call relunit (iou)
 
       call getunit (iou, 'control.in', 'f s r')
-      read  (iou, adv_q, end=105)
+      read  (iou, veg, end=105)
 105   continue
-      write (stdout,adv_q)
-      call relunit (iou)
-
-      call getunit (iou, 'control.in', 'f s r')
-      read  (iou, veg, end=106)
-106   continue
       write (stdout,veg)
       call relunit (iou)
 
+      call getunit (iou, 'control.in', 'f s r')
+      read  (iou, solar, end=106)
+106   continue
+      write (stdout,solar)
+      call relunit (iou)
+
+!     ensure pass is between zero and one.
+      pass =  min(max((1. - scatter), 0.), 1.)
+
 !     sort out forcing years
-      if (pyear  .gt. 1.e20) pyear = 2000.
+      if (pyear  .gt. 1.e20) pyear = 1850.
+      if (co2_yr .gt. 1.e20) co2_yr = pyear
+      if (c14_yr .gt. 1.e20) c14_yr = pyear
       if (orbit_yr .gt. 1.e20) orbit_yr = pyear
       if (crops_yr .gt. 1.e20) crops_yr = pyear
       if (ice_yr .gt. 1.e20) ice_yr = pyear
       if (solar_yr .gt. 1.e20) solar_yr = pyear
-      if (co2_yr .gt. 1.e20) co2_yr = pyear
 
       if (mod(timavgint, segtim) .gt. 1.e-6 .and. timavgint .gt. 0.)
      &  then
@@ -229,22 +253,20 @@
      &  '==> Time averages will be written every ', timavgint, ' days, '
      &, '    with an averaging period of         ', timavgper, ' days. '
 
-!-----------------------------------------------------------------------
-!     calculate the relative CO2 forcing term
-!-----------------------------------------------------------------------
-
-      call co2forc
-
-      write(stdout,*)
-      write(stdout,*) 'CO2 concentration (versus today) =',co2ccn/350.
-      write(stdout,*) 'Yields radiative forcing (W/m2) = ',anthro*1.e-3
-
 !-----------------------------------------------------------------------
 !     calculate the expansion coefficients for Berger's solution for
 !     the year of the initial conditions
 !-----------------------------------------------------------------------
 
       call orbit (orbit_yr, eccen, obliq, mvelp, lambm0)
+      write (stdout,*)
+      write (stdout,*) 'Initial Orbital Parameters:'
+
+      write (stdout,*) '  Orbital Year:', orbit_yr
+
+      write (stdout,*) '  Eccentricity:', eccen
+      write (stdout,*) '  Obliquity:   ', obliq
+      write (stdout,*) '  Longitude of Perihelion:', mvelp+180.
 
 !-----------------------------------------------------------------------
 !     calculate annual average insolation and Coriolis factor
@@ -294,10 +316,10 @@
 
       itin(1:nat)  = 500        ! max solver iterations
 
-      epsin(1) = 1.e-3
-      epsin(2:nat) = 1.e-10
+      epsin(:) = 5.e-12
 
       nsolve = nsolve + 1
+      levelin = 20              ! max coarse grid level
 
       if (nsolve .ne. 1) then
         write(*,*) '==> Error: more or less than one solver defined.'
@@ -334,77 +356,6 @@
 
       enddo
 
-!-----------------------------------------------------------------------
-!     read constant annual average snow-free surface albedos
-!-----------------------------------------------------------------------
-
-!     read surface albedo
-      sbc(:,:,icalb) = c0
-      fname = new_file_name ("sf_alb_ann.nc")
-      inquire (file=trim(fname), exist=exists)
-      if (.not. exists) then
-        print*, "Warning => ", trim(fname), " does not exist."
-      else
-        ib(:) = 1
-        ic(:) = imt
-        ic(2) = jmt
-        call openfile (fname, iou)
-        call getvara ('sf_alb', iou, imt*jmt, ib, ic, sbc(1,1,icalb)
-     &,   c1, c0)
-        call closefile (iou)
-      endif
-
-!     calculate new grid yz for zonal averages
-      yz_max = -90.
-      yz_min = 90.
-      do j=1,jmt
-        do i=1,imt
-          yz_max = max(yz_max, tlat(i,j))
-          yz_min = min(yz_min, tlat(i,j))
-        enddo
-      enddo
-      dyz = (yz_max-yz_min)/float(jmz-3)
-      yz_max = yz_max + dyz
-      yz_min = yz_min - dyz
-      dyz = (yz_max-yz_min)/float(jmzm1)
-      do jz=1,jmz
-        yz(jz) = yz_min + float(jz-1)*dyz
-        area_z(jz) = epsln
-        s_alb_z(jz) = 0.
-      enddo
-
-!     convert to coalbedo and find weights for zonal averaging
-      do j=1,jmt
-        do i=1,imt
-          sbc(i,j,icalb) = c1 - sbc(i,j,icalb)
-          do jz=1,jmzm1
-            if (tlat(i,j).ge.yz(jz) .and. tlat(i,j).le.yz(jz+1)) then
-              wt_zonal(i,j) = jz + (yz(jz)-tlat(i,j))/(yz(jz)-yz(jz+1))
-            endif
-          enddo
-       enddo
-      enddo
-
-!     calculate zonal average snow free albedo. sbc(:,:,icalb) may then
-!     be changed but the constant zonal average, s_alb_z should not.
-      do j=2,jmtm1
-        do i=2,imtm1
-          grarea = dxt(i)*dyt(j)*cst(j)
-          jz = int(wt_zonal(i,j))
-          wz = wt_zonal(i,j) - jz
-          area_z(jz) = area_z(jz) + (c1-wz)*grarea
-          area_z(jz+1) = area_z(jz+1) + wz*grarea
-          s_alb_z(jz) = s_alb_z(jz) + (c1-wz)*sbc(i,j,icalb)*grarea
-          s_alb_z(jz+1) = s_alb_z(jz+1) + wz*sbc(i,j,icalb)*grarea
-        enddo
-      enddo
-      do jz=1,jmz
-!       ensure zonal surface albedo is between zero and one.
-        s_alb_z(jz) = c1 - min(max(s_alb_z(jz)/area_z(jz), c0), c1)
-      enddo
-!     ensure pass is between zero and one.
-      pass = min(max(pass, epsln), c1-epsln)
-
 !-----------------------------------------------------------------------
 !     set initial conditions or read a restart
 !-----------------------------------------------------------------------
@@ -418,24 +369,17 @@
       msrsdy = 0
 
       at(:,:,:,:) = 0.
-      tair = 10.
-      rhair = 0.9
+      tair = 13.
       at(:,:,:,isat) = tair
       ssh = cssh*exp(17.67*tair/(tair + 243.5))
-      rh(:,:) = rhair
-      at(:,:,:,ishum) = rhair*ssh
+      rh(:,:) = rhmax
+      at(:,:,:,ishum) = rhmax*ssh
 
       precip(:,:) = 0.
-      sbc(:,:,isst) = 0.
-      sbc(:,:,isss) = 0.
-      tmsk(:,:) = 0.
 
       aicel(:,:,:) = 0.
       hicel(:,:,:) = 0.
 
-      avgp(:,:) = 0.
-      accp(:,:) = 0.
-
       soilm(:,:,:) = 0.
       surf(:,:) = 0.
 
@@ -466,11 +410,11 @@
       bv(:) = 0.
       xv(:) = 0.
 
-      raux(:) = 0.
-      iaux(:) = 0
+!-----------------------------------------------------------------------
+!     set land ice data and tracer grid ocean mask
+!-----------------------------------------------------------------------
 
-      tmsk(:,:) = 0.
-      umsk(:,:) = 0.
+      call icedata
 
       if (.not. init) then
         fname = new_file_name ("restart_embm.nc")
@@ -505,68 +449,11 @@
 !     check for negative elevations
       where (elev(:,:) .lt. 0.) elev(:,:) = 0.
 
-!-----------------------------------------------------------------------
-!     calculate albedo
-!-----------------------------------------------------------------------
-
-      call albedo
-
-!-----------------------------------------------------------------------
-!     set tracer grid ocean mask
-!-----------------------------------------------------------------------
-
-      fname = new_file_name ("restatm.nc")
-      inquire (file=trim(fname), exist=exists)
-      if (exists) then
-        call openfile (fname, iou)
-        exists = inqvardef('tmsk', iou)
-        call closefile (iou)
-      endif
-
-      if (.not. exists .or. init) then
-!       read tmsk if not in the restart or starting from initial condition
-        fname = new_file_name ("tmsk.nc")
-        inquire (file=trim(fname), exist=exists)
-        if (exists) then
-          call openfile (fname, iou)
-          exists = inqvardef('tmsk', iou)
-          if (exists) then
-            ib(:) = 1
-            ic(:) = imt
-            ic(2) = jmt
-            call getvara ('tmsk', iou, imt*jmt, ib, ic, tmsk, c1, c0)
-          endif
-          call closefile (iou)
-        endif
-        if (.not. exists) then
-!         if tmsk does not exist use kmt
-          tmsk(:,:) = 0.
-          do j=1,jmtm1
-            do i=1,imtm1
-              if (kmt(i,j) .gt. 0.) tmsk(i,j) = 1.
-            enddo
-          enddo
-        endif
-      endif
-
-!-----------------------------------------------------------------------
-!     set landice data
-!-----------------------------------------------------------------------
-
-      call icedata
-
-      do j=1,jmtm1
-        do i=1,imtm1
-          if (aicel(i,j,2) .ge. 0.5) tmsk(i,j) = 0.
-        enddo
-      enddo
-
-      call embmbc (tmsk)
-
 !-----------------------------------------------------------------------
 !     set velocity grid ocean mask
 !-----------------------------------------------------------------------
 
+      umsk(:,:) = 0.
       do j=2,jmtm1
         do i=2,imtm1
           umsk(i,j) = min (tmsk(i,j), tmsk(i+1,j), tmsk(i,j+1)
@@ -582,6 +469,43 @@
         enddo
       enddo
       call embmbc (tmsk)
+      do j=2,jmtm1
+        do i=2,imtm1
+          umsk(i,j) = min (tmsk(i,j), tmsk(i+1,j), tmsk(i,j+1)
+     &,                    tmsk(i+1,j+1))
+        enddo
+      enddo
+      call embmbc (umsk)
+
+      do j=1,jmt
+        do i=1,imt
+          if (tmsk(i,j) .ge. 0.5) then
+            if (hice(i,j,1) .le. 0.) aice(i,j,1) = 0.
+            if (hice(i,j,2) .le. 0.) aice(i,j,2) = 0.
+          endif
+        enddo
+      enddo
+      call embmbc (aice(1,1,1))
+      call embmbc (aice(1,1,2))
+
+!-----------------------------------------------------------------------
+!     set the river model
+!-----------------------------------------------------------------------
+
+      call rivinit
+
+!-----------------------------------------------------------------------
+!     set ocean coalbedo
+!-----------------------------------------------------------------------
+
+      do j=1,jmt
+        do i=1,imt
+          if (kmt(i,j) .gt. 0) then
+!           varies from 0.895 at the equator to 0.815 at the pole
+            sbc(i,j,isca) = 0.855 + 0.04*cos(abs(tlat(i,j))*2./radian)
+          endif
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     read vegetation class
@@ -602,25 +526,21 @@
       do j=1,jmt
         do i=1,imt
           if (kmt(i,j) .gt. 0) then
+
             iveg(i,j) = iice
           elseif (rveg(i,j) .gt. 0.6 .and. rveg(i,j) .lt. 7.4) then
             iveg(i,j) = nint(rveg(i,j))
           else
-            print*, "==> Error: invalid vegetation type, ", rveg(i,j)
-            print*, "           at point (i,j), ", i, j
-            stop 'veg check in setembm.f'
+            print*, "==> Warning: invalid vegetation type, ", rveg(i,j)
+     &,             " at point (i,j), ", i, j
+            print*, "    Setting point to vegetation type ice"
+            iveg(i,j) = iice
           endif
         enddo
       enddo
 
       call gvsbc
 
-!-----------------------------------------------------------------------
-!     set the river model
-!-----------------------------------------------------------------------
-
-      call rivinit
-
 !----------------------------------------------------------------------
 !     initialize elastic viscous plastic variables
 !-----------------------------------------------------------------------
