@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/setocn.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/setocn.F
       subroutine setocn
 
 !-----------------------------------------------------------------------
@@ -35,6 +35,8 @@
       include "iounit.h"
       include "isleperim.h"
 
+      include "isopyc.h"
+
       include "levind.h"
       include "mw.h"
 
@@ -51,15 +53,29 @@
 
       dimension kmz(imt,jmt)
 
-      logical error, vmixset, hmixset, uvic_mk
+      integer isfwa1, iefwa1, isfwa2, iefwa2, jsfwa, jefwa, mrfwa
+      logical compensate
+      real fwaflxi, fwayri, fwayrf, fwarate
+
+      real alpha, kw, kc, abio, bbio, cbio, k1, nup, gamma1, gbio
+      real epsbio, nuz, gamma2, nud0, LFe, wd0, par, dtnpzd
+      real redctn, ki, redptn, capr, dcaco3, nupt0, redotn
+      real jdiar
+
+      character (120) :: fname, new_file_name, logfile
+
+      integer ib(10), ic(10)
+
+      logical error, vmixset, hmixset, uvic_mk, exists
 
       namelist /contrl/ init, runlen, rununits, restrt, initpt
      &,                 num_processors, runstep
       namelist /tsteps/ dtts, dtuv, dtsf, dtatm, dtatms, namix, segtim
+     &,                 daylen
       namelist /riglid/ mxscan, sor, tolrsf, tolrsp, tolrfs
-      namelist /mixing/ am, ah, ambi, ahbi, kappa_m, kappa_h, cdbot
-     &,                 spnep, senep, aidif, ncon, nmix, eb, acor
-     &,                 dampts, dampdz, annlev, annlevobc
+      namelist /mixing/ am, ah, ahbkg, ambi, ahbi, kappa_m, kappa_h
+     &,                 cdbot, spnep, senep, aidif, ncon, nmix, eb
+     &,                 acor, dampts, dampdz, annlev, annlevobc
       namelist /diagn/  tsiint, tsiper, tavgint, itavg, tmbint, tmbper
      &,                 itmb, stabint, zmbcint, glenint, trmbint, itrmb
      &,                 vmsfint, gyreint,igyre, extint, prxzint, trajint
@@ -70,13 +86,32 @@
      &,                 cflons, cflone, cflats, cflate, cfldps, cfldpe
      &,                 maxcfl, xbtint, xbtper, crossint, densityint
      &,                 fctint, tyzint, restint, tbtint, tbtper
-      namelist /io/     expnam, iotavg, iotmb, iotrmb, ioglen, iovmsf
-     &,                 iogyre, ioprxz, ioext, iodsp, iotsi, iozmbc
-     &,                 iotraj, ioxbt, uvic_mk, isot1, ieot1, isot2
-     &,                 ieot2, jsot, jeot, ksot, keot, mrot
+      namelist /io/     expnam, logfile, runstamp, iotavg, iotmb, iotrmb
+     &,                 ioglen, iovmsf, iogyre, ioprxz, ioext, iodsp
+     &,                 iotsi, iozmbc, iotraj, ioxbt, uvic_mk, isot1
+     &,                 ieot1, isot2, ieot2, jsot, jeot, ksot, keot
+     &,                 mrot
       namelist /ictime/ year0, month0, day0, hour0, min0, sec0, ryear
      &,                 rmonth, rday, rhour, rmin, rsec, refrun, refinit
      &,                 refuser, eqyear, eqmon, monlen, init_time
+     &,                 init_time_in, init_time_out, omega
+      namelist /npzd/   alpha, kw, kc, abio, bbio, cbio, k1, nup, gamma1
+     &,                 gbio, epsbio, nuz, gamma2, nud0, LFe, wd0, par
+     &,                 dtnpzd, redctn, ki, redptn, capr, dcaco3
+     &,                 nupt0, redotn, jdiar
+      namelist /fwa/    isfwa1, iefwa1, isfwa2, iefwa2, jsfwa, jefwa
+     &,                 mrfwa, fwaflxi, fwayri, fwayrf, fwarate
+     &,                 compensate
+
+!-----------------------------------------------------------------------
+!     physical constants
+!-----------------------------------------------------------------------
+
+      rho0 = 1.035
+      rho0r = c1/rho0
+      grav = 980.6
+      radius = 6370.0e5
+      pi = atan(1.0) * 4.0
 
 !-----------------------------------------------------------------------
 !     initialize variables
@@ -99,6 +134,7 @@
       dtatms = 43200.0
       namix = 16
       segtim = 1.0
+      daylen = 86400.0
 
 !     set defaults for namelist riglid
       mxscan = 300
@@ -109,6 +145,7 @@
 
       am = 2.0e9
       ah = 2.0e7
+      ahbkg = 0.
       ambi = 1.0e23
       ahbi = 5.0e22
       kappa_m = 10.0
@@ -117,7 +154,7 @@
       spnep = 3.0e5
       senep = 12.0e5
 
-      aidif    = 0.0
+      aidif = 1.0
 
       ncon = 1
       nmix = 16
@@ -197,6 +234,8 @@
 
 !     set defaults for namelist io
       expnam = ' '
+      logfile = 'machine.log'
+      runstamp = ' '
       restrt = .false.
       iotavg = -1
       iotmb = -1
@@ -241,16 +280,52 @@
       eqmon = .false.
       monlen = 30
       init_time = .false.
-
-!     physical constants
-
-      rho0 = 1.035
-      rho0r = c1/rho0
-      grav = 980.6
-      radius = 6370.0e5
-      pi = atan(1.0) * 4.0
+      init_time_in = .false.
+      init_time_out = .false.
       omega = pi/43082.0
 
+!     set defaults for namelist npzd
+      alpha = 0.1  ! Initial slope P-I curve [(W/m^2)^(-1)/day]
+      kw = 0.04  ! Light attenuation due to water [1/m]
+      kc = 0.047  ! Light atten. by phytoplankton [1/(m*mmol/m^3)]
+      ki = 5.0  ! Light attenuation through sea ice & snow
+      abio = 0.11  ! a; Maximum growth rate parameter [1/day]
+      bbio = 1.066  ! b
+      cbio = 1.0  ! c [1/deg_C]
+      k1 = 0.7  ! Half saturation constant for N uptake [mmol/m^3]
+      nup = 0.025  ! Specific mortality rate (Phytoplankton) [1/day]
+      nupt0 = 0.02  ! Specific mortality rate (Phytoplankton) [1/day]
+      gamma1 = 0.925  ! gama1; Assimilation efficiency (zpk)
+      gbio = 1.575  ! Maximum grazing rate [1/day]
+      epsbio = 1.6  ! Prey capture rate [(mmol/m^3)^(-2)day^(-1)]
+      nuz = 0.34  ! Quadratic mortality (zpk) [(mmol/m^3)^(-2)day^(-1)]
+      gamma2 = 0.01  ! Excretion (zpk)
+      nud0 = 0.048  ! remineralization rate [1/day]
+      LFe = 1.0  ! Iron limitation
+      wd0 = 6.0  ! Sinking speed of detritus at surface [m/day]
+      par = 0.43  ! fraction of photosythetically active radiation
+      dtnpzd = dtts  ! time step of biology [s]
+      redctn = 7.  ! C/N Redfield ratio
+      redptn = 1./16.  ! P/N Redfield ratio
+      capr = 0.018  ! carbonate to carbon production ratio
+      dcaco3 = 450000.0  ! remineralisation depth of calcite [cm]
+      redotn = 10.6  ! O2/N Redfield ratio
+      jdiar = 0.5  ! factor reducing the growth rate of diazotrophs
+
+!     set defaults for namelist fwa
+      isfwa1 = 1
+      iefwa1 = imt
+      isfwa2 = 0
+      iefwa2 = 0
+      jsfwa = 1
+      jefwa = jmt
+      mrfwa = 1
+      fwaflxi = 0.
+      fwayri = -1.e20
+      fwayrf =  1.e20
+      fwarate = 0.
+      compensate = .false.
+
 !     set other stuff
 
       do k=1,km
@@ -314,6 +389,8 @@
       write (stdout,mixing)
       call relunit (ioun)
 
+      ah = ahbkg
+
       call getunit (ioun, 'control.in', 'f s r')
       read  (ioun, diagn, end=105)
 105   continue
@@ -332,12 +409,19 @@
       write (stdout,ictime)
       call relunit (ioun)
 
-      if (uvic_mk) then
-        print*, ' '
-        print*, 'Mk Options are:'
-        include "uvic_mk.h"
-        print*, ' '
-      endif
+      call getunit (ioun, 'control.in', 'f s r')
+      read  (ioun, npzd, end=108)
+108   continue
+      write (stdout,npzd)
+      call relunit (ioun)
+
+      call getunit (ioun, 'control.in', 'f s r')
+      read  (ioun, fwa, end=109)
+109   continue
+      write (stdout,fwa)
+      call relunit (ioun)
+
+      dtocn = dtts
 
 !     limit some variables
       isot1 = max(isot1, 1)
@@ -351,6 +435,10 @@
       tsiper = min(tsiper, tsiint)
       tbtper = min(tbtper, tbtint)
       if (runstep .gt. 0.0) runlen = min(runstep, runlen)
+      if (init_time) then
+        init_time_in = .true.
+        init_time_out = .true.
+      endif
 
       if (eqyear) then
         if (eqmon) then
@@ -369,10 +457,23 @@
       endif
 
 !-----------------------------------------------------------------------
-!     zero integrated time average accumulators
+!     set runstamp
 !-----------------------------------------------------------------------
-
-      call ta_ocn_tsi (0)
+      if (runstamp .eq. ' ') then
+!       read runstamp from last line of logfile if it exists
+        fname = new_file_name (logfile)
+        inquire (file=trim(fname), exist=exists)
+        if (exists) then
+          call getunit (ioun, fname, 'f s r')
+          do while (exists)
+            read  (ioun, '(a120)', end=120) runstamp
+          enddo
+120       continue
+          call relunit (ioun)
+          print*, " "
+          print*, "runstamp: ", trim(runstamp)
+        endif
+      endif
 
 !     user specified tracer names are placed into "trname" here.
 
@@ -383,16 +484,13 @@
       trname(2) = 'salinity    '
 
 !-----------------------------------------------------------------------
-!     open i/o units needed for prognostic variables
-!     nbuf = number of i/o buffers (currently not used)
+!     get i/o units needed for prognostic variables
 !-----------------------------------------------------------------------
 
       call getunitnumber (kflds)
       call getunitnumber (latdisk(1))
       call getunitnumber (latdisk(2))
 
-      nbuf = 2
-
 !-----------------------------------------------------------------------
 !     set up the grids in x (longitude), y (latitude), and z (depth)
 !     corresponding to Arakawa "b" gird system
@@ -425,52 +523,51 @@
 !     set prognostic quantities to either initial conditions or restart
 !-----------------------------------------------------------------------
 
-      if (init) then
+!     generate topographic levels "kmt" on "t" cells.
 
-!       generate topographic levels "kmt" on "t" cells.
+      call topog (kmt, map, xt, yt, zt, xu, yu, zw, imt, jmt, km)
 
-        call topog (kmt, map, xt, yt, zt, xu, yu, zw, imt, jmt, km)
+!     construct depth arrays associated with "u" cells
 
-!       construct depth arrays associated with "u" cells
+      call depth_u (kmt, imt, jmt, zw, km, kmu, h, hr)
 
-        call depth_u (kmt, imt, jmt, zw, km, kmu, h, hr)
+!     initialize two dimensional fields on disk
 
-!       initialize two dimensional fields on disk
+!     initialize stream function fields in memory
 
-!       initialize stream function fields in memory
+      do n=1,2
+        do jrow=1,jmt
+          do i=1,imt
 
-        do n=1,2
-          do jrow=1,jmt
-            do i=1,imt
+            psi(i,jrow,n) = c0
+            ptd(i,jrow)   = c0
 
-              psi(i,jrow,n) = c0
-              ptd(i,jrow)   = c0
-
-            enddo
           enddo
         enddo
+      enddo
 
-!       initialize stream function guess fields on disk
-!       block`s 1 & 2 are for the stream function guess field on disk
+!     initialize stream function guess fields on disk
+!     block`s 1 & 2 are for the stream function guess field on disk
 
-        do n=1,nkflds
-          call oput (kflds, nwds, n, ptd(1,1))
-        enddo
+      do n=1,nkflds
+        call oput (kflds, nwds, n, ptd(1,1))
+      enddo
 
-!       initialize all latitude rows
+!     initialize all latitude rows
 
-        call rowi
+      call rowi
 
-!       initialize time step counter = 0
+!     initialize time step counter = 0
 
-        itt    = 0
-        irstdy = 0
-        msrsdy = 0
-      else
+      itt    = 0
+      irstdy = 0
+      msrsdy = 0
 
-!       initialize all prognostic quantities from the restart
+!     initialize all prognostic quantities from the restart
 
-        call ocn_rest_in ('restocn.nc', 1, imt, 1, jmt)
+      if (.not. init) then
+        fname = new_file_name ("restart_mom.nc")
+        call mom_rest_in (fname, 1, imt, 1, jmt)
 
 !       compute a topography checksum
 
@@ -483,6 +580,12 @@
         write (stdout,*) ' "kmt" checksum = ', cksum
       endif
 
+!-----------------------------------------------------------------------
+!     zero integrated time average accumulators
+!-----------------------------------------------------------------------
+
+      call ta_mom_tsi (0)
+
 !-----------------------------------------------------------------------
 !     initialize the time manager with specified initial conditions
 !     time, user reference time, model time, and how long to integrate.
@@ -549,7 +652,7 @@
         write (stderr,9599) njtbft, njtbfu
         stop '>ocean 1'
       endif
-9551  format (/' ==== start and end indices for fourier filtering ====')
+9551  format (/' ==== start and end indices for Fourier filtering ====')
 9552  format (' only 11 sets of indices fit across the page.',
      &       '  others will not be printed.'/)
 9553  format (/,' == filtering indices for t,s ==')
@@ -603,7 +706,7 @@
 !     also set the vertical regional masks and names for use (along
 !     with the horizontal ones) in term balance calculations for
 !     tracers & momentum. For term balance calculations the number
-!     of masks is the product of horizonatl & vertical regions.
+!     of masks is the product of horizontal & vertical regions.
 !---------------------------------------------------------------------
 
 !    read in horizontal & vertical regional masks ("mskhr" & "mskvr")
@@ -618,7 +721,7 @@
 !     compute the surface area and volume of the ocean regions. index 0
 !     refers to the sum of all regions.
 !     (values used in subroutine region are done in terms of meters,
-!     rather than centimeters)
+!     rather than centimetres)
 !-----------------------------------------------------------------------
 
       areag = c0
@@ -748,7 +851,7 @@
      &, 1x,f6.2,'% of the grid points lie within the ocean.'/)
 
 !-----------------------------------------------------------------------
-!     find all land mass perimeters for poisson solvers
+!     find all land mass perimeters for Poisson solvers
 !-----------------------------------------------------------------------
 
       auto_kmt_changes = .false.
@@ -773,8 +876,8 @@
           imask(isle) = .true.
         else
           imask(isle) = .false.
-        end if
-      end do
+        endif
+      enddo
 
 !     user-specified changes to island mask
 !       imask(1) = .true.
@@ -792,15 +895,15 @@
           else
             print '(2a,i3)','=> calculations enabled for ocean ',
      &                      'perimeter of land mass',isle
-          end if
-        end if
-      end do
+          endif
+        endif
+      enddo
       do isle=0,nisle
         if (.not. imask(isle)) then
             print '(2a,i3)','=> calculations disabled for ocean ',
      &                      'perimeter of land mass',isle
-        end if
-      end do
+        endif
+      enddo
 
 !     imain is the land mass on which dpsi is normalized to 0
 !     if imain is 0, then dpsi is not normalized.
@@ -810,25 +913,25 @@
       do isle=1,nisle
         if (nippts(isle) .gt. nippts(imain)) then
           imain = isle
-        end if
-      end do
+        endif
+      enddo
 
 !     if any island perimeter is not calculated, imain must be one such
 
       do isle=1,nisle
         if (.not.imask(isle)) then
           imain = isle
-        end if
+        endif
       enddo
 
       if (imain .gt. 0 .and. imain .le. nisle) then
         print '(a,i4)', 'dpsi normalized to zero on land mass',imain
-      else if (imain .eq. 0) then
+      elseif (imain .eq. 0) then
         print *, 'no normalization on dpsi'
       else
         print *, 'ERROR: illegal value for choice of normalization ',
      &           'land mass, imain =', imain
-      end if
+      endif
       print *,' (user may set "imain" to any valid land mass number)'
 
 !---------------------------------------------------------------------
@@ -907,11 +1010,13 @@
         enddo
       enddo
 
-!     coriolis factors
+!     Coriolis factors
 
       do jrow=1,jmt
-        cori(jrow,1) = c2*omega*sine(jrow)
-        cori(jrow,2) = -c2*omega*sine(jrow)
+        do i=1,imt
+          cori(i,jrow,1) = c2*omega*sin(ulat(i,jrow)/radian)
+          cori(i,jrow,2) = -cori(i,jrow,1)
+        enddo
       enddo
 
 !     metric diffusion factors
@@ -919,21 +1024,17 @@
       amix = am
 
       do jrow=1,jmt
-
         am3(jrow)   = amix*(c1-tng(jrow)*tng(jrow))/(radius**2)
         am4(jrow,1) = -amix*c2*sine(jrow)/(radius*csu(jrow)
      &                                     *csu(jrow))
         am4(jrow,2) = -am4(jrow,1)
-
       enddo
 
 !     metric advection factors
 
       do jrow=1,jmt
-
         advmet(jrow,1) = tng(jrow)/radius
         advmet(jrow,2) = -advmet(jrow,1)
-
       enddo
 
 !     diffusive flux through bottom of cells
@@ -963,16 +1064,18 @@
 
       call avgi
 
+!-----------------------------------------------------------------------
+!    initialize the isopycnal mixing
+!-----------------------------------------------------------------------
+
+      call isopi (error, am, ah)
+
 !-----------------------------------------------------------------------
 !     do all consistency checks last
 !-----------------------------------------------------------------------
 
       call checks (error, vmixset, hmixset)
 
-!-----------------------------------------------------------------------
-!     list options enabled for this model run
-!-----------------------------------------------------------------------
-
       return
 
 9341  format (//,'  Global ocean statistics:'
@@ -1000,7 +1103,7 @@
 !       h   = depth to ocean floor over "u" cells (cm)
 !       hr  = reciprocal of "h"
 
-!     author:  r.c.pacanowski   e-mail  rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       dimension kmt(imt,jmt), kmu(imt,jmt), h(imt,jmt), hr(imt,jmt)
@@ -1058,7 +1161,7 @@
       subroutine rowi
 
 !-----------------------------------------------------------------------
-!     initialize prognositc quantities at "tau-1" and "tau"
+!     initialize prognostic quantities at "tau-1" and "tau"
 
 !     inputs:
 
@@ -1069,11 +1172,17 @@
 
       include "param.h"
       include "coord.h"
+      include "csbc.h"
       include "iounit.h"
       include "levind.h"
       include "mw.h"
       include "task_on.h"
       include "taskrows.h"
+      character(120) :: fname, new_file_name
+      integer iou
+      integer ib(10), ic(10)
+      logical exists
+      real tmpik(imt,km), p1, c100, c1e3, dmsk(imt,jmt)
 
 !-----------------------------------------------------------------------
 !     update pointers to tau-1, tau, & tau+1 data on disk.
@@ -1087,6 +1196,10 @@
       taudisk   = mod(itt  ,2) + 1
       taup1disk = taum1disk
 
+      p1 = 0.1
+      c100 = 100.
+      c1e3 = 1000.
+
 !-----------------------------------------------------------------------
 !     update pointers to tau-1, tau, & tau+1 data in the MW
 !-----------------------------------------------------------------------
@@ -1137,41 +1250,232 @@
         enddo
 
 !-----------------------------------------------------------------------
-!       set the Temperature and Salinity
+!       set tracers
 !-----------------------------------------------------------------------
 
-!       construct highly idealized initial density profile
+        do n=1,nt
 
-        do i=1,imt
-          do k=1,km
-            t(i,k,j,1,taup1) = theta0 (yt(jrow), zt(k))
-            t(i,k,j,2,taup1) = 0.03472 - 0.035
-          enddo
-        enddo
-
-!       Initialize passive tracers to 1.0 (k=1) and 0.0 (k>1)
-
-        if (nt .gt. 2) then
-          do n=3,nt
-            do k=1,km
-              do i=1,imt
+          do i=1,imt
+            do k=1,kmt(i,jrow)
+              if (trim(mapt(n)) .eq. 'temp') then
+                t(i,k,j,n,taup1) = theta0 (yt(jrow), zt(k))
+              elseif (trim(mapt(n)) .eq. 'salt') then
+                t(i,k,j,n,taup1) = 0.03472 - 0.035
+              elseif (trim(mapt(n)) .eq. 'dic') then
+                t(i,k,j,n,taup1) = 2.315
+              elseif (trim(mapt(n)) .eq. 'alk') then
+                t(i,k,j,n,taup1) = 2.429
+              elseif (trim(mapt(n)) .eq. 'o2') then
+                t(i,k,j,n,taup1) = 0.1692
+              elseif (trim(mapt(n)) .eq. 'po4') then
+                if (k .eq. 1) then
+                  t(i,k,j,n,taup1) = 0.543
+                else
+                  t(i,k,j,n,taup1) = 2.165
+                endif
+              elseif (trim(mapt(n)) .eq. 'phyt') then
+                t(i,k,j,n,taup1) = 0.14*exp((zt(1)-zt(k))/100.e2)
+              elseif (trim(mapt(n)) .eq. 'zoop') then
+                t(i,k,j,n,taup1) = 0.014*exp((zt(1)-zt(k))/100.e2)
+              elseif (trim(mapt(n)) .eq. 'detr') then
+                t(i,k,j,n,taup1) = 1.e-4
+              elseif (trim(mapt(n)) .eq. 'no3') then
+                if (k .eq. 1) then
+                  t(i,k,j,n,taup1) = 5.30
+                else
+                  t(i,k,j,n,taup1) = 30.84
+                endif
+              elseif (trim(mapt(n)) .eq. 'diaz') then
+                t(i,k,j,n,taup1) = 0.014*exp((zt(1)-zt(k))/100.e2)
+              elseif (trim(mapt(n)) .eq. 'c14') then
+                t(i,k,j,n,taup1) = -150 ! permil (converted later)
+              elseif (trim(mapt(n)) .eq. 'cfc11') then
+                t(i,k,j,n,taup1) = 0.0
+              elseif (trim(mapt(n)) .eq. 'cfc12') then
+                t(i,k,j,n,taup1) = 0.0
+              else
                 if (k .eq. 1) then
                   t(i,k,j,n,taup1) = c1
                 else
                   t(i,k,j,n,taup1) = c0
                 endif
-              enddo
+              endif
             enddo
           enddo
-        endif
-        if (jrow .eq. jmt) then
-          write (stdout,'(a,a)')
-     & '=> Note: initialized T & S to internally generated idealized'
-     &,                    ' values for a test case.'
-        endif
+
+          ib(:) = 1
+          ib(2) = jrow
+          ib(3) = 1
+          ic(:) = imt
+          ic(2) = 1
+          ic(3) = km
+          if (trim(mapt(n)) .eq. 'temp') then
+            C2K = 273.15
+!           expecting units of degrees K
+            fname = new_file_name ("temperature_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,itemp,taup1)
+!             convert to model units (degrees C)
+              call getvara ('temperature', iou, imt*km, ib, ic, tmpik
+     &,         c1, -C2K)
+              t(1:imt,1:km,j,itemp,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'salt') then
+!           expecting units of psu
+            fname = new_file_name ("salinity_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              p001 = 0.001
+              p035 = 0.035
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,isalt,taup1)
+!             convert to model units ((psu-35)/1000)
+              call getvara ('salinity', iou, imt*km, ib, ic, tmpik
+     &,         p001, -p035)
+              t(1:imt,1:km,j,isalt,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'dic') then
+!           expecting units of mol m-3 (equals model units, umol cm-3)
+            fname = new_file_name ("tco2_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,idic,taup1)
+              call getvara ('tco2', iou, imt*km, ib, ic, tmpik, c1, c0)
+              t(1:imt,1:km,j,idic,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'alk') then
+!           expecting units of mol m-3 (equals model units, umol cm-3)
+            fname = new_file_name ("alk_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,ialk,taup1)
+              call getvara ('alk', iou, imt*km, ib, ic, tmpik, c1, c0)
+              t(1:imt,1:km,j,ialk,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'o2') then
+!           expecting units of mol m-3 (equals model units, umol cm-3)
+            fname = new_file_name ("oxygen_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,io2,taup1)
+              call getvara ('oxygen', iou, imt*km, ib, ic, tmpik
+     &,         c1, c0)
+              t(1:imt,1:km,j,io2,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'po4') then
+!           expecting units of mol m-3
+            fname = new_file_name ("phosphate_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,ipo4,taup1)
+!             convert to model units (nmol cm-3)
+              call getvara ('phosphate', iou, imt*km, ib, ic, tmpik
+     &,         c1e3, c0)
+              t(1:imt,1:km,j,ipo4,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'no3') then
+!           expecting units of mol m-3
+            fname = new_file_name ("nitrate_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,ino3,taup1)
+!             convert to model units (nmol cm-3)
+              call getvara ('nitrate', iou, imt*km, ib, ic, tmpik
+     &,         c1e3, c0)
+              t(1:imt,1:km,j,ino3,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          elseif (trim(mapt(n)) .eq. 'c14') then
+!           expecting units of permil
+            fname = new_file_name ("bkgc14_ann.nc")
+            inquire (file=trim(fname), exist=exists)
+            if (exists) then
+              call openfile (trim(fname), iou)
+              tmpik(1:imt,1:km) = t(1:imt,1:km,j,ic14,taup1)
+!             convert later
+              call getvara ('bkgc14', iou, imt*km, ib, ic, tmpik
+     &,         c1, c0)
+              t(1:imt,1:km,j,ic14,taup1) = tmpik(1:imt,1:km)
+              call closefile (iou)
+            else
+              if (jrow .eq. 1)
+     &          print*, "Warning => Can not find ",trim(fname)
+            endif
+          endif
+
+          do k=1,km
+            do i=1,imt
+              if (kmt(i,jrow) .lt. k)  t(i,k,j,n,taup1) = c0
+            enddo
+          enddo
+
+        enddo
 
 !-----------------------------------------------------------------------
-!       zero out Temperature and Salinity in land points
+!       initialize surface boundary
+!-----------------------------------------------------------------------
+        if (isst .ne. 0) sbc(1:imt,jrow,isst) = t(1:imt,1,j,itemp,taup1)
+        if (isss .ne. 0) sbc(1:imt,jrow,isss) = t(1:imt,1,j,isalt,taup1)
+        if (issdic .ne. 0)
+     &    sbc(1:imt,jrow,issdic) = t(1:imt,1,j,idic,taup1)
+        if (isso2 .ne. 0) sbc(1:imt,jrow,isso2) = t(1:imt,1,j,io2,taup1)
+        if (issalk .ne. 0)
+     &    sbc(1:imt,jrow,issalk) = t(1:imt,1,j,ialk,taup1)
+        if (isspo4 .ne. 0)
+     &    sbc(1:imt,jrow,isspo4) = t(1:imt,1,j,ipo4,taup1)
+        if (issphyt .ne. 0)
+     &    sbc(1:imt,jrow,issphyt) = t(1:imt,1,j,iphyt,taup1)
+        if (isszoop .ne. 0)
+     &    sbc(1:imt,jrow,isszoop) = t(1:imt,1,j,izoop,taup1)
+        if (issdetr .ne. 0)
+     &    sbc(1:imt,jrow,issdetr) = t(1:imt,1,j,idetr,taup1)
+        if (issno3 .ne. 0)
+     &    sbc(1:imt,jrow,issno3) = t(1:imt,1,j,ino3,taup1)
+        if (issdiaz .ne. 0)
+     &    sbc(1:imt,jrow,issdiaz) = t(1:imt,1,j,idiaz,taup1)
+        if (issc14 .ne. 0)
+     &    sbc(1:imt,jrow,issc14) = t(1:imt,1,j,ic14,taup1)
+        if (isscfc11 .ne. 0)
+     &    sbc(1:imt,jrow,isscfc11) = t(1:imt,1,j,icfc11,taup1)
+        if (isscfc12 .ne. 0)
+     &    sbc(1:imt,jrow,isscfc12) = t(1:imt,1,j,icfc12,taup1)
+
+!-----------------------------------------------------------------------
+!       zero out tracers in land points
 !-----------------------------------------------------------------------
 
         do i=1,imt
@@ -1214,6 +1518,68 @@
         endif
 
       enddo
+
+!-----------------------------------------------------------------------
+!     find inital average surface references
+!-----------------------------------------------------------------------
+      print*, " "
+      print*, "inital average surface references: "
+      dmsk(:,:) = 1.
+      if (isss .ne. 0) then
+        call areaavg (sbc(1,1,isss), dmsk, socn)
+        socn = socn + 0.035
+        print*, "salinity, socn = ", socn
+      endif
+      if (issdic .ne. 0) then
+        call areaavg (sbc(1,1,issdic), dmsk, dicocn)
+        print*, "dissolved inorganic carbon, dicocn = ", dicocn
+      endif
+      if (isso2 .ne. 0) then
+        call areaavg (sbc(1,1,isso2), dmsk, o2ocn)
+        print*, "oxygen, o2oc = ", o2ocn
+      endif
+      if (issalk .ne. 0) then
+        call areaavg (sbc(1,1,issalk), dmsk, alkocn)
+        print*, "alkalinity, alkocn = ", alkocn
+      endif
+      if (isspo4 .ne. 0) then
+        call areaavg (sbc(1,1,isspo4), dmsk, po4ocn)
+        print*, "phosphate, po4ocn = ", po4ocn
+      endif
+      if (issphyt .ne. 0) then
+        call areaavg (sbc(1,1,issphyt), dmsk, phytocn)
+        print*, "phytoplankton, phytocn = ", phytocn
+      endif
+      if (isszoop .ne. 0) then
+        call areaavg (sbc(1,1,isszoop), dmsk, zoopocn)
+        print*, "zooplankton, zoopocn = ",zoopocn
+      endif
+      if (issdetr .ne. 0) then
+        call areaavg (sbc(1,1,issdetr), dmsk, detrocn)
+        print*, "detritus, detocn = ", detocn
+      endif
+      if (issno3 .ne. 0) then
+        call areaavg (sbc(1,1,issno3), dmsk, no3ocn)
+        print*, "nitrate, no3ocn = ", no3ocn
+      endif
+      if (issdiaz .ne. 0) then
+        call areaavg (sbc(1,1,issdiaz), dmsk, diazocn)
+        print*, "diazotrophs, diazocn = ", diazocn
+      endif
+      if (issc14 .ne. 0) then
+        call areaavg (sbc(1,1,issc14), dmsk, c14ocn)
+        print*, "carbon 14, c14ocn = ", c14ocn
+      endif
+      if (isscfc11 .ne. 0) then
+        call areaavg (sbc(1,1,isscfc11), dmsk, cfc11ocn)
+        print*, "chlorofluorocarbon 11, cfc11ocn = ", cfc11ocn
+      endif
+      if (isscfc12 .ne. 0) then
+        call areaavg (sbc(1,1,isscfc12), dmsk, cfc12ocn)
+        print*, "chlorofluorocarbon 12, cfc12ocn = ", cfc12ocn
+      endif
+      print*, " "
+
       write (stdout,*) ' I.C. checksum for t =',tcksum
       write (stdout,*) ' I.C. checksum for s =',scksum
       write (stdout,*) ' I.C. checksum for u =',ucksum
@@ -1224,7 +1590,7 @@
       subroutine sethr (nr, xstart, xend, ystart, yend)
 
 !=======================================================================
-!     discretizes the horizontal region to nearset model grid points
+!     discretizes the horizontal region to nearest model grid points
 
 !     nr     = the horizontal region number
 !     xstart = starting longitude at edge of "t" box region
@@ -1238,7 +1604,7 @@
       include "cregin.h"
       include "levind.h"
 
-!     find the nearest "t" box indicies within the region
+!     find the nearest "t" box indices within the region
 
       jsr = min(indp (ystart, yu, jmt)+1, jmt)
       jer = indp (yend, yu, jmt)
@@ -1286,7 +1652,7 @@
       subroutine setvr (nr, zstart, zend)
 
 !=======================================================================
-!     discretizes the vertical region to nearset model grid points
+!     discretizes the vertical region to nearest model grid points
 
 !     nr     = the vertical region number
 !     zstart = starting depth at edge of "t" box region in cm.
@@ -1297,7 +1663,7 @@
       include "coord.h"
       include "cregin.h"
 
-!     find the nearest "t" box indicies within the region
+!     find the nearest "t" box indices within the region
 
       if (zstart .lt. p5*zw(1)) then
         ksr = 1
@@ -1331,13 +1697,13 @@
 !     potential temperature returned is 2.0 degrees C.  surface
 !     values are set slightly above 18.4 degrees C at the reference
 !     latitude "reflat".
-!     the estimates are produced from a 7th order ploynomial fit to
+!     the estimates are produced from a 7th order polynomial fit to
 !     the annual mean world ocean potential temperature observations
 !     of Levitus (1982).
 
 !     input [units]:
-!       a latitdue (ydeg): [degrees]
-!       a zt value (depth): [centimeters]
+!       a latitude (ydeg): [degrees]
+!       a zt value (depth): [centimetres]
 !     output [units]:
 !       potential temperature estimate (est): [degrees centigrade]
 
@@ -1350,7 +1716,7 @@
 !                   ("ydeg") to the reference latitude ("reflat")
 !                   used to scale the upper 2000 meters of the vertical
 !                   temperature profile
-!       tmin,tmax = the minumum and maximum potential temperatures
+!       tmin,tmax = the minimum and maximum potential temperatures
 !                   allowed at the time of model initialization
 
 !     reference:
