@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/size.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/size.h
 !======================= include file "size.h" =========================
 
 !-----------------------------------------------------------------------
@@ -8,24 +8,23 @@
 !     imt    = number of grid points in the longitudinal direction
 !              (calculated points are from 2 through imt-1. End points
 !               are boundaries)
-
 !     jmt    = number of grid points (latitude rows) in the latitudinal
 !              direction (calculated points are from 2 through jmt-1.
 !              End points are boundaries)
-
 !     km     = number of grid points in the vertical direction
 !              (calculated points are from 1 through km)
-
 !     nt     = number of tracers (temperature, salinity, ...)
-
+!     nsrc   = number of tracer with sources
+!     kpzd   = depth for limited npzd model
+!     jmz    = size for "unrotated" zonal averages
+!     jmzm1  = jmz minus one
 !     mnisle = maximum number of islands (unconnected land masses)
-
 !     maxipp = maximum number of all island perimeter points
 !-----------------------------------------------------------------------
       include "derived_options.h"
 
-      integer imt, jmt, km, nt, nat, jmz, jmzm1, mnisle, maxipp
-      integer nprocessors, jmw, jsmw, jemw, jextra
+      integer imt, jmt, km, nt, nsrc, kpzd, nat, jmz, jmzm1, mnisle
+      integer maxipp, nprocessors, jmw, jsmw, jemw, jextra
 
       parameter (imt=  102, jmt=  102, km= 19)
       parameter (nt=2
@@ -33,11 +32,16 @@
      $             +1
 
      $               )
+      parameter (nsrc=0
+
+     $               +1
+
+     $                 )
+      parameter (kpzd=km)
 
       parameter (nat=2
 
      $, jmz=jmt, jmzm1=jmz-1)
-
       parameter (mnisle=50, maxipp=5000)
 
       parameter (jmw=jmt)
@@ -60,9 +64,10 @@
 
 ! POINTS = Maximum number of points in grid.
 ! STEPSM = Maximum number of timesteps in a day.
+! klmax = maximum ocean depth levels over which the land model can exist
 
-      integer POINTS, STEPSM
-      parameter (POINTS=3639, STEPSM=24)
+      integer POINTS, STEPSM, klmax
+      parameter (POINTS=4600, STEPSM=24, klmax=0)
 
 ! NNVG  = Number of non-vegetation surface types.
 ! NPFT  = Number of plant functional types.
