@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/state.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/state.h
 !====================== include file "state.h" =========================
 
 !     variables for equation of state
