@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/stdunits.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/stdunits.h
 !====================== include file "stdunits.h" ======================
 
 !     stdin  = unit number for standard input.
