@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/switch.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/switch.h
 !====================== include file "switch.h" ========================
 
 !     all time dependent decisions are made by time manager "tmngr.F"
@@ -28,7 +28,7 @@
 !               number of "segtim".
 
 !     nmix    = number of time steps between mixing timesteps. used
-!               to damp timestep splitting due to centered leapfrog.
+!               to damp timestep splitting due to centred leapfrog.
 
 !     init    = (true,false)  indicates that this run is a
 !               (start from initial conditions, restart)
@@ -39,7 +39,11 @@
 !     eb      = (true,false) configures for the use of a
 !               (euler backward,forward) type mixing timestep
 
-!     init_time = (true,false) sets restart time to initial condition
+!     init_time     = (true,false) sets restarts to initial time
+
+!     init_time_in  = (true,false) sets input restart to initial time
+
+!     init_time_out = (true,false) sets output restart to initial time
 
 !-----------------------------------------------------------------------
 !     inputs to tmngr.F: diagnostic intervals
@@ -293,7 +297,7 @@
 !     osege  =  true on the last time step of an ocean segment in mom.F
 !               otherwise false.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 
       character(8) :: rununits
       common /switc_c/ rununits
@@ -311,8 +315,8 @@
       common /switc_l/ itavg, itmb, itrmb, igyre
       common /switc_l/  eoday, eoweek, eo2wks
       common /switc_l/  eomon, midmon, eoyear, eorun
-      logical init_time
-      common /switc_l/  init_time
+      logical init_time, init_time_in, init_time_out
+      common /switc_l/  init_time, init_time_in, init_time_out
 
       real runlen, rundays
       common /switc_r/ runlen, rundays
@@ -515,7 +519,7 @@
 !     Note the use of "ieomon" to key off the months.  The switch
 !     "testts" will be true whenever "eomon" is true.
 !     Also note that when an averaging switch is keyed off another
-!     switch, the switch inverval argument is not used, but is
+!     switch, the switch interval argument is not used, but is
 !     retained for consistency with the form of other averaging
 !     switches.
 !-----------------------------------------------------------------------
