@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/tcslab.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/tcslab.h
 !====================== include file "tcslab.h" ========================
 
 !     slab block extensions for turbulent closure
