@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/timeavgs.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/timeavgs.F
       subroutine avgset (xt, xu, yt, yu, zt, zw, imkmax
      &,         cvxz, cvx, cvy, cvz, javgr, imav, jmav, levav)
 
@@ -32,7 +32,7 @@
 !       jmav  = number of latitudinal points for averaging data
 !       levav = number of depth points for averaging data
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       include "size.h"
@@ -197,7 +197,7 @@
 9900  format (1x,i4,a,/ (1x,10f10.2))
       end
 
-      subroutine avgvar (j, jrow, w, varu, vart, stf, smf)
+      subroutine avgvar (j, jrow, w, varu, vart, stf, smf, mapt)
 
 !-----------------------------------------------------------------------
 
@@ -215,11 +215,8 @@
 !      1) set up the "averaging" grid in "avgset" (in this module)
 !      2) run this "timeavgs.F" module and follow its directions
 !      3) enable the "time_averages" option
-!          (possibly the "time_averages_disk" also and set the
-!           averaging interval "timavgint" and period "timavgper"
-!          (See "switch.h")
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
       include "param.h"
@@ -243,12 +240,12 @@
       common /avgblk/ xtav(imtav), xuav(imtav), ytav(jmtav+2)
       common /avgblk/ yuav(jmtav+2), ztav(kmav), zwav(kmav)
       common /avgblk/ avg3d(imkmav,n3dvar), avg2d(imtav,n2dvar)
-
       common /avgblk/ spbuf(imkmav,n3dvar,jmtav)
       common /avgblk/ spbuf2(imtav,n2dvar,jmtav)
-
       character(12) :: name3d, name2d
       common /avgblc/ name3d(n3dvar), name2d(n2dvar+1)
+      character(10) :: mapt(nt), mapta(nt)
+      common /avgblc/ mapta
 
 !     imav    =  number of points in longitude on the "averaging" grid
 !     jmav    =  number of points in latitude on the "averaging" grid
@@ -284,17 +281,18 @@
       include "scalar.h"
       include "switch.h"
       include "tmngr.h"
+      include "calendar.h"
 
       dimension varu(imtkm,jmw,2), w(imtkm)
       dimension vart(imtkm,jmw,n3dtra)
       dimension stf(imt,1:jmw,nt), smf(imt,1:jmw,2)
       real tmask(imt,km), umask(imt,km)
-      character(80) :: ftavg, file_stamp
-      save ftavg
-      data ftavg /' '/
 
+      character(120) :: fname
       integer ntrec
 
+      mapta(:) =  mapt(:)
+
 !-----------------------------------------------------------------------
 !     only process those "jrows" that are on the "averaging" grid
 !-----------------------------------------------------------------------
@@ -370,6 +368,10 @@
 !-----------------------------------------------------------------------
 
       rnavgt = c1/navgts
+
+      rnta_conv = 0.
+      if (nta_conv .gt. 0) rnta_conv = c1/nta_conv
+
       do jj=1,jmtav
 
 !       construct the time average
@@ -386,15 +388,19 @@
           enddo
         enddo
 
-        ntrec = 1
-        if (jj .eq. 1) then
-          if (ftavg .eq. ' ') ntrec = 0
+        do k=1,km
+          do i=2,imtav
+            ta_vetiso(i,k,jj+1) = rnavgt*ta_vetiso(i,k,jj+1)
+            ta_vntiso(i,k,jj+1) = rnavgt*ta_vntiso(i,k,jj+1)
+            ta_vbtiso(i,k,jj+1) = rnavgt*ta_vbtiso(i,k,jj+1)
+          enddo
+        enddo
 
-          if (ftavg .eq. ' ')
-     &      ftavg = file_stamp('time_mean',stamp,'.nc')
-
-          avgper = dtts*navgts/86400.0
-        endif
+        do i=2,imtav
+          ta_totalk(i,jj+1) = rnta_conv*ta_totalk(i,jj+1)
+          ta_vdepth(i,jj+1) = rnta_conv*ta_vdepth(i,jj+1)
+          ta_pe(i,jj+1) = rnta_conv*ta_pe(i,jj+1)
+        enddo
 
         tmask(:,:) = c0
         umask(:,:) = c0
@@ -403,25 +409,36 @@
           if (kmu(i,jj+1) .gt. 0) umask(i,1:kmt(i,jj+1)) = c1
         enddo
 
+        ntrec = 1
+        avgper = dtts*navgts/daylen
         is = 1
         ie = imt
-        call ocn_snap_out (ftavg, is, ie, jj+1, jj+1, imt, jmt, km, nt
+        time = relyr + year0
+        if (jj .eq. 1) call def_tavg
+        call def_tavg_mom (fname)
+        call mom_snap_out (fname, is, ie, jj+1, jj+1, imt, jmt, km, nt
      &,                    xt, yt, zt, xu, yu, zw, dxt, dyt, dzt, dxu
-     &,                    dyu, dzw, ntrec, timunit, expnam, avgper
-     &,                    relyr, stamp
-     &,                    avg3d(1:imkmav,1:nt), avg3d(1:imkmav,nt+1)
-     &,                    avg3d(1:imkmav,nt+2), avg3d(1:imkmav,nt+3)
-     &,                    avg2d(is:ie,1:nt), avg2d(is:ie,nt+1)
-     &,                    avg2d(is:ie,nt+2)
+     &,                    dyu, dzw, avgper, time, stamp, mapta
+     &,                    avg3d(1,1), avg3d(1,nt+1), avg3d(1,nt+2)
+     &,                    avg3d(1,nt+3), avg2d(is,1), avg2d(is,nt+1)
+     &,                    avg2d(is,nt+2)
 
-     &,                    avg2d(is:ie,nt+3)
+     &,                    ta_vetiso(is,1,jj+1), ta_vntiso(is,1,jj+1)
+     &,                    ta_vbtiso(is,1,jj+1)
 
-     &,                    kmt(is:ie,jj+1), mskhr(is:ie,jj+1)
-     &,                    tmask(is:ie,1:km), umask(is:ie,1:km))
+     &,                    ta_totalk(is,jj+1), ta_vdepth(is,jj+1)
+     &,                    ta_pe(is,jj+1)
+
+     &,                    avg2d(is,nt+3)
+
+     &,                    kmt(is,jj+1), mskhr(is,jj+1)
+     &,                    tmask(is,1), umask(is,1)
+     &,                    tlat(is,jj+1), tlon(is,jj+1)
+     &,                    ulat(is,jj+1), ulon(is,jj+1), ntrec)
 
         if (jj .eq. 1)
      &    write (stdout,'(a,i4,a,a,a,i10,a,a)') '=> Ocn time means #'
-     &,     ntrec, ' written to ',trim(ftavg),' on ts = ',itt, ', '
+     &,     ntrec, ' written to ',trim(fname),' on ts = ',itt, ', '
      &,     stamp
 
 !-----------------------------------------------------------------------
@@ -442,12 +459,22 @@
 
       enddo
 
+      ta_vetiso(:,:,:) = c0
+      ta_vntiso(:,:,:) = c0
+      ta_vbtiso(:,:,:) = c0
+
+      ta_totalk(:,:) = c0
+      ta_vdepth(:,:) = c0
+      ta_pe(:,:) = c0
+
 !-----------------------------------------------------------------------
 !     zero out the "averaging" counter for the next averaging period
 !-----------------------------------------------------------------------
 
       navgts = 0
 
+      nta_conv = 0
+
       return
 
       entry avgi
@@ -460,6 +487,8 @@
       navgts = 0
       navgp  = 0
 
+      nta_conv = 0
+
 !-----------------------------------------------------------------------
 !     setup the "averaging" grid (data will be time averaged only on
 !     these grid cells)
@@ -500,6 +529,14 @@
         enddo
       enddo
 
+      ta_vetiso(:,:,:) = c0
+      ta_vntiso(:,:,:) = c0
+      ta_vbtiso(:,:,:) = c0
+
+      ta_totalk(:,:) = c0
+      ta_vdepth(:,:) = c0
+      ta_pe(:,:) = c0
+
       return
       end
 
