@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/timeavgs.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/timeavgs.h
 !====================== include file "timeavgs.h" ======================
 
 !     imtav =  # of longitudes used for the time averages grid
@@ -7,10 +7,10 @@
 
       parameter (imtav=imt, jmtav=jmt-2, kmav=km)
 
-!     ta_vetiso = time averaged adv_vetiso
-!     ta_vntiso = time averaged adv_vntiso
-!     ta_vbtiso = time averaged adv_vbtiso
-
       common /ta_gm_r/ ta_vetiso(imt,km,jmt), ta_vntiso(imt,km,jmt)
       common /ta_gm_r/ ta_vbtiso(imt,km,jmt)
 
+      common /ta_conv_i/ nta_conv
+      common /ta_conv_r/ ta_totalk(imt,jmt), ta_vdepth(imt,jmt)
+      common /ta_conv_r/ ta_pe(imt,jmt)
+
