@@ -1,9 +1,9 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/timeinterp.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/timeinterp.F
       subroutine timeinterpi (nrec, stamp1, aprec, tdrec, isbcstart
      &,                       period)
 
 !=======================================================================
-!     initializes time center of each data record based on the time
+!     initializes time centre of each data record based on the time
 !     stamp and average period.
 
 !     based on code by: C. H. Goldberg and R. C. Pacanowski
@@ -16,7 +16,7 @@
       data isbcend /0/
       save isbcend
 
-!     define each climatological data record to be at the center of the
+!     define each climatological data record to be at the centre of the
 !     month starting with month "isbcmonth"
 
       sum = 0.0
@@ -61,8 +61,8 @@
 
 !     tdrec  = the times at which the data records in the dataset are
 !              defined. times must be monotonically increasing and are
-!              assumed to be at the centers of the averaging periods.
-!              (eg: the centers of the months if using monthly averaged
+!              assumed to be at the centres of the averaging periods.
+!              (eg: the centres of the months if using monthly averaged
 !               climatology. units are arbitrary)
 
 !     aprec  = array of averaging periods for the data records
@@ -269,7 +269,7 @@
       else
 
 !-----------------------------------------------------------------------
-!     anyting else is not allowed for (unless you want to add one!)
+!     anything else is not allowed for (unless you want to add one!)
 !-----------------------------------------------------------------------
 
         print *,'=>Error: method = ',method,' not allowed in timeinterp'
@@ -285,7 +285,7 @@
         print *,' ic=',ic,' io=',io, ' dtmid=',dtmid,' dtbnd=',dtbnd
      &,' dtomid=',dtomid, ' time=',time, ' ia=',ia,' ib=',ib
      &, ' wc=',wc
-        print *,' =>Error: bad interpolation wieght in timeinterp'
+        print *,' =>Error: bad interpolation weight in timeinterp'
         stop
       endif
 
@@ -307,7 +307,7 @@
       subroutine checkinterp (ntdrec, tdrec, aprec)
 
 !=======================================================================
-!     check for consistency between interpolation period centers "tdrec"
+!     check for consistency between interpolation period centres "tdrec"
 !     and period lengths "aprec".
 !     adjust tdrec and aprec for leap years
 !     check for and compensate for some mismatches between data and
@@ -332,7 +332,7 @@
           error = .true.
           write (stdout,*) 'Error in time interpolation data'
           write (stdout,*) 'Date for middle of record ',m
-     &,                   ' is not centered'
+     &,                   ' is not centred'
         endif
         if (.not.(28.0 .le. aprec(m) .and. aprec(m) .le. 32)) then
           monthly = .false.
