@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/tmngr.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/tmngr.F
 !=======================================================================
 
 !               T I M E      M A N A G E R   M O D U L E
@@ -64,10 +64,8 @@
 !     write time stamps on a data set prepared by a user-written
 !     program, might find some of them useful.
 
-!     authors: c. h. goldberg         chg@gfdl.gov
-!              d. j. goldberg
-!             (an improved version (to eliminate roundoff) of the time
-!              manager written by r.c. pacanowski and k. dixon)
+!     based on code by: C. H. Goldberg, D. J. Goldberg,
+!                       R. C. Pacanowski and K. Dixon)
 
 !=======================================================================
 
@@ -81,13 +79,14 @@
 !     for externally defined times (initial conditions, user reference
 !     and model time at start of run).
 
-!     author: c. h. goldberg         chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
       include "switch.h"
       include "tmngr.h"
       include "calendar.h"
+
       character(*) :: rununits0
 
       integer icyear, icmonth, icday, ichour, icmin, icsec
@@ -105,7 +104,7 @@
      &            yrlen, daypm, msum, dayname, monname, error)
       if (error) then
         stop 'badcal'
-      end if
+      endif
 
 !-----------------------------------------------------------------------
 !     enter and print initial date and time and check bounds.
@@ -119,7 +118,7 @@
       call ckdate (initial, error)
       if (error) then
         stop '=>tmngri'
-      end if
+      endif
 
 !----------------------------------------------------------------------
 !     set model time counter.
@@ -149,10 +148,10 @@
 !       dayoyr = days since start of current year
 !-----------------------------------------------------------------------
 
-      dayoyr = dayofyear(itime) - 1 + (msday(itime)/86400000.0)
-      relyr  = year(itime) - year(initial) + dayoyr/daysinyear(itime) -
-     &         (dayofyear(initial) - 1 + (msday(initial)/86400000.0))/
-     &         daysinyear(initial)
+      dayoyr = dayofyear(itime) - 1 + (msday(itime)/(daylen*1000.0))
+      relyr  = year(itime) - year(initial) + dayoyr/daysinyear(itime)
+     &       - (dayofyear(initial) - 1
+     &       + (msday(initial)/(daylen*1000.0)))/daysinyear(initial)
       prelyr = relyr
 
       write (stdout,9000) 'Start of Run: ', tstamp(irunstart)
@@ -229,7 +228,7 @@
       call settime2 (isunday, 0, 0)
       if (timeless (initial, isunday)) then
         iday(isunday) = 14*int(iday(initial)/14) - 14
-      end if
+      endif
 
 !-----------------------------------------------------------------------
 !     initialize idt as "timestep" rounded to the nearest millisecond
@@ -289,11 +288,8 @@
 !       relyr  = model time in years since initial conditions
 !       dayoyr = days + fractional days since start of calendar year
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
-!             (an improved version (to eliminate roundoff) of the time
-!              manager written by r.c. pacanowski and k. dixon)
-
+!     based on code by: C. H. Goldberg, D. J. Goldberg,
+!                       R. C. Pacanowski and K. Dixon)
 !=======================================================================
 
       include "stdunits.h"
@@ -358,7 +354,7 @@
       call subtime (itime, initial, imodeltime)
       if (refuser) then
         call subtime (itime, iuser, iusertime)
-      end if
+      endif
 
 !-----------------------------------------------------------------------
 !     calculate real output quantities:
@@ -366,10 +362,10 @@
 !       dayoyr = days since start of current year
 !-----------------------------------------------------------------------
 
-      dayoyr = dayofyear(itime) - 1 + (msday(itime)/86400000.0)
-      relyr  = year(itime) - year(initial) + dayoyr/daysinyear(itime) -
-     &         (dayofyear(initial) - 1 + (msday(initial)/86400000.0))/
-     &         daysinyear(initial)
+      dayoyr = dayofyear(itime) - 1 + (msday(itime)/(daylen*1000.))
+      relyr  = year(itime) - year(initial) + dayoyr/daysinyear(itime)
+     &       - (dayofyear(initial) - 1
+     &       + (msday(initial)/(daylen*1000.)))/daysinyear(initial)
 
       return
       end
@@ -390,13 +386,12 @@
 !     outputs:
 !        yrlen   = length of year in days
 !        daypm   = days per month
-!        msum    = accululated days per month
+!        msum    = accumulated days per month
 !        dayname = character day names
 !        monname = character month names
 !        error   = .t. if something went wrong
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -480,8 +475,7 @@
 !     at present, one extra day is allowed in month 2, even if year is
 !     not a leap year or if there are no leap years.
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -541,8 +535,7 @@
 !       ndim   = number of days in the current month
 !       ndiy   = number of days in the current year
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !======================================================================
 
       include "calendar.h"
@@ -573,7 +566,7 @@
 
 !-----------------------------------------------------------------------
 !     convert to days after january 1, 1601 using a virtual calendar
-!     consistent with current leap-year systems to extend backwards.
+!     consistent with current leap-year systems to extend backward.
 !     (ie. 1700, 1800, 1900 are not considered leap-years but 2000
 !     is a leap-year)
 !-----------------------------------------------------------------------
@@ -583,7 +576,7 @@
 
 !-----------------------------------------------------------------------
 !     make corrections for years before 1601 (assuming modern leap year
-!     conventions)  note that 400 years doesn`t affect the day of the
+!     conventions)  note that 400 years does not affect the day of the
 !     week.   146097 days = 20871 weeks exactly.
 !-----------------------------------------------------------------------
 
@@ -594,7 +587,7 @@
       endif
 
 !-----------------------------------------------------------------------
-!     peel off year.  Acurate from before Jan 1, 1900 until the
+!     peel off year.  Accurate from before Jan 1, 1900 until the
 !     julian day overflows machine limitations.
 !----------------------------------------------------------------------
 
@@ -677,8 +670,7 @@
 !       ndim   = number of days in the current month
 !       ndiy   = number of days in the current year
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !======================================================================
       include "calendar.h"
 
@@ -697,7 +689,7 @@
         iyr = (inday / yrlen) - 1
       else
         iyr = (inday - 1) / yrlen
-      end if
+      endif
       iyear = iyr + 1900
       idoy  = inday - yrlen*iyr
 
@@ -745,8 +737,7 @@
 !       ndim   = number of days in the current month
 !       ndiy   = number of days in the current year
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !======================================================================
 
       include "calendar.h"
@@ -760,7 +751,7 @@
       if (eqyear) then
         call ymd2dc (iyear, imonth, iday, nday, idoy, idow, ndim, ndiy)
         return
-      end if
+      endif
 
       if (mod (iyear, 400) .eq. 0) then
         leap = .true.
@@ -795,7 +786,7 @@
 !-----------------------------------------------------------------------
 !     correct for leap-years between 1601 and iyear-1.
 !     A virtual calendar consistent with current leap-year systems
-!     is used to extend backwards.  (ie. 1700, 1800, 1900 are not
+!     is used to extend backward.  (ie. 1700, 1800, 1900 are not
 !     considered leap-year but 2000 is a leap-year)
 !-----------------------------------------------------------------------
 
@@ -816,7 +807,7 @@
       ndim = daypm(imonth)
       if (leap .and. (imonth .eq. 2)) then
         ndim = ndim + 1
-      end if
+      endif
 
       return
       end
@@ -843,8 +834,7 @@
 !       ndim   = number of days in the current month
 !       ndiy   = number of days in the current year
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "calendar.h"
@@ -863,8 +853,8 @@
 !=======================================================================
 !     make a 32 character time stamp from day,month,year,sec,min,hour
 !     writes an i5 or i9 year in y/m/d, d/m/y or m/d/y format
-!     based on code by:  R.C. Pacanowski     e-mail=>  rcp@gfdl.gov
-!     author:            M. Eby              e-mail=>  eby@uvic.ca
+
+!     based on code by: R.C. Pacanowski and M. Eby
 !=======================================================================
 
       integer year, month, day, hour, min, sec, y, yr
@@ -896,8 +886,8 @@
 !=======================================================================
 !     convert 32 character time stamp into day,month,year,sec,min,hour
 !     reads stamp of form y/m/d, d/m/y or m/d/y (for many year lengths)
-!     based on code by:  R.C. Pacanowski     e-mail=>  rcp@gfdl.gov
-!     author:            M. Eby              e-mail=>  eby@uvic.ca
+
+!     based on code by: R.C. Pacanowski and M. Eby
 !=======================================================================
 
       character(32) :: stamp
@@ -981,15 +971,14 @@
 !=======================================================================
 !     add day, month and year information from "stamp" to "fname"
 !     writes year as 5 or 9 characters padded with zeros.
-!     based on code by:  R.C. Pacanowski     e-mail=>  rcp@gfdl.gov
-!     author:            M. Eby              e-mail=>  eby@uvic.ca
+!     based on code by: R.C. Pacanowski and M. Eby
 !=======================================================================
 
       character(*) :: fname, stamp, suffix
       character(3) :: dd(1:31)
       character(3) :: mm(1:12)
       character(10) :: yy
-      character(80) :: file_stamp
+      character(120) :: file_stamp
 
       integer year, month, day, hour, min, sec
 
@@ -1047,13 +1036,15 @@
 !     output:
 !      stamp2 = stamp1 incremented by days
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
+
       character(*) :: stamp1, stamp2
       call settimefromstamp (stamp1, itemptime)
-      call settime2 (itemptime2, id(days*86400.0), msec(days*86400.0))
+      call settime2 (itemptime2, id(days*daylen), msec(days*daylen))
       call addtime (itemptime, itemptime2, itemptime)
       call expandtime2 (itemptime)
       stamp2 = tstamp(itemptime)
@@ -1070,11 +1061,13 @@
 !     output:
 !      time arrays for index2 (year, month, day, etc) in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
-      call settime2 (itemptime, id(days*86400.0), msec(days*86400.0))
+      include "calendar.h"
+
+      call settime2 (itemptime, id(days*daylen), msec(days*daylen))
       call addtime (index1, itemptime, index2)
       call expandtime2 (index2)
       return
@@ -1088,7 +1081,7 @@
 !     output:
 !      time arrays for index (year, month, day, etc) in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       character(*) :: stamp
@@ -1108,17 +1101,18 @@
 !      iday(index) = integer day number of answer in tmngr.h
 !      msday(index)= millisec fractional day of answer in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
 
       mst = msday(index1) + msday(index2)
       it  = iday(index1) + iday(index2)
-      if (mst .ge. 86400000) then
-        mst = mst - 86400000
+      if (mst .ge. int(daylen*1000.)) then
+        mst = mst - int(daylen*1000.)
         it  = it + 1
-      end if
+      endif
       iday(index) = it
       msday(index) = mst
 
@@ -1136,17 +1130,18 @@
 !      iday(index) = integer day number of answer in tmngr.h
 !      msday(index)= millisec fractional day of answer in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
 
       mst = msday(index1) - msday(index2)
       it  = iday(index1) - iday(index2)
       if (mst .lt. 0) then
-        mst = mst + 86400000
+        mst = mst + int(daylen*1000.)
         it = it - 1
-      end if
+      endif
       iday(index)  = it
       msday(index) = mst
 
@@ -1164,17 +1159,19 @@
 !      iday(index) = integer day number of answer in tmngr.h
 !      msday(index)= millisec fractional day of answer in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
 
-      double precision dmst
+      double precision dmst, dayl
 
+      dayl = daylen*1000.
       dmst = n*dble(msday(index1))
       it   = n*iday(index1)
-      it   = it + int(dmst/86400000.0d0)
-      mst  = nint(mod (dmst, 86400000.0d0))
+      it   = it + int(dmst/dayl)
+      mst  = nint(mod (dmst, dayl))
       iday(index)  = it
       msday(index) = mst
 
@@ -1185,7 +1182,7 @@
 !=======================================================================
 !     converts fraction of a day in milliseconds to hour/min/sec
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       integer ms, hour, min, sec
@@ -1202,7 +1199,7 @@
 !=======================================================================
 !     converts fraction of a day in hour/min/sec to milliseconds
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       integer hms2ms, hour, min, sec
@@ -1217,7 +1214,7 @@
 !     f90 intrinsic "floor"
 !     largest integer less than or equal to realvalue
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       iflr = int(realvalue) -1
@@ -1231,10 +1228,12 @@
 !     converts time in real seconds to the integer day part
 !     see also "msec"
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
-      id = ifloor(realsec/86400.0)
+      include "calendar.h"
+
+      id = ifloor(realsec/daylen)
 
       return
       end
@@ -1244,10 +1243,12 @@
 !     extracts integer milliseconds from time in real seconds
 !     see also "id"
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
-      msec = nint (1000.0*(realsec-86400.0*id(realsec)))
+      include "calendar.h"
+
+      msec = nint (1000.0*(realsec-daylen*id(realsec)))
 
       return
       end
@@ -1258,12 +1259,13 @@
 !     input:
 !      index = index of any time in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
 
-      realsecs = 86400.0*iday(index) + msday(index)/1000.0
+      realsecs = daylen*iday(index) + msday(index)/1000.0
 
       return
       end
@@ -1274,12 +1276,13 @@
 !     input:
 !      index = index of any time in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
+      include "calendar.h"
 
-      realdays = iday(index) + msday(index)/86400000.0
+      realdays = iday(index) + msday(index)/(daylen*1000.)
 
       return
       end
@@ -1290,14 +1293,14 @@
 !     similar to mod, but remainder has sign of n.
 !     always gives positive remainder when n .gt. 0, even if m .lt. 0
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       if (m .ge. 0) then
         modulo = mod(m,n)
       else
         modulo = abs(n) - mod(-m-1,n) - 1
-      end if
+      endif
 
       return
       end
@@ -1306,7 +1309,7 @@
 !=======================================================================
 !     initialize time indices for gettime and getfulltime.
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "tmngr.h"
@@ -1325,7 +1328,7 @@
 !     output:
 !      index = index of a full time in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1350,7 +1353,7 @@
 !     output:
 !      index = index of a short time (iday, msday only) in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1378,7 +1381,7 @@
 !     output:
 !      full time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1415,7 +1418,7 @@
 !     output:
 !      short time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1442,18 +1445,19 @@
 !     output:
 !      short time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
       include "tmngr.h"
+      include "calendar.h"
 
       logical badindex
 
-      if (mst .ge. 86400000 .or. mst .lt. 0) then
+      if (mst .ge. int(daylen*1000.) .or. mst .lt. 0) then
         write (stdout, *) '     Invalid millisecond designation'
         stop 'settime2'
-      end if
+      endif
       if (badindex (index,  'short')) stop 'settime2'
       iday(index)  = it
       msday(index) = mst
@@ -1470,18 +1474,19 @@
 !     output:
 !      short time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
       include "tmngr.h"
+      include "calendar.h"
 
       logical badindex
 
       if (badindex (index,  'short')) stop 'settime3'
 
-      iday(index)  = id(rd*86400.0)
-      msday(index) = msec(rd*86400.0)
+      iday(index)  = id(rd*daylen)
+      msday(index) = msec(rd*daylen)
 
       return
       end
@@ -1498,7 +1503,7 @@
 !     output:
 !      full time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1533,7 +1538,7 @@
 !     output:
 !      full time fields set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1568,7 +1573,7 @@
 !     output:
 !      full time fields (iday,msday, tstamp) set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1599,7 +1604,7 @@
 !      full time fields (year,month,day,hour,minute,second,tstamp)
 !      set for index in tmngr.h
 
-!     author:  c. h. goldberg       chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1624,8 +1629,7 @@
 !     compare times referenced by index1 and index2.  timeless is
 !     true if time1 is less than time2.
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1642,7 +1646,7 @@
         timeless = .true.
       else
         timeless = .false.
-      end if
+      endif
 
       return
       end
@@ -1652,8 +1656,7 @@
 !     compare times referenced by index1 and index2.  timeequal is
 !     true if time1 is equal to  time2.
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1668,7 +1671,7 @@
         timeequal = .true.
       else
         timeequal = .false.
-      end if
+      endif
 
       return
       end
@@ -1678,8 +1681,7 @@
 !     compare times referenced by index1 and index2.  timemore is
 !     true if time1 is more than time2.
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1696,7 +1698,7 @@
         timemore = .true.
       else
         timemore = .false.
-      end if
+      endif
 
       return
       end
@@ -1707,8 +1709,7 @@
 !     type = 'full'  means a full time
 !     type = 'short' means a short time
 
-!     authors: c. h. goldberg        chg@gfdl.gov
-!              d. j. goldberg
+!     based on code by: C. H. Goldberg, D. J. Goldberg
 !=======================================================================
 
       include "stdunits.h"
@@ -1723,15 +1724,15 @@
           print *, '     Invalid full time index = ',index
         else
           badindex = .false.
-        end if
+        endif
       else
         if (index .lt. 1 .or. index .gt. ntimes) then
           badindex = .true.
           print *, '     Invalid time index = ',index
         else
           badindex = .false.
-        end if
-      end if
+        endif
+      endif
 
       return
       end
