@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/tmngr.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/tmngr.h
 !======================= include file "tmngr.h" ========================
 
 !                       time manager variables
@@ -19,7 +19,7 @@
 !              periods per month of approximately 10 days each. the
 !              only restriction is that "timavgint"is an integral number
 !              of time steps (if not then "timavgint" is reset to insure
-!              this condition. other diagonstic switches do not have
+!              this condition. other diagnostic switches do not have
 !              this restriction).
 
 !     refinit = (true, false) for basing calculation of logical switches
@@ -144,7 +144,7 @@
 !-----------------------------------------------------------------------
 
       integer ntimes, nfulltimes
-      parameter (ntimes = 100, nfulltimes = 20)
+      parameter (ntimes = 100, nfulltimes = 30)
 
       character(32) :: tstamp, stamp, pstamp
       character(120) :: timunit
