@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/tracer.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/tracer.F
       subroutine tracer (joff, js, je, is, ie)
 
 !=======================================================================
@@ -31,11 +31,17 @@
       include "mw.h"
       include "scalar.h"
       include "switch.h"
+      include "timeavgs.h"
+      include "tmngr.h"
       include "vmixc.h"
       dimension twodt(km)
 
       include "fdift.h"
 
+      include "diaga.h"
+
+      include "ice.h"
+
 !-----------------------------------------------------------------------
 !     bail out if starting row exceeds ending row
 !-----------------------------------------------------------------------
@@ -214,6 +220,18 @@
         enddo
       enddo
 
+      if (timavgperts .and. eots) then
+        if (joff .eq. 0) nta_conv = nta_conv + 1
+        do j=js,je
+          jrow = j + joff
+          do i=istrt,iend
+            ta_totalk(i,jrow) = ta_totalk(i,jrow) + totalk(i,j)
+            ta_vdepth(i,jrow) = ta_vdepth(i,jrow) + vdepth(i,j)
+            ta_pe(i,jrow) = ta_pe(i,jrow) + pe(i,j)
+          enddo
+        enddo
+      endif
+
 !-----------------------------------------------------------------------
 !     construct diagnostics after convection
 !-----------------------------------------------------------------------
@@ -255,7 +273,7 @@
       call asbct (joff, js, je, istrt, iend, isst, itemp)
       call asbct (joff, js, je, istrt, iend, isss, isalt)
 
-      call asbct (joff, js, je, istrt, iend, issc, idic)
+      call asbct (joff, js, je, istrt, iend, issdic, idic)
 
       return
       end
@@ -302,7 +320,6 @@
       dimension temp1(imt,km), temp2(imt,km), temp3(imt,km)
 
       dimension twodt(km)
-
       include "fdift.h"
 
 !-----------------------------------------------------------------------
@@ -501,7 +518,7 @@
 !     based on code by: R. C. Pacanowski
 !-----------------------------------------------------------------------
 
-      include "size.h"
+      include "param.h"
       include "levind.h"
       include "mw.h"
       include "switch.h"
@@ -511,11 +528,6 @@
 !     store terms to compute implicit vertical mixing on
 !     diagnostic time steps
 
-!     set some constants
-
-      c1 = 1.0
-      c0 = 0.0
-
       if (trmbts .and. eots) then
         do j=js,je
           do k=1,km
