@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/tropic.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/tropic.F
 
       subroutine tropic (c2dtsf, acor, f, itt, dtts)
 
@@ -74,7 +74,7 @@
 !     by allowing the solvers to run to machine precision are indeed
 !     less than the stated tolerances.
 
-!     author:      c. h. goldberg      e-mail=> chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "param.h"
@@ -86,8 +86,12 @@
       include "switch.h"
       include "task_on.h"
       character(8) :: bc_symm
+      dimension f(imt,jmt)
 
-      dimension f(jmt)
+      data nconv /0/
+      save nconv
+
+      if (eoyear) nconv = 0
 
       call setbcx (zu(1,1,1), imt, jmt)
       call setbcx (zu(1,1,2), imt, jmt)
@@ -152,7 +156,7 @@
       if (imain .gt. 0) then
         dpsi1 = ptd(iperm(iofs(imain)+1), jperm(iofs(imain)+1))
         call con_adjust (ptd, dpsi1, map)
-      end if
+      endif
 
 !-----------------------------------------------------------------------
 !     test accuracy of solving for change in stream function
@@ -164,6 +168,8 @@
      &, ' scans. max(psi)='
      &, absmax(psi(1,1,2)), ' max(dpsi)=',absmax(ptd)
      &, ' estimated max(err)=', esterr
+        nconv = nconv + 1
+        if (nconv .gt. 50) stop 'nconv > 50 in tropic.f'
       endif
 
 !-----------------------------------------------------------------------
@@ -217,7 +223,7 @@
 
 !           S T R E A M   F U N C T I O N   F O R C I N G
 
-!     author:      c. h. goldberg      e-mail=> chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "size.h"
@@ -236,8 +242,8 @@
       do i=1,imt
         do jrow=1,jmt
           forc(i,jrow) = c0
-        end do
-      end do
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     construct coefficients for partial differences. a partial
@@ -290,8 +296,8 @@
         do jrow=1,jmt-1
           ustuff(i,jrow) = zu(i,jrow,1)*dxu(i)*csu(jrow)
           vstuff(i,jrow) = zu(i,jrow,2)*dyu(jrow)
-        end do
-      end do
+        enddo
+      enddo
 
       do i1=-1,0
         do j1=-1,0
@@ -300,10 +306,10 @@
               forc(i,jrow) = forc(i,jrow)
      &                     - cddyt(i1,j1)*ustuff(i+i1,jrow+j1)
      &                     + cddxt(i1,j1)*vstuff(i+i1,jrow+j1)
-            end do
-          end do
-        end do
-      end do
+            enddo
+          enddo
+        enddo
+      enddo
 
       return
       end
@@ -330,16 +336,14 @@
 
 !     coeff   = 3 x 3 array of coefficients at each (i,j) point
 
-!     author: c.h. goldberg         e-mail => chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "size.h"
       include "task_on.h"
       parameter (p5=0.5, c0=0.0)
       dimension csu(jmt), dxu(imt), dyu(jmt), hr(imt,jmt)
-
-      dimension f(jmt)
-
+      dimension f(imt,jmt)
       dimension coef(imt,jmt,-1:1,-1:1)
       dimension ustuff(imt,jmt), vstuff(imt,jmt)
       dimension cddxu(0:1,0:1), cddyu(0:1,0:1)
@@ -354,10 +358,10 @@
           do j=1,jmt
             do i=1,imt
               coef(i,j,ii,jj) = c0
-            end do
-          end do
-        end do
-      end do
+            enddo
+          enddo
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     construct coefficients for partial differences. a partial
@@ -408,8 +412,8 @@
         do j=1,jmt-1
           ustuff(i,j) = dxu(i)*csu(j)*hr(i,j) / (c2dtsf*dyu(j))
           vstuff(i,j) = dyu(j)*hr(i,j) / (c2dtsf*dxu(i)*csu(j))
-        end do
-      end do
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     calculate 5 point coefficients
@@ -429,12 +433,12 @@
      &               cddyu(i1,j1)*cddyt(i2,j2)*ustuff(i+i2,j+j2)
                   coef(i,j,i1+i2,0) = coef(i,j,i1+i2,0) +
      &               cddxu(i1,j1)*cddxt(i2,j2)*vstuff(i+i2,j+j2)
-                end do
-              end do
-            end do
-          end do
-        end do
-      end do
+                enddo
+              enddo
+            enddo
+          enddo
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     augment coefficients for implicit treatment of coriolis term
@@ -444,12 +448,10 @@
       if (acor .ne. 0.0) then
         do i=1,imt-1
           do j=1,jmt-1
-
-            ustuff(i,j) = acor*hr(i,j)*(-f(j))
-            vstuff(i,j) = acor*hr(i,j)*( f(j))
-
-          end do
-        end do
+            ustuff(i,j) = acor*hr(i,j)*(-f(i,j))
+            vstuff(i,j) = acor*hr(i,j)*( f(i,j))
+          enddo
+        enddo
         do i1=0,1
           do j1=0,1
             do i2=-1,0
@@ -460,13 +462,13 @@
      &                 - cddxu(i1,j1)*cddyt(i2,j2)*ustuff(i+i2,j+j2)
                     coef(i,j,i1+i2,j1+j2) = coef(i,j,i1+i2,j1+j2)
      &                 - cddyu(i1,j1)*cddxt(i2,j2)*vstuff(i+i2,j+j2)
-                  end do
-                end do
-              end do
-            end do
-          end do
-        end do
-      end if
+                  enddo
+                enddo
+              enddo
+            enddo
+          enddo
+        enddo
+      endif
 
       return
       end
@@ -493,16 +495,14 @@
 
 !     coeff   = 3 x 3 array of coefficients at each (i,j) point
 
-!     author: c.h. goldberg         e-mail => chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "size.h"
       include "task_on.h"
       parameter (c0=0.0, p5=0.5)
       dimension csu(jmt), dxu(imt), dyu(jmt), hr(imt,jmt)
-
-      dimension f(jmt)
-
+      dimension f(imt,jmt)
       dimension coef(imt,jmt,-1:1,-1:1)
       dimension ustuff(imt,jmt), vstuff(imt,jmt)
       dimension cddxu(0:1,0:1), cddyu(0:1,0:1)
@@ -517,10 +517,10 @@
           do j=1,jmt
             do i=1,imt
               coef(i,j,ii,jj) = c0
-            end do
-          end do
-        end do
-      end do
+            enddo
+          enddo
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     generate arrays of coefficients
@@ -573,8 +573,8 @@
         do j=1,jmt-1
           ustuff(i,j) = dxu(i)*csu(j)*hr(i,j) / (c2dtsf*dyu(j))
           vstuff(i,j) = dyu(j)*hr(i,j) / (c2dtsf*dxu(i)*csu(j))
-        end do
-      end do
+        enddo
+      enddo
 
 !---------------------------------------------------------------------
 !     calculate 9 point coefficients
@@ -589,12 +589,12 @@
                   coef(i,j,i1+i2,j1+j2) = coef(i,j,i1+i2,j1+j2) +
      &               cddyu(i1,j1)*cddyt(i2,j2)*ustuff(i+i2,j+j2)  +
      &               cddxu(i1,j1)*cddxt(i2,j2)*vstuff(i+i2,j+j2)
-                end do
-              end do
-            end do
-          end do
-        end do
-      end do
+                enddo
+              enddo
+            enddo
+          enddo
+        enddo
+      enddo
 
 !-----------------------------------------------------------------------
 !     augment coefficients for implicit treatment of coriolis term
@@ -604,12 +604,10 @@
       if (acor .ne. 0.0) then
         do i=1,imt-1
           do j=1,jmt-1
-
-            ustuff(i,j) = acor*hr(i,j)*(-f(j))
-            vstuff(i,j) = acor*hr(i,j)*( f(j))
-
-          end do
-        end do
+            ustuff(i,j) = acor*hr(i,j)*(-f(i,j))
+            vstuff(i,j) = acor*hr(i,j)*( f(i,j))
+          enddo
+        enddo
         do i1=0,1
           do j1=0,1
             do i2=-1,0
@@ -619,13 +617,13 @@
                     coef(i,j,i1+i2,j1+j2) = coef(i,j,i1+i2,j1+j2)
      &               - cddxu(i1,j1)*cddyt(i2,j2)*ustuff(i+i2,j+j2)
      &               - cddyu(i1,j1)*cddxt(i2,j2)*vstuff(i+i2,j+j2)
-                  end do
-                end do
-              end do
-            end do
-          end do
-        end do
-      end if
+                  enddo
+                enddo
+              enddo
+            enddo
+          enddo
+        enddo
+      endif
 
       return
       end
@@ -636,7 +634,7 @@
 
 !           S U R F A C E   P R E S S U R E   F O R C I N G
 
-!     author:      c. h. goldberg      e-mail=> chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "size.h"
@@ -699,14 +697,14 @@
         do j=1,jmt-1
           ustuff(i,j) = h(i,j)*zu(i,j,1)*dyu(j)
           vstuff(i,j) = h(i,j)*zu(i,j,2)*dxu(i)*csu(j)
-        end do
-      end do
+        enddo
+      enddo
 
       do i=1,imt
         do j=1,jmt
           forc(i,j) = 0.0
-        end do
-      end do
+        enddo
+      enddo
 
       do i1=-1,0
         do j1=-1,0
@@ -714,10 +712,10 @@
             do j=2,jmt-1
               forc(i,j) = forc(i,j) + cddxt(i1,j1)*ustuff(i+i1,j+j1)
      &                              + cddyt(i1,j1)*vstuff(i+i1,j+j1)
-            end do
-          end do
-        end do
-      end do
+            enddo
+          enddo
+        enddo
+      enddo
 
       return
       end
@@ -741,7 +739,7 @@
 
 !     coeff   = 3 x 3 array of coefficients at each (i,j) point
 
-!     author: c.h. goldberg         e-mail => chg@gfdl.gov
+!     based on code by: C. H. Goldberg
 !=======================================================================
 
       include "size.h"
@@ -807,10 +805,10 @@
           do i=1,imt
             do j=1,jmt
               coef(i,j,i1,j1) = c0
-            end do
-          end do
-        end do
-      end do
+            enddo
+          enddo
+        enddo
+      enddo
 
       do j=1,jmt
         do i=1,imt
@@ -822,8 +820,8 @@
         do j=1,jmt-1
           ustuff(i,j) = h(i,j)*dyu(j)/(dxu(i)*csu(j))
           vstuff(i,j) = h(i,j)*dxu(i)*csu(j)/dyu(j)
-        end do
-      end do
+        enddo
+      enddo
 
 !     calculate divergence = ddx (ddx (ustuff)) + ddy( ddy (vstuff))
 
@@ -836,12 +834,12 @@
                   coef(i,j,i1+i2,j1+j2) = coef(i,j,i1+i2,j1+j2)
      &                 + cddxu(i1,j1) * cddxt(i2,j2) * ustuff(i+i2,j+j2)
      &                 + cddyu(i1,j1) * cddyt(i2,j2) * vstuff(i+i2,j+j2)
-                end do
-              end do
-            end do
-          end do
-        end do
-      end do
+                enddo
+              enddo
+            enddo
+          enddo
+        enddo
+      enddo
 
       return
       end
