@@ -1,4 +1,4 @@
-! source file: /usr/local/models/UVic_ESCM/2.7/source/common/util.F
+! source file: /usr/local/models/UVic_ESCM/2.8/source/common/util.F
       function indp (value, array, ia)
 
 !=======================================================================
@@ -79,10 +79,10 @@
 
 !=======================================================================
 
-!     "ftc" is a nemonic for "fine to coarse".
+!     "ftc" is a mnemonic for "fine to coarse".
 
-!     obtain a coarse grid representaion of a fine grid dataset by area
-!     averaging grid boxe values on the fine grid which overlay coarse
+!     obtain a coarse grid representation of a fine grid dataset by area
+!     averaging grid box values on the fine grid which overlay coarse
 !     grid boxes. note: the coarse grid boxes do not have to contain an
 !     integral number of fine grid boxes.
 
@@ -91,8 +91,8 @@
 !     f      = data on fine grid
 !     if     = inner dimension of "f"
 !     jf     = outer dimension of "f"
-!     xf     = coordinates for inner dimension of "f" (eg: longitues)
-!     yf     = coordinates for outer dimension of "f" (eg: latitues)
+!     xf     = coordinates for inner dimension of "f" (eg: longitudes)
+!     yf     = coordinates for outer dimension of "f" (eg: latitudes)
 
 !     ic     = inner dimension of coarse grid "c"
 !     jc     = outer dimension of coarse grid "c"
@@ -104,8 +104,8 @@
 !              averaged values are desired
 !     jend   = ending index along outer dimension of "c" for which
 !              averaged values are desired
-!     xc     = coordinates for inner dimension of "c" (eg: longitues)
-!     yc     = coordinates for outer dimension of "c" (eg: latitues)
+!     xc     = coordinates for inner dimension of "c" (eg: longitudes)
+!     yc     = coordinates for outer dimension of "c" (eg: latitudes)
 !     init   = initialize the averaging factors
 !              "init" should be set = 1 on the first call.
 !              "init" <> 1 uses the previously computed factors stored
@@ -429,9 +429,9 @@
 
 !=======================================================================
 
-!     "ctf" is a nemonic for "coarse to fine".
+!     "ctf" is a mnemonic for "coarse to fine".
 
-!     obtain a fine grid representaion of a coarse grid dataset by
+!     obtain a fine grid representation of a coarse grid dataset by
 !     linear interpolation of grid box values on the coarse grid to grid
 !     boxes on the fine grid.
 
@@ -440,13 +440,13 @@
 !     c      = coarse grid data
 !     ic     = inner dimension of coarse grid "c"
 !     jc     = outer dimension of coarse grid "c"
-!     xc     = coordinates for inner dimension of "c" (eg: longitues)
-!     yc     = coordinates for outer dimension of "c" (eg: latitues)
+!     xc     = coordinates for inner dimension of "c" (eg: longitudes)
+!     yc     = coordinates for outer dimension of "c" (eg: latitudes)
 
 !     if     = inner dimension of "f"
 !     jf     = outer dimension of "f"
-!     xf     = coordinates for inner dimension of "f" (eg: longitues)
-!     yf     = coordinates for outer dimension of "f" (eg: latitues)
+!     xf     = coordinates for inner dimension of "f" (eg: longitudes)
+!     yf     = coordinates for outer dimension of "f" (eg: latitudes)
 
 !     istart = starting index along inner dimension of "f" for which
 !              interpolated values are desired
@@ -466,7 +466,7 @@
 
 !     output:
 
-!     f      = interplated data on fine grid defined over
+!     f      = interpolated data on fine grid defined over
 !              ((f(i,j),i=istart,iend),j=jstart,jend)
 !     work   = work array of interpolation factors when "init" = 1
 
@@ -697,10 +697,10 @@
 
 !-----------------------------------------------------------------------
 
-!     solve a simple poisson eqn by relaxation to extrapolate data into
+!     solve a simple Poisson eqn by relaxation to extrapolate data into
 !     land areas using values over non land areas as boundary values.
 
-!     note: sucessive calls to extrap will require fewer scans beacuse
+!     note: successive calls to extrap will require fewer scans because
 !           the initial guess field over land areas gets better with
 !           each call.
 !-----------------------------------------------------------------------
@@ -881,8 +881,8 @@
      & ' => Note: there are ',maxint-minint+1,' integers in the field'
         write (stdout,*) '          "iplot" cannot uniquely assign '
      &,' more than 120 characters for plotting symbols.'
-        write (stdout,*) '          therfore integers are'
-     &, ' represented by cyclicly reusing the list of plotting symbols'
+        write (stdout,*) '          therefore integers are '
+     &, 'represented by cyclically reusing the list of plotting symbols'
         write (stdout,*) '   '
       endif
 
@@ -1376,7 +1376,7 @@
 !     longitude to remove the jump in
 !     longitudes (358.5 359.5, 0.5, 1.5) across the meridian before
 !     interpolating to the model grid. This is only of concern in
-!     limited domain grids (e.g. atlantic basin) that contain the
+!     limited domain grids (e.g. Atlantic basin) that contain the
 !     prime meridian.
 
 !     translate longitudes  "cx" to "tx" so that tx(i) i=1..ic
@@ -1445,7 +1445,7 @@
 !     calculate the area weighted total of data
 
 !     input:
-!       data = data to be totaled
+!       data = data to be totalled
 !       dmsk = data mask
 !     output:
 !       tot = area weighted total of the data
