@@ -1,3 +1,4 @@
+! source file: /usr/local/models/UVic_ESCM/2.8/source/netcdf/uvic_netcdf.f
       subroutine opentime (fname, relyr, ntrec, ncid)
 !=======================================================================
 !     open file for reading or writing at record of relyr
@@ -6,7 +7,7 @@
 !       fname = file name to be opened
 !       relyr = relative year
 !     output:
-!       ntrec = rexcord number of relyr (next if relyr is not found)
+!       ntrec = record number of relyr (next if relyr is not found)
 !       ncid  = iou unit
 
 !     based on code by: M. Eby
@@ -46,6 +47,7 @@
       call checkerror (i,'opentime  nf_inq_vardimid'//trim(name))
       i = nf_inq_dimlen (ncid, id, ln)
       call checkerror (i,'opentime  nf_inq_dimlen'//trim(name))
+      if (ln .le. 0) return
       allocate (time(ln))
 !     find ntrec of relyr or next if relyr is not found
       i = nf_get_var_double (ncid, iv, time)
@@ -108,6 +110,7 @@
       call checkerror (i,'opennext  nf_inq_vardimid'//trim(name))
       i = nf_inq_dimlen (ncid, id, ln)
       call checkerror (i,'opennext  nf_inq_dimlen'//trim(name))
+      if (ln .le. 0) return
 !     get next record or last if last is relyr
       i = nf_get_vara_double (ncid, iv, ln, 1, time)
       call checkerror (i,'opennext nf_get_vara_double time')
@@ -215,7 +218,7 @@
 
       subroutine redef (ncid)
 !=======================================================================
-!     redifine
+!     redefine
 
 !     input:
 !       ncid = iou unit
@@ -318,102 +321,9 @@
       return
       end
 
-      subroutine putglobal (ncid, name, title, expnam, timunit)
-!=======================================================================
-!     put global atributes
-
-!     input:
-!       ncid    = iou unit
-!       name    = file name
-!       title   = file title
-!       expnam  = experiment name
-!       timunit = timunit
-
-!     based on code by: M. Eby
-!=======================================================================
-
-      implicit none
-
-      include 'netcdf.inc'
-
-      character(*), intent(in) :: name, title, expnam, timunit
-
-      integer, intent(in) :: ncid
-      integer i
-
-      i = nf_put_att_text (ncid, nf_global, 'Conventions'                                                                             &
-     &, len('CF-1.0'), 'CF-1.0')
-      call checkerror(i,'putglobal conventions '//trim(name))
-
-      if (len(trim(name)) .ne. 0) then
-        i = nf_put_att_text (ncid, nf_global, 'file_name'                                                                              &
-     &,   len(trim(name)), trim(name))
-        call checkerror(i,'putglobal file_name '//trim(name))
-      endif
-
-      if (len(trim(title)) .ne. 0) then
-        i = nf_put_att_text (ncid, nf_global, 'title'                                                                                  &
-     &,   len(trim(title)), trim(title))
-        call checkerror (i,'putglobal title '//trim(name))
-      endif
-
-      if (len(trim(expnam)) .ne. 0) then
-        i = nf_put_att_text (ncid, nf_global, 'experiment_name'                                                                        &
-     &,   len(trim(expnam)), trim(expnam))
-        call checkerror (i,'putglobal experiment_name '//trim(name))
-      endif
-
-      if (len(trim(timunit)) .ne. 0) then
-        i = nf_put_att_text (ncid, nf_global, 'time_unit'                                                                              &
-     &,   len(trim(timunit)), trim(timunit))
-        call checkerror (i,'putglobal time_unit '//trim(name))
-      endif
-
-      return
-      end
-
-      subroutine getglobal (ncid, name, title, expnam, timunit)
-!=======================================================================
-!     get global atributes
-
-!     input:
-!       ncid   = iou unit
-!     output
-!       name    = file name
-!       title   = file title
-!       expnam  = experiment name
-!       timunit = timunit
-
-!     based on code by: M. Eby
-!=======================================================================
-
-      implicit none
-
-      include 'netcdf.inc'
-
-      character(*), intent(out) :: name, title, expnam, timunit
-
-      integer, intent(in) :: ncid
-      integer i
-
-      i = nf_get_att_text (ncid, nf_global, 'file_name', name)
-      if (i .ne. nf_noerr) print*,'getglobal: file_name not found'
-
-      i = nf_get_att_text (ncid, nf_global, 'title', title)
-      if (i .ne. nf_noerr) print*,'getglobal: title not found'
-
-      i = nf_get_att_text (ncid, nf_global, 'experiment_name', expnam)
-      if (i .ne. nf_noerr) print*,'getglobal: experiment_name not found'
-
-      i = nf_get_att_text (ncid, nf_global, 'time_unit', timunit)
-      if (i .ne. nf_noerr) print*,'getglobal: time_unit not found'
-
-      return
-      end
-
       subroutine putatttext (ncid, var, name, text)
 !=======================================================================
-!     put text atribute
+!     put text attribute
 
 !     input:
 !       ncid = iou unit
@@ -434,13 +344,13 @@
       integer i, iv
 
       if (var .eq. "global" .or. var .eq. "Global") then
-        i = nf_put_att_text (ncid, nf_global, trim(name)                                                                               &
+        i = nf_put_att_text (ncid, nf_global, trim(name)                                                                             &
      &,   len(trim(text)), trim(text))
         call checkerror(i,'putatttext global '//trim(name))
       else
         i = nf_inq_varid (ncid, var, iv)
         call checkerror (i,'putatttext nf_inq_varid '//trim(var))
-        i = nf_put_att_text (ncid, iv, trim(name)                                                                               &
+        i = nf_put_att_text (ncid, iv, trim(name)                                                                                    &
      &,   len(trim(text)), trim(text))
         call checkerror(i,'putatttext '//trim(var)//' '//trim(name))
       endif
@@ -450,7 +360,7 @@
 
       subroutine getatttext (ncid, var, name, text)
 !=======================================================================
-!     get text atribute
+!     get text attribute
 
 !     input:
 !       ncid = iou unit
@@ -677,6 +587,9 @@
         i = nf_put_att_double (ncid,iv,'fill_value',nf_double,1                                                                      &
      &,   nf_fill_double)
         call checkerror (i,'defvar fill_value double '//trim(name))
+        call checkerror (i,'defvar missing_value double '//trim(name))
+        i = nf_put_att_double (ncid,iv,'missing_value',nf_double,1                                                                   &
+     &,   nf_fill_double)
 
       elseif (type .eq. 'F') then
         i = nf_def_var (ncid, name, nf_real, nd, id, iv)
@@ -690,6 +603,9 @@
         i = nf_put_att_double (ncid,iv,'fill_value',nf_real,1                                                                        &
      &,   nf_fill_double)
         call checkerror (i,'defvar fill_value real '//trim(name))
+        i = nf_put_att_double (ncid,iv,'missing_value',nf_real,1                                                                     &
+     &,   nf_fill_double)
+        call checkerror (i,'defvar missing_value real '//trim(name))
 
       elseif (type .eq. 'I') then
         i = nf_def_var (ncid, name, nf_int, nd, id, iv)
@@ -703,6 +619,9 @@
         i = nf_put_att_int (ncid,iv,'fill_value',nf_int,1                                                                            &
      &,   nf_fill_int)
         call checkerror (i,'defvar fill_value integer '//trim(name))
+        i = nf_put_att_int (ncid,iv,'missing_value',nf_int,1                                                                         &
+     &,   nf_fill_int)
+        call checkerror (i,'defvar missing_value integer '//trim(name))
 
       elseif (type(1:1) .eq. 'T') then
         ln = 0
@@ -985,9 +904,9 @@
 
 !     input:
 !       it  = flag for grid (t=1, u=2)
-!       xt  = t grid poistion array
+!       xt  = t grid position array
 !       dxt = t grid width
-!       xu  = u grid poistion array
+!       xu  = u grid position array
 !       dxu = u grid width
 !       imt = array size
 !     output:
