@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/vmixc.h
+! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/vmixc.h
 !====================== include file "vmixc.h" =========================
 
 !         vertical mixing coefficients and related variables
@@ -16,7 +16,7 @@
 !             note: not used unless "implicitvmix" or "isopycmix"
 !                   is enabled
 
-!     author:   r.c.pacanowski     e-mail  rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       real kappa_h,  kappa_m
