@@ -1,33 +1,21 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/embm/winds.F
-      subroutine calc_astress (is, ie, js, je)
-
-!=======================================================================
-!     calculate anomolous pressure and geostrophic wind
-!     based on code by a.fanning
-
-!     author:   m.eby   e-mail: eby@uvic.ca
-!=======================================================================
-
-      return
-      end
-
-      subroutine add_astress (is, ie, js, je)
+! source file: /usr/local/models/UVic_ESCM/2.8/source/embm/winds.F
+      subroutine add_awind (is, ie, js, je)
 
 !=======================================================================
 !     update winds
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: A. Fanning and M. Eby
 !=======================================================================
 
       return
       end
 
-      subroutine geowind (contr, press, ugr, vgr, is, ie, js, je)
+      subroutine calc_awind (is, ie, js, je)
 
 !=======================================================================
-!     calculate the geostrophic velocities on uv grid (cm/s)
+!     calculate anomalous pressure and geostrophic wind
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: A. Fanning, A. Scmittner and M. Eby
 !=======================================================================
 
       return
